ten_k = "material/10k"
ten_k_fill = "material/10k:fill"
ten_mp = "material/10mp"
ten_mp_fill = "material/10mp:fill"
eleven_mp = "material/11mp"
eleven_mp_fill = "material/11mp:fill"
hundred_twenty_three_ = "material/123"
hundred_twenty_three__fill = "material/123:fill"
twelve_mp = "material/12mp"
twelve_mp_fill = "material/12mp:fill"
thirteen_mp = "material/13mp"
thirteen_mp_fill = "material/13mp:fill"
fourteen_mp = "material/14mp"
fourteen_mp_fill = "material/14mp:fill"
fifteen_mp = "material/15mp"
fifteen_mp_fill = "material/15mp:fill"
sixteen_mp = "material/16mp"
sixteen_mp_fill = "material/16mp:fill"
seventeen_mp = "material/17mp"
seventeen_mp_fill = "material/17mp:fill"
eighteen__up_rating = "material/18-up-rating"
eighteen__up_rating_fill = "material/18-up-rating:fill"
eighteen_mp = "material/18mp"
eighteen_mp_fill = "material/18mp:fill"
nineteen_mp = "material/19mp"
nineteen_mp_fill = "material/19mp:fill"
one_k = "material/1k"
one_k_fill = "material/1k:fill"
one_k_plus = "material/1k-plus"
one_k_plus_fill = "material/1k-plus:fill"
one_x_mobiledata = "material/1x-mobiledata"
one_x_mobiledata_fill = "material/1x-mobiledata:fill"
one_x_mobiledata_badge = "material/1x-mobiledata-badge"
one_x_mobiledata_badge_fill = "material/1x-mobiledata-badge:fill"
twenty_mp = "material/20mp"
twenty_mp_fill = "material/20mp:fill"
twenty_one_mp = "material/21mp"
twenty_one_mp_fill = "material/21mp:fill"
twenty_two_mp = "material/22mp"
twenty_two_mp_fill = "material/22mp:fill"
twenty_three_mp = "material/23mp"
twenty_three_mp_fill = "material/23mp:fill"
twenty_four_mp = "material/24mp"
twenty_four_mp_fill = "material/24mp:fill"
two_d = "material/2d"
two_d_fill = "material/2d:fill"
two_k = "material/2k"
two_k_fill = "material/2k:fill"
two_k_plus = "material/2k-plus"
two_k_plus_fill = "material/2k-plus:fill"
two_mp = "material/2mp"
two_mp_fill = "material/2mp:fill"
thirty_fps = "material/30fps"
thirty_fps_fill = "material/30fps:fill"
thirty_fps_select = "material/30fps-select"
thirty_fps_select_fill = "material/30fps-select:fill"
three_sixty_ = "material/360"
three_sixty__fill = "material/360:fill"
three_d_rotation = "material/3d-rotation"
three_d_rotation_fill = "material/3d-rotation:fill"
three_g_mobiledata = "material/3g-mobiledata"
three_g_mobiledata_fill = "material/3g-mobiledata:fill"
three_g_mobiledata_badge = "material/3g-mobiledata-badge"
three_g_mobiledata_badge_fill = "material/3g-mobiledata-badge:fill"
three_k = "material/3k"
three_k_fill = "material/3k:fill"
three_k_plus = "material/3k-plus"
three_k_plus_fill = "material/3k-plus:fill"
three_mp = "material/3mp"
three_mp_fill = "material/3mp:fill"
three_p = "material/3p"
three_p_fill = "material/3p:fill"
four_g_mobiledata = "material/4g-mobiledata"
four_g_mobiledata_fill = "material/4g-mobiledata:fill"
four_g_mobiledata_badge = "material/4g-mobiledata-badge"
four_g_mobiledata_badge_fill = "material/4g-mobiledata-badge:fill"
four_g_plus_mobiledata = "material/4g-plus-mobiledata"
four_g_plus_mobiledata_fill = "material/4g-plus-mobiledata:fill"
four_k = "material/4k"
four_k_fill = "material/4k:fill"
four_k_plus = "material/4k-plus"
four_k_plus_fill = "material/4k-plus:fill"
four_mp = "material/4mp"
four_mp_fill = "material/4mp:fill"
fifty_mp = "material/50mp"
fifty_mp_fill = "material/50mp:fill"
five_g = "material/5g"
five_g_fill = "material/5g:fill"
five_g_mobiledata_badge = "material/5g-mobiledata-badge"
five_g_mobiledata_badge_fill = "material/5g-mobiledata-badge:fill"
five_k = "material/5k"
five_k_fill = "material/5k:fill"
five_k_plus = "material/5k-plus"
five_k_plus_fill = "material/5k-plus:fill"
five_mp = "material/5mp"
five_mp_fill = "material/5mp:fill"
six__ft_apart = "material/6-ft-apart"
six__ft_apart_fill = "material/6-ft-apart:fill"
sixty_fps = "material/60fps"
sixty_fps_fill = "material/60fps:fill"
sixty_fps_select = "material/60fps-select"
sixty_fps_select_fill = "material/60fps-select:fill"
six_k = "material/6k"
six_k_fill = "material/6k:fill"
six_k_plus = "material/6k-plus"
six_k_plus_fill = "material/6k-plus:fill"
six_mp = "material/6mp"
six_mp_fill = "material/6mp:fill"
seven_k = "material/7k"
seven_k_fill = "material/7k:fill"
seven_k_plus = "material/7k-plus"
seven_k_plus_fill = "material/7k-plus:fill"
seven_mp = "material/7mp"
seven_mp_fill = "material/7mp:fill"
eight_k = "material/8k"
eight_k_fill = "material/8k:fill"
eight_k_plus = "material/8k-plus"
eight_k_plus_fill = "material/8k-plus:fill"
eight_mp = "material/8mp"
eight_mp_fill = "material/8mp:fill"
nine_k = "material/9k"
nine_k_fill = "material/9k:fill"
nine_k_plus = "material/9k-plus"
nine_k_plus_fill = "material/9k-plus:fill"
nine_mp = "material/9mp"
nine_mp_fill = "material/9mp:fill"
abc = "material/abc"
abc_fill = "material/abc:fill"
ac_unit = "material/ac-unit"
ac_unit_fill = "material/ac-unit:fill"
accessibility = "material/accessibility"
accessibility_fill = "material/accessibility:fill"
accessibility_new = "material/accessibility-new"
accessibility_new_fill = "material/accessibility-new:fill"
accessible = "material/accessible"
accessible_fill = "material/accessible:fill"
accessible_forward = "material/accessible-forward"
accessible_forward_fill = "material/accessible-forward:fill"
account_balance = "material/account-balance"
account_balance_fill = "material/account-balance:fill"
account_balance_wallet = "material/account-balance-wallet"
account_balance_wallet_fill = "material/account-balance-wallet:fill"
account_box = "material/account-box"
account_box_fill = "material/account-box:fill"
account_circle = "material/account-circle"
account_circle_fill = "material/account-circle:fill"
account_circle_off = "material/account-circle-off"
account_circle_off_fill = "material/account-circle-off:fill"
account_tree = "material/account-tree"
account_tree_fill = "material/account-tree:fill"
activity_zone = "material/activity-zone"
activity_zone_fill = "material/activity-zone:fill"
acute = "material/acute"
acute_fill = "material/acute:fill"
ad = "material/ad"
ad_fill = "material/ad:fill"
ad_group = "material/ad-group"
ad_group_fill = "material/ad-group:fill"
ad_group_off = "material/ad-group-off"
ad_group_off_fill = "material/ad-group-off:fill"
ad_off = "material/ad-off"
ad_off_fill = "material/ad-off:fill"
ad_units = "material/ad-units"
ad_units_fill = "material/ad-units:fill"
adb = "material/adb"
adb_fill = "material/adb:fill"
add = "material/add"
add_fill = "material/add:fill"
add_a_photo = "material/add-a-photo"
add_a_photo_fill = "material/add-a-photo:fill"
add_ad = "material/add-ad"
add_ad_fill = "material/add-ad:fill"
add_alert = "material/add-alert"
add_alert_fill = "material/add-alert:fill"
add_box = "material/add-box"
add_box_fill = "material/add-box:fill"
add_business = "material/add-business"
add_business_fill = "material/add-business:fill"
add_call = "material/add-call"
add_call_fill = "material/add-call:fill"
add_card = "material/add-card"
add_card_fill = "material/add-card:fill"
add_chart = "material/add-chart"
add_chart_fill = "material/add-chart:fill"
add_circle = "material/add-circle"
add_circle_fill = "material/add-circle:fill"
add_comment = "material/add-comment"
add_comment_fill = "material/add-comment:fill"
add_home = "material/add-home"
add_home_fill = "material/add-home:fill"
add_home_work = "material/add-home-work"
add_home_work_fill = "material/add-home-work:fill"
add_link = "material/add-link"
add_link_fill = "material/add-link:fill"
add_location = "material/add-location"
add_location_fill = "material/add-location:fill"
add_location_alt = "material/add-location-alt"
add_location_alt_fill = "material/add-location-alt:fill"
add_moderator = "material/add-moderator"
add_moderator_fill = "material/add-moderator:fill"
add_notes = "material/add-notes"
add_notes_fill = "material/add-notes:fill"
add_photo_alternate = "material/add-photo-alternate"
add_photo_alternate_fill = "material/add-photo-alternate:fill"
add_reaction = "material/add-reaction"
add_reaction_fill = "material/add-reaction:fill"
add_road = "material/add-road"
add_road_fill = "material/add-road:fill"
add_shopping_cart = "material/add-shopping-cart"
add_shopping_cart_fill = "material/add-shopping-cart:fill"
add_task = "material/add-task"
add_task_fill = "material/add-task:fill"
add_to_drive = "material/add-to-drive"
add_to_drive_fill = "material/add-to-drive:fill"
add_to_home_screen = "material/add-to-home-screen"
add_to_home_screen_fill = "material/add-to-home-screen:fill"
add_to_photos = "material/add-to-photos"
add_to_photos_fill = "material/add-to-photos:fill"
add_to_queue = "material/add-to-queue"
add_to_queue_fill = "material/add-to-queue:fill"
adf_scanner = "material/adf-scanner"
adf_scanner_fill = "material/adf-scanner:fill"
adjust = "material/adjust"
adjust_fill = "material/adjust:fill"
admin_meds = "material/admin-meds"
admin_meds_fill = "material/admin-meds:fill"
admin_panel_settings = "material/admin-panel-settings"
admin_panel_settings_fill = "material/admin-panel-settings:fill"
ads_click = "material/ads-click"
ads_click_fill = "material/ads-click:fill"
agender = "material/agender"
agender_fill = "material/agender:fill"
agriculture = "material/agriculture"
agriculture_fill = "material/agriculture:fill"
air = "material/air"
air_fill = "material/air:fill"
air_freshener = "material/air-freshener"
air_freshener_fill = "material/air-freshener:fill"
air_purifier_gen = "material/air-purifier-gen"
air_purifier_gen_fill = "material/air-purifier-gen:fill"
airline_seat_flat = "material/airline-seat-flat"
airline_seat_flat_fill = "material/airline-seat-flat:fill"
airline_seat_flat_angled = "material/airline-seat-flat-angled"
airline_seat_flat_angled_fill = "material/airline-seat-flat-angled:fill"
airline_seat_individual_suite = "material/airline-seat-individual-suite"
airline_seat_individual_suite_fill = (
    "material/airline-seat-individual-suite:fill"
)
airline_seat_legroom_extra = "material/airline-seat-legroom-extra"
airline_seat_legroom_extra_fill = "material/airline-seat-legroom-extra:fill"
airline_seat_legroom_normal = "material/airline-seat-legroom-normal"
airline_seat_legroom_normal_fill = "material/airline-seat-legroom-normal:fill"
airline_seat_legroom_reduced = "material/airline-seat-legroom-reduced"
airline_seat_legroom_reduced_fill = "material/airline-seat-legroom-reduced:fill"
airline_seat_recline_extra = "material/airline-seat-recline-extra"
airline_seat_recline_extra_fill = "material/airline-seat-recline-extra:fill"
airline_seat_recline_normal = "material/airline-seat-recline-normal"
airline_seat_recline_normal_fill = "material/airline-seat-recline-normal:fill"
airline_stops = "material/airline-stops"
airline_stops_fill = "material/airline-stops:fill"
airlines = "material/airlines"
airlines_fill = "material/airlines:fill"
airplane_ticket = "material/airplane-ticket"
airplane_ticket_fill = "material/airplane-ticket:fill"
airplanemode_active = "material/airplanemode-active"
airplanemode_active_fill = "material/airplanemode-active:fill"
airplanemode_inactive = "material/airplanemode-inactive"
airplanemode_inactive_fill = "material/airplanemode-inactive:fill"
airplay = "material/airplay"
airplay_fill = "material/airplay:fill"
airport_shuttle = "material/airport-shuttle"
airport_shuttle_fill = "material/airport-shuttle:fill"
airware = "material/airware"
airware_fill = "material/airware:fill"
airwave = "material/airwave"
airwave_fill = "material/airwave:fill"
alarm = "material/alarm"
alarm_fill = "material/alarm:fill"
alarm_add = "material/alarm-add"
alarm_add_fill = "material/alarm-add:fill"
alarm_off = "material/alarm-off"
alarm_off_fill = "material/alarm-off:fill"
alarm_on = "material/alarm-on"
alarm_on_fill = "material/alarm-on:fill"
alarm_smart_wake = "material/alarm-smart-wake"
alarm_smart_wake_fill = "material/alarm-smart-wake:fill"
album = "material/album"
album_fill = "material/album:fill"
align_center = "material/align-center"
align_center_fill = "material/align-center:fill"
align_end = "material/align-end"
align_end_fill = "material/align-end:fill"
align_flex_center = "material/align-flex-center"
align_flex_center_fill = "material/align-flex-center:fill"
align_flex_end = "material/align-flex-end"
align_flex_end_fill = "material/align-flex-end:fill"
align_flex_start = "material/align-flex-start"
align_flex_start_fill = "material/align-flex-start:fill"
align_horizontal_center = "material/align-horizontal-center"
align_horizontal_center_fill = "material/align-horizontal-center:fill"
align_horizontal_left = "material/align-horizontal-left"
align_horizontal_left_fill = "material/align-horizontal-left:fill"
align_horizontal_right = "material/align-horizontal-right"
align_horizontal_right_fill = "material/align-horizontal-right:fill"
align_items_stretch = "material/align-items-stretch"
align_items_stretch_fill = "material/align-items-stretch:fill"
align_justify_center = "material/align-justify-center"
align_justify_center_fill = "material/align-justify-center:fill"
align_justify_flex_end = "material/align-justify-flex-end"
align_justify_flex_end_fill = "material/align-justify-flex-end:fill"
align_justify_flex_start = "material/align-justify-flex-start"
align_justify_flex_start_fill = "material/align-justify-flex-start:fill"
align_justify_space_around = "material/align-justify-space-around"
align_justify_space_around_fill = "material/align-justify-space-around:fill"
align_justify_space_between = "material/align-justify-space-between"
align_justify_space_between_fill = "material/align-justify-space-between:fill"
align_justify_space_even = "material/align-justify-space-even"
align_justify_space_even_fill = "material/align-justify-space-even:fill"
align_justify_stretch = "material/align-justify-stretch"
align_justify_stretch_fill = "material/align-justify-stretch:fill"
align_self_stretch = "material/align-self-stretch"
align_self_stretch_fill = "material/align-self-stretch:fill"
align_space_around = "material/align-space-around"
align_space_around_fill = "material/align-space-around:fill"
align_space_between = "material/align-space-between"
align_space_between_fill = "material/align-space-between:fill"
align_space_even = "material/align-space-even"
align_space_even_fill = "material/align-space-even:fill"
align_start = "material/align-start"
align_start_fill = "material/align-start:fill"
align_stretch = "material/align-stretch"
align_stretch_fill = "material/align-stretch:fill"
align_vertical_bottom = "material/align-vertical-bottom"
align_vertical_bottom_fill = "material/align-vertical-bottom:fill"
align_vertical_center = "material/align-vertical-center"
align_vertical_center_fill = "material/align-vertical-center:fill"
align_vertical_top = "material/align-vertical-top"
align_vertical_top_fill = "material/align-vertical-top:fill"
all_inbox = "material/all-inbox"
all_inbox_fill = "material/all-inbox:fill"
all_inclusive = "material/all-inclusive"
all_inclusive_fill = "material/all-inclusive:fill"
all_match = "material/all-match"
all_match_fill = "material/all-match:fill"
all_out = "material/all-out"
all_out_fill = "material/all-out:fill"
allergies = "material/allergies"
allergies_fill = "material/allergies:fill"
allergy = "material/allergy"
allergy_fill = "material/allergy:fill"
alt_route = "material/alt-route"
alt_route_fill = "material/alt-route:fill"
alternate_email = "material/alternate-email"
alternate_email_fill = "material/alternate-email:fill"
altitude = "material/altitude"
altitude_fill = "material/altitude:fill"
ambulance = "material/ambulance"
ambulance_fill = "material/ambulance:fill"
amend = "material/amend"
amend_fill = "material/amend:fill"
amp_stories = "material/amp-stories"
amp_stories_fill = "material/amp-stories:fill"
analytics = "material/analytics"
analytics_fill = "material/analytics:fill"
anchor = "material/anchor"
anchor_fill = "material/anchor:fill"
android = "material/android"
android_fill = "material/android:fill"
animation = "material/animation"
animation_fill = "material/animation:fill"
aod = "material/aod"
aod_fill = "material/aod:fill"
aod_tablet = "material/aod-tablet"
aod_tablet_fill = "material/aod-tablet:fill"
aod_watch = "material/aod-watch"
aod_watch_fill = "material/aod-watch:fill"
apartment = "material/apartment"
apartment_fill = "material/apartment:fill"
api = "material/api"
api_fill = "material/api:fill"
apk_document = "material/apk-document"
apk_document_fill = "material/apk-document:fill"
apk_install = "material/apk-install"
apk_install_fill = "material/apk-install:fill"
app_badging = "material/app-badging"
app_badging_fill = "material/app-badging:fill"
app_blocking = "material/app-blocking"
app_blocking_fill = "material/app-blocking:fill"
app_promo = "material/app-promo"
app_promo_fill = "material/app-promo:fill"
app_registration = "material/app-registration"
app_registration_fill = "material/app-registration:fill"
app_shortcut = "material/app-shortcut"
app_shortcut_fill = "material/app-shortcut:fill"
approval = "material/approval"
approval_fill = "material/approval:fill"
approval_delegation = "material/approval-delegation"
approval_delegation_fill = "material/approval-delegation:fill"
apps = "material/apps"
apps_fill = "material/apps:fill"
apps_outage = "material/apps-outage"
apps_outage_fill = "material/apps-outage:fill"
aq = "material/aq"
aq_fill = "material/aq:fill"
aq_indoor = "material/aq-indoor"
aq_indoor_fill = "material/aq-indoor:fill"
ar_on_you = "material/ar-on-you"
ar_on_you_fill = "material/ar-on-you:fill"
architecture = "material/architecture"
architecture_fill = "material/architecture:fill"
archive = "material/archive"
archive_fill = "material/archive:fill"
area_chart = "material/area-chart"
area_chart_fill = "material/area-chart:fill"
arming_countdown = "material/arming-countdown"
arming_countdown_fill = "material/arming-countdown:fill"
arrow_and_edge = "material/arrow-and-edge"
arrow_and_edge_fill = "material/arrow-and-edge:fill"
arrow_back = "material/arrow-back"
arrow_back_fill = "material/arrow-back:fill"
arrow_back_ios = "material/arrow-back-ios"
arrow_back_ios_fill = "material/arrow-back-ios:fill"
arrow_back_ios_new = "material/arrow-back-ios-new"
arrow_back_ios_new_fill = "material/arrow-back-ios-new:fill"
arrow_circle_down = "material/arrow-circle-down"
arrow_circle_down_fill = "material/arrow-circle-down:fill"
arrow_circle_left = "material/arrow-circle-left"
arrow_circle_left_fill = "material/arrow-circle-left:fill"
arrow_circle_right = "material/arrow-circle-right"
arrow_circle_right_fill = "material/arrow-circle-right:fill"
arrow_circle_up = "material/arrow-circle-up"
arrow_circle_up_fill = "material/arrow-circle-up:fill"
arrow_downward = "material/arrow-downward"
arrow_downward_fill = "material/arrow-downward:fill"
arrow_downward_alt = "material/arrow-downward-alt"
arrow_downward_alt_fill = "material/arrow-downward-alt:fill"
arrow_drop_down = "material/arrow-drop-down"
arrow_drop_down_fill = "material/arrow-drop-down:fill"
arrow_drop_down_circle = "material/arrow-drop-down-circle"
arrow_drop_down_circle_fill = "material/arrow-drop-down-circle:fill"
arrow_drop_up = "material/arrow-drop-up"
arrow_drop_up_fill = "material/arrow-drop-up:fill"
arrow_forward = "material/arrow-forward"
arrow_forward_fill = "material/arrow-forward:fill"
arrow_forward_ios = "material/arrow-forward-ios"
arrow_forward_ios_fill = "material/arrow-forward-ios:fill"
arrow_insert = "material/arrow-insert"
arrow_insert_fill = "material/arrow-insert:fill"
arrow_left = "material/arrow-left"
arrow_left_fill = "material/arrow-left:fill"
arrow_left_alt = "material/arrow-left-alt"
arrow_left_alt_fill = "material/arrow-left-alt:fill"
arrow_or_edge = "material/arrow-or-edge"
arrow_or_edge_fill = "material/arrow-or-edge:fill"
arrow_outward = "material/arrow-outward"
arrow_outward_fill = "material/arrow-outward:fill"
arrow_range = "material/arrow-range"
arrow_range_fill = "material/arrow-range:fill"
arrow_right = "material/arrow-right"
arrow_right_fill = "material/arrow-right:fill"
arrow_right_alt = "material/arrow-right-alt"
arrow_right_alt_fill = "material/arrow-right-alt:fill"
arrow_selector_tool = "material/arrow-selector-tool"
arrow_selector_tool_fill = "material/arrow-selector-tool:fill"
arrow_split = "material/arrow-split"
arrow_split_fill = "material/arrow-split:fill"
arrow_top_left = "material/arrow-top-left"
arrow_top_left_fill = "material/arrow-top-left:fill"
arrow_top_right = "material/arrow-top-right"
arrow_top_right_fill = "material/arrow-top-right:fill"
arrow_upward = "material/arrow-upward"
arrow_upward_fill = "material/arrow-upward:fill"
arrow_upward_alt = "material/arrow-upward-alt"
arrow_upward_alt_fill = "material/arrow-upward-alt:fill"
arrows_more_down = "material/arrows-more-down"
arrows_more_down_fill = "material/arrows-more-down:fill"
arrows_more_up = "material/arrows-more-up"
arrows_more_up_fill = "material/arrows-more-up:fill"
arrows_outward = "material/arrows-outward"
arrows_outward_fill = "material/arrows-outward:fill"
art_track = "material/art-track"
art_track_fill = "material/art-track:fill"
article = "material/article"
article_fill = "material/article:fill"
article_shortcut = "material/article-shortcut"
article_shortcut_fill = "material/article-shortcut:fill"
aspect_ratio = "material/aspect-ratio"
aspect_ratio_fill = "material/aspect-ratio:fill"
assignment = "material/assignment"
assignment_fill = "material/assignment:fill"
assignment_add = "material/assignment-add"
assignment_add_fill = "material/assignment-add:fill"
assignment_ind = "material/assignment-ind"
assignment_ind_fill = "material/assignment-ind:fill"
assignment_late = "material/assignment-late"
assignment_late_fill = "material/assignment-late:fill"
assignment_return = "material/assignment-return"
assignment_return_fill = "material/assignment-return:fill"
assignment_returned = "material/assignment-returned"
assignment_returned_fill = "material/assignment-returned:fill"
assignment_turned_in = "material/assignment-turned-in"
assignment_turned_in_fill = "material/assignment-turned-in:fill"
assist_walker = "material/assist-walker"
assist_walker_fill = "material/assist-walker:fill"
assistant_direction = "material/assistant-direction"
assistant_direction_fill = "material/assistant-direction:fill"
assistant_navigation = "material/assistant-navigation"
assistant_navigation_fill = "material/assistant-navigation:fill"
assistant_on_hub = "material/assistant-on-hub"
assistant_on_hub_fill = "material/assistant-on-hub:fill"
assured_workload = "material/assured-workload"
assured_workload_fill = "material/assured-workload:fill"
atm = "material/atm"
atm_fill = "material/atm:fill"
atr = "material/atr"
atr_fill = "material/atr:fill"
attach_email = "material/attach-email"
attach_email_fill = "material/attach-email:fill"
attach_file = "material/attach-file"
attach_file_fill = "material/attach-file:fill"
attach_file_add = "material/attach-file-add"
attach_file_add_fill = "material/attach-file-add:fill"
attach_money = "material/attach-money"
attach_money_fill = "material/attach-money:fill"
attachment = "material/attachment"
attachment_fill = "material/attachment:fill"
attractions = "material/attractions"
attractions_fill = "material/attractions:fill"
attribution = "material/attribution"
attribution_fill = "material/attribution:fill"
audio_description = "material/audio-description"
audio_description_fill = "material/audio-description:fill"
audio_file = "material/audio-file"
audio_file_fill = "material/audio-file:fill"
audio_video_receiver = "material/audio-video-receiver"
audio_video_receiver_fill = "material/audio-video-receiver:fill"
auto_awesome_mosaic = "material/auto-awesome-mosaic"
auto_awesome_mosaic_fill = "material/auto-awesome-mosaic:fill"
auto_awesome_motion = "material/auto-awesome-motion"
auto_awesome_motion_fill = "material/auto-awesome-motion:fill"
auto_delete = "material/auto-delete"
auto_delete_fill = "material/auto-delete:fill"
auto_read_pause = "material/auto-read-pause"
auto_read_pause_fill = "material/auto-read-pause:fill"
auto_read_play = "material/auto-read-play"
auto_read_play_fill = "material/auto-read-play:fill"
auto_stories = "material/auto-stories"
auto_stories_fill = "material/auto-stories:fill"
autofps_select = "material/autofps-select"
autofps_select_fill = "material/autofps-select:fill"
autopause = "material/autopause"
autopause_fill = "material/autopause:fill"
autoplay = "material/autoplay"
autoplay_fill = "material/autoplay:fill"
autorenew = "material/autorenew"
autorenew_fill = "material/autorenew:fill"
autostop = "material/autostop"
autostop_fill = "material/autostop:fill"
av_timer = "material/av-timer"
av_timer_fill = "material/av-timer:fill"
avg_pace = "material/avg-pace"
avg_pace_fill = "material/avg-pace:fill"
avg_time = "material/avg-time"
avg_time_fill = "material/avg-time:fill"
award_star = "material/award-star"
award_star_fill = "material/award-star:fill"
azm = "material/azm"
azm_fill = "material/azm:fill"
baby_changing_station = "material/baby-changing-station"
baby_changing_station_fill = "material/baby-changing-station:fill"
back_hand = "material/back-hand"
back_hand_fill = "material/back-hand:fill"
back_to_tab = "material/back-to-tab"
back_to_tab_fill = "material/back-to-tab:fill"
background_dot_large = "material/background-dot-large"
background_dot_large_fill = "material/background-dot-large:fill"
background_grid_small = "material/background-grid-small"
background_grid_small_fill = "material/background-grid-small:fill"
background_replace = "material/background-replace"
background_replace_fill = "material/background-replace:fill"
backlight_high = "material/backlight-high"
backlight_high_fill = "material/backlight-high:fill"
backlight_low = "material/backlight-low"
backlight_low_fill = "material/backlight-low:fill"
backpack = "material/backpack"
backpack_fill = "material/backpack:fill"
backspace = "material/backspace"
backspace_fill = "material/backspace:fill"
backup = "material/backup"
backup_fill = "material/backup:fill"
backup_table = "material/backup-table"
backup_table_fill = "material/backup-table:fill"
badge = "material/badge"
badge_fill = "material/badge:fill"
badge_critical_battery = "material/badge-critical-battery"
badge_critical_battery_fill = "material/badge-critical-battery:fill"
bakery_dining = "material/bakery-dining"
bakery_dining_fill = "material/bakery-dining:fill"
balance = "material/balance"
balance_fill = "material/balance:fill"
balcony = "material/balcony"
balcony_fill = "material/balcony:fill"
ballot = "material/ballot"
ballot_fill = "material/ballot:fill"
bar_chart = "material/bar-chart"
bar_chart_fill = "material/bar-chart:fill"
bar_chart_4_bars = "material/bar-chart-4-bars"
bar_chart_4_bars_fill = "material/bar-chart-4-bars:fill"
barcode = "material/barcode"
barcode_fill = "material/barcode:fill"
barcode_reader = "material/barcode-reader"
barcode_reader_fill = "material/barcode-reader:fill"
barcode_scanner = "material/barcode-scanner"
barcode_scanner_fill = "material/barcode-scanner:fill"
barefoot = "material/barefoot"
barefoot_fill = "material/barefoot:fill"
batch_prediction = "material/batch-prediction"
batch_prediction_fill = "material/batch-prediction:fill"
bath_outdoor = "material/bath-outdoor"
bath_outdoor_fill = "material/bath-outdoor:fill"
bath_private = "material/bath-private"
bath_private_fill = "material/bath-private:fill"
bath_public_large = "material/bath-public-large"
bath_public_large_fill = "material/bath-public-large:fill"
bathroom = "material/bathroom"
bathroom_fill = "material/bathroom:fill"
bathtub = "material/bathtub"
bathtub_fill = "material/bathtub:fill"
battery_0_bar = "material/battery-0-bar"
battery_0_bar_fill = "material/battery-0-bar:fill"
battery_1_bar = "material/battery-1-bar"
battery_1_bar_fill = "material/battery-1-bar:fill"
battery_2_bar = "material/battery-2-bar"
battery_2_bar_fill = "material/battery-2-bar:fill"
battery_3_bar = "material/battery-3-bar"
battery_3_bar_fill = "material/battery-3-bar:fill"
battery_4_bar = "material/battery-4-bar"
battery_4_bar_fill = "material/battery-4-bar:fill"
battery_5_bar = "material/battery-5-bar"
battery_5_bar_fill = "material/battery-5-bar:fill"
battery_6_bar = "material/battery-6-bar"
battery_6_bar_fill = "material/battery-6-bar:fill"
battery_alert = "material/battery-alert"
battery_alert_fill = "material/battery-alert:fill"
battery_change = "material/battery-change"
battery_change_fill = "material/battery-change:fill"
battery_charging_20 = "material/battery-charging-20"
battery_charging_20_fill = "material/battery-charging-20:fill"
battery_charging_30 = "material/battery-charging-30"
battery_charging_30_fill = "material/battery-charging-30:fill"
battery_charging_50 = "material/battery-charging-50"
battery_charging_50_fill = "material/battery-charging-50:fill"
battery_charging_60 = "material/battery-charging-60"
battery_charging_60_fill = "material/battery-charging-60:fill"
battery_charging_80 = "material/battery-charging-80"
battery_charging_80_fill = "material/battery-charging-80:fill"
battery_charging_90 = "material/battery-charging-90"
battery_charging_90_fill = "material/battery-charging-90:fill"
battery_charging_full = "material/battery-charging-full"
battery_charging_full_fill = "material/battery-charging-full:fill"
battery_error = "material/battery-error"
battery_error_fill = "material/battery-error:fill"
battery_full = "material/battery-full"
battery_full_fill = "material/battery-full:fill"
battery_full_alt = "material/battery-full-alt"
battery_full_alt_fill = "material/battery-full-alt:fill"
battery_horiz_000 = "material/battery-horiz-000"
battery_horiz_000_fill = "material/battery-horiz-000:fill"
battery_horiz_050 = "material/battery-horiz-050"
battery_horiz_050_fill = "material/battery-horiz-050:fill"
battery_horiz_075 = "material/battery-horiz-075"
battery_horiz_075_fill = "material/battery-horiz-075:fill"
battery_low = "material/battery-low"
battery_low_fill = "material/battery-low:fill"
battery_plus = "material/battery-plus"
battery_plus_fill = "material/battery-plus:fill"
battery_profile = "material/battery-profile"
battery_profile_fill = "material/battery-profile:fill"
battery_saver = "material/battery-saver"
battery_saver_fill = "material/battery-saver:fill"
battery_share = "material/battery-share"
battery_share_fill = "material/battery-share:fill"
battery_status_good = "material/battery-status-good"
battery_status_good_fill = "material/battery-status-good:fill"
battery_unknown = "material/battery-unknown"
battery_unknown_fill = "material/battery-unknown:fill"
battery_very_low = "material/battery-very-low"
battery_very_low_fill = "material/battery-very-low:fill"
beach_access = "material/beach-access"
beach_access_fill = "material/beach-access:fill"
bed = "material/bed"
bed_fill = "material/bed:fill"
bedroom_baby = "material/bedroom-baby"
bedroom_baby_fill = "material/bedroom-baby:fill"
bedroom_child = "material/bedroom-child"
bedroom_child_fill = "material/bedroom-child:fill"
bedroom_parent = "material/bedroom-parent"
bedroom_parent_fill = "material/bedroom-parent:fill"
bedtime = "material/bedtime"
bedtime_fill = "material/bedtime:fill"
bedtime_off = "material/bedtime-off"
bedtime_off_fill = "material/bedtime-off:fill"
beenhere = "material/beenhere"
beenhere_fill = "material/beenhere:fill"
bento = "material/bento"
bento_fill = "material/bento:fill"
bia = "material/bia"
bia_fill = "material/bia:fill"
bid_landscape = "material/bid-landscape"
bid_landscape_fill = "material/bid-landscape:fill"
bid_landscape_disabled = "material/bid-landscape-disabled"
bid_landscape_disabled_fill = "material/bid-landscape-disabled:fill"
bike_scooter = "material/bike-scooter"
bike_scooter_fill = "material/bike-scooter:fill"
biotech = "material/biotech"
biotech_fill = "material/biotech:fill"
blanket = "material/blanket"
blanket_fill = "material/blanket:fill"
blender = "material/blender"
blender_fill = "material/blender:fill"
blind = "material/blind"
blind_fill = "material/blind:fill"
blinds = "material/blinds"
blinds_fill = "material/blinds:fill"
blinds_closed = "material/blinds-closed"
blinds_closed_fill = "material/blinds-closed:fill"
block = "material/block"
block_fill = "material/block:fill"
blood_pressure = "material/blood-pressure"
blood_pressure_fill = "material/blood-pressure:fill"
bloodtype = "material/bloodtype"
bloodtype_fill = "material/bloodtype:fill"
bluetooth = "material/bluetooth"
bluetooth_fill = "material/bluetooth:fill"
bluetooth_connected = "material/bluetooth-connected"
bluetooth_connected_fill = "material/bluetooth-connected:fill"
bluetooth_disabled = "material/bluetooth-disabled"
bluetooth_disabled_fill = "material/bluetooth-disabled:fill"
bluetooth_drive = "material/bluetooth-drive"
bluetooth_drive_fill = "material/bluetooth-drive:fill"
bluetooth_searching = "material/bluetooth-searching"
bluetooth_searching_fill = "material/bluetooth-searching:fill"
blur_circular = "material/blur-circular"
blur_circular_fill = "material/blur-circular:fill"
blur_linear = "material/blur-linear"
blur_linear_fill = "material/blur-linear:fill"
blur_medium = "material/blur-medium"
blur_medium_fill = "material/blur-medium:fill"
blur_off = "material/blur-off"
blur_off_fill = "material/blur-off:fill"
blur_on = "material/blur-on"
blur_on_fill = "material/blur-on:fill"
blur_short = "material/blur-short"
blur_short_fill = "material/blur-short:fill"
body_fat = "material/body-fat"
body_fat_fill = "material/body-fat:fill"
body_system = "material/body-system"
body_system_fill = "material/body-system:fill"
bolt = "material/bolt"
bolt_fill = "material/bolt:fill"
bomb = "material/bomb"
bomb_fill = "material/bomb:fill"
book = "material/book"
book_fill = "material/book:fill"
book_online = "material/book-online"
book_online_fill = "material/book-online:fill"
bookmark = "material/bookmark"
bookmark_fill = "material/bookmark:fill"
bookmark_add = "material/bookmark-add"
bookmark_add_fill = "material/bookmark-add:fill"
bookmark_added = "material/bookmark-added"
bookmark_added_fill = "material/bookmark-added:fill"
bookmark_manager = "material/bookmark-manager"
bookmark_manager_fill = "material/bookmark-manager:fill"
bookmark_remove = "material/bookmark-remove"
bookmark_remove_fill = "material/bookmark-remove:fill"
bookmarks = "material/bookmarks"
bookmarks_fill = "material/bookmarks:fill"
border_all = "material/border-all"
border_all_fill = "material/border-all:fill"
border_bottom = "material/border-bottom"
border_bottom_fill = "material/border-bottom:fill"
border_clear = "material/border-clear"
border_clear_fill = "material/border-clear:fill"
border_color = "material/border-color"
border_color_fill = "material/border-color:fill"
border_horizontal = "material/border-horizontal"
border_horizontal_fill = "material/border-horizontal:fill"
border_inner = "material/border-inner"
border_inner_fill = "material/border-inner:fill"
border_left = "material/border-left"
border_left_fill = "material/border-left:fill"
border_outer = "material/border-outer"
border_outer_fill = "material/border-outer:fill"
border_right = "material/border-right"
border_right_fill = "material/border-right:fill"
border_style = "material/border-style"
border_style_fill = "material/border-style:fill"
border_top = "material/border-top"
border_top_fill = "material/border-top:fill"
border_vertical = "material/border-vertical"
border_vertical_fill = "material/border-vertical:fill"
bottom_app_bar = "material/bottom-app-bar"
bottom_app_bar_fill = "material/bottom-app-bar:fill"
bottom_drawer = "material/bottom-drawer"
bottom_drawer_fill = "material/bottom-drawer:fill"
bottom_navigation = "material/bottom-navigation"
bottom_navigation_fill = "material/bottom-navigation:fill"
bottom_panel_close = "material/bottom-panel-close"
bottom_panel_close_fill = "material/bottom-panel-close:fill"
bottom_panel_open = "material/bottom-panel-open"
bottom_panel_open_fill = "material/bottom-panel-open:fill"
bottom_right_click = "material/bottom-right-click"
bottom_right_click_fill = "material/bottom-right-click:fill"
bottom_sheets = "material/bottom-sheets"
bottom_sheets_fill = "material/bottom-sheets:fill"
box = "material/box"
box_fill = "material/box:fill"
box_add = "material/box-add"
box_add_fill = "material/box-add:fill"
box_edit = "material/box-edit"
box_edit_fill = "material/box-edit:fill"
boy = "material/boy"
boy_fill = "material/boy:fill"
brand_awareness = "material/brand-awareness"
brand_awareness_fill = "material/brand-awareness:fill"
branding_watermark = "material/branding-watermark"
branding_watermark_fill = "material/branding-watermark:fill"
breakfast_dining = "material/breakfast-dining"
breakfast_dining_fill = "material/breakfast-dining:fill"
breaking_news = "material/breaking-news"
breaking_news_fill = "material/breaking-news:fill"
breaking_news_alt_1 = "material/breaking-news-alt-1"
breaking_news_alt_1_fill = "material/breaking-news-alt-1:fill"
breastfeeding = "material/breastfeeding"
breastfeeding_fill = "material/breastfeeding:fill"
brightness_1 = "material/brightness-1"
brightness_1_fill = "material/brightness-1:fill"
brightness_2 = "material/brightness-2"
brightness_2_fill = "material/brightness-2:fill"
brightness_3 = "material/brightness-3"
brightness_3_fill = "material/brightness-3:fill"
brightness_4 = "material/brightness-4"
brightness_4_fill = "material/brightness-4:fill"
brightness_5 = "material/brightness-5"
brightness_5_fill = "material/brightness-5:fill"
brightness_6 = "material/brightness-6"
brightness_6_fill = "material/brightness-6:fill"
brightness_7 = "material/brightness-7"
brightness_7_fill = "material/brightness-7:fill"
brightness_alert = "material/brightness-alert"
brightness_alert_fill = "material/brightness-alert:fill"
brightness_auto = "material/brightness-auto"
brightness_auto_fill = "material/brightness-auto:fill"
brightness_empty = "material/brightness-empty"
brightness_empty_fill = "material/brightness-empty:fill"
brightness_high = "material/brightness-high"
brightness_high_fill = "material/brightness-high:fill"
brightness_low = "material/brightness-low"
brightness_low_fill = "material/brightness-low:fill"
brightness_medium = "material/brightness-medium"
brightness_medium_fill = "material/brightness-medium:fill"
bring_your_own_ip = "material/bring-your-own-ip"
bring_your_own_ip_fill = "material/bring-your-own-ip:fill"
broadcast_on_home = "material/broadcast-on-home"
broadcast_on_home_fill = "material/broadcast-on-home:fill"
broadcast_on_personal = "material/broadcast-on-personal"
broadcast_on_personal_fill = "material/broadcast-on-personal:fill"
broken_image = "material/broken-image"
broken_image_fill = "material/broken-image:fill"
browse = "material/browse"
browse_fill = "material/browse:fill"
browse_activity = "material/browse-activity"
browse_activity_fill = "material/browse-activity:fill"
browse_gallery = "material/browse-gallery"
browse_gallery_fill = "material/browse-gallery:fill"
browser_updated = "material/browser-updated"
browser_updated_fill = "material/browser-updated:fill"
brunch_dining = "material/brunch-dining"
brunch_dining_fill = "material/brunch-dining:fill"
brush = "material/brush"
brush_fill = "material/brush:fill"
bubble = "material/bubble"
bubble_fill = "material/bubble:fill"
bubble_chart = "material/bubble-chart"
bubble_chart_fill = "material/bubble-chart:fill"
bubbles = "material/bubbles"
bubbles_fill = "material/bubbles:fill"
bug_report = "material/bug-report"
bug_report_fill = "material/bug-report:fill"
build = "material/build"
build_fill = "material/build:fill"
build_circle = "material/build-circle"
build_circle_fill = "material/build-circle:fill"
bungalow = "material/bungalow"
bungalow_fill = "material/bungalow:fill"
burst_mode = "material/burst-mode"
burst_mode_fill = "material/burst-mode:fill"
bus_alert = "material/bus-alert"
bus_alert_fill = "material/bus-alert:fill"
business_center = "material/business-center"
business_center_fill = "material/business-center:fill"
business_chip = "material/business-chip"
business_chip_fill = "material/business-chip:fill"
business_messages = "material/business-messages"
business_messages_fill = "material/business-messages:fill"
buttons_alt = "material/buttons-alt"
buttons_alt_fill = "material/buttons-alt:fill"
cabin = "material/cabin"
cabin_fill = "material/cabin:fill"
cable = "material/cable"
cable_fill = "material/cable:fill"
cached = "material/cached"
cached_fill = "material/cached:fill"
cake = "material/cake"
cake_fill = "material/cake:fill"
cake_add = "material/cake-add"
cake_add_fill = "material/cake-add:fill"
calculate = "material/calculate"
calculate_fill = "material/calculate:fill"
calendar_add_on = "material/calendar-add-on"
calendar_add_on_fill = "material/calendar-add-on:fill"
calendar_apps_script = "material/calendar-apps-script"
calendar_apps_script_fill = "material/calendar-apps-script:fill"
calendar_month = "material/calendar-month"
calendar_month_fill = "material/calendar-month:fill"
calendar_today = "material/calendar-today"
calendar_today_fill = "material/calendar-today:fill"
calendar_view_day = "material/calendar-view-day"
calendar_view_day_fill = "material/calendar-view-day:fill"
calendar_view_month = "material/calendar-view-month"
calendar_view_month_fill = "material/calendar-view-month:fill"
calendar_view_week = "material/calendar-view-week"
calendar_view_week_fill = "material/calendar-view-week:fill"
call = "material/call"
call_fill = "material/call:fill"
call_end = "material/call-end"
call_end_fill = "material/call-end:fill"
call_log = "material/call-log"
call_log_fill = "material/call-log:fill"
call_made = "material/call-made"
call_made_fill = "material/call-made:fill"
call_merge = "material/call-merge"
call_merge_fill = "material/call-merge:fill"
call_missed = "material/call-missed"
call_missed_fill = "material/call-missed:fill"
call_missed_outgoing = "material/call-missed-outgoing"
call_missed_outgoing_fill = "material/call-missed-outgoing:fill"
call_quality = "material/call-quality"
call_quality_fill = "material/call-quality:fill"
call_received = "material/call-received"
call_received_fill = "material/call-received:fill"
call_split = "material/call-split"
call_split_fill = "material/call-split:fill"
call_to_action = "material/call-to-action"
call_to_action_fill = "material/call-to-action:fill"
camera = "material/camera"
camera_fill = "material/camera:fill"
camera_front = "material/camera-front"
camera_front_fill = "material/camera-front:fill"
camera_indoor = "material/camera-indoor"
camera_indoor_fill = "material/camera-indoor:fill"
camera_outdoor = "material/camera-outdoor"
camera_outdoor_fill = "material/camera-outdoor:fill"
camera_rear = "material/camera-rear"
camera_rear_fill = "material/camera-rear:fill"
camera_roll = "material/camera-roll"
camera_roll_fill = "material/camera-roll:fill"
camera_video = "material/camera-video"
camera_video_fill = "material/camera-video:fill"
cameraswitch = "material/cameraswitch"
cameraswitch_fill = "material/cameraswitch:fill"
campaign = "material/campaign"
campaign_fill = "material/campaign:fill"
camping = "material/camping"
camping_fill = "material/camping:fill"
cancel = "material/cancel"
cancel_fill = "material/cancel:fill"
cancel_presentation = "material/cancel-presentation"
cancel_presentation_fill = "material/cancel-presentation:fill"
cancel_schedule_send = "material/cancel-schedule-send"
cancel_schedule_send_fill = "material/cancel-schedule-send:fill"
candle = "material/candle"
candle_fill = "material/candle:fill"
candlestick_chart = "material/candlestick-chart"
candlestick_chart_fill = "material/candlestick-chart:fill"
captive_portal = "material/captive-portal"
captive_portal_fill = "material/captive-portal:fill"
capture = "material/capture"
capture_fill = "material/capture:fill"
car_crash = "material/car-crash"
car_crash_fill = "material/car-crash:fill"
car_rental = "material/car-rental"
car_rental_fill = "material/car-rental:fill"
car_repair = "material/car-repair"
car_repair_fill = "material/car-repair:fill"
card_membership = "material/card-membership"
card_membership_fill = "material/card-membership:fill"
card_travel = "material/card-travel"
card_travel_fill = "material/card-travel:fill"
cardiology = "material/cardiology"
cardiology_fill = "material/cardiology:fill"
cards = "material/cards"
cards_fill = "material/cards:fill"
carpenter = "material/carpenter"
carpenter_fill = "material/carpenter:fill"
cases = "material/cases"
cases_fill = "material/cases:fill"
casino = "material/casino"
casino_fill = "material/casino:fill"
cast = "material/cast"
cast_fill = "material/cast:fill"
cast_connected = "material/cast-connected"
cast_connected_fill = "material/cast-connected:fill"
cast_for_education = "material/cast-for-education"
cast_for_education_fill = "material/cast-for-education:fill"
cast_pause = "material/cast-pause"
cast_pause_fill = "material/cast-pause:fill"
cast_warning = "material/cast-warning"
cast_warning_fill = "material/cast-warning:fill"
castle = "material/castle"
castle_fill = "material/castle:fill"
category = "material/category"
category_fill = "material/category:fill"
celebration = "material/celebration"
celebration_fill = "material/celebration:fill"
cell_merge = "material/cell-merge"
cell_merge_fill = "material/cell-merge:fill"
cell_tower = "material/cell-tower"
cell_tower_fill = "material/cell-tower:fill"
cell_wifi = "material/cell-wifi"
cell_wifi_fill = "material/cell-wifi:fill"
center_focus_strong = "material/center-focus-strong"
center_focus_strong_fill = "material/center-focus-strong:fill"
center_focus_weak = "material/center-focus-weak"
center_focus_weak_fill = "material/center-focus-weak:fill"
chair = "material/chair"
chair_fill = "material/chair:fill"
chair_alt = "material/chair-alt"
chair_alt_fill = "material/chair-alt:fill"
chalet = "material/chalet"
chalet_fill = "material/chalet:fill"
change_circle = "material/change-circle"
change_circle_fill = "material/change-circle:fill"
change_history = "material/change-history"
change_history_fill = "material/change-history:fill"
charger = "material/charger"
charger_fill = "material/charger:fill"
charging_station = "material/charging-station"
charging_station_fill = "material/charging-station:fill"
chart_data = "material/chart-data"
chart_data_fill = "material/chart-data:fill"
chat = "material/chat"
chat_fill = "material/chat:fill"
chat_add_on = "material/chat-add-on"
chat_add_on_fill = "material/chat-add-on:fill"
chat_apps_script = "material/chat-apps-script"
chat_apps_script_fill = "material/chat-apps-script:fill"
chat_bubble = "material/chat-bubble"
chat_bubble_fill = "material/chat-bubble:fill"
chat_error = "material/chat-error"
chat_error_fill = "material/chat-error:fill"
chat_paste_go = "material/chat-paste-go"
chat_paste_go_fill = "material/chat-paste-go:fill"
check = "material/check"
check_fill = "material/check:fill"
check_box = "material/check-box"
check_box_fill = "material/check-box:fill"
check_box_outline_blank = "material/check-box-outline-blank"
check_box_outline_blank_fill = "material/check-box-outline-blank:fill"
check_circle = "material/check-circle"
check_circle_fill = "material/check-circle:fill"
check_in_out = "material/check-in-out"
check_in_out_fill = "material/check-in-out:fill"
check_indeterminate_small = "material/check-indeterminate-small"
check_indeterminate_small_fill = "material/check-indeterminate-small:fill"
check_small = "material/check-small"
check_small_fill = "material/check-small:fill"
checklist = "material/checklist"
checklist_fill = "material/checklist:fill"
checklist_rtl = "material/checklist-rtl"
checklist_rtl_fill = "material/checklist-rtl:fill"
checkroom = "material/checkroom"
checkroom_fill = "material/checkroom:fill"
cheer = "material/cheer"
cheer_fill = "material/cheer:fill"
chess = "material/chess"
chess_fill = "material/chess:fill"
chevron_left = "material/chevron-left"
chevron_left_fill = "material/chevron-left:fill"
chevron_right = "material/chevron-right"
chevron_right_fill = "material/chevron-right:fill"
child_care = "material/child-care"
child_care_fill = "material/child-care:fill"
child_friendly = "material/child-friendly"
child_friendly_fill = "material/child-friendly:fill"
chip_extraction = "material/chip-extraction"
chip_extraction_fill = "material/chip-extraction:fill"
chips = "material/chips"
chips_fill = "material/chips:fill"
chrome_reader_mode = "material/chrome-reader-mode"
chrome_reader_mode_fill = "material/chrome-reader-mode:fill"
chromecast_2 = "material/chromecast-2"
chromecast_2_fill = "material/chromecast-2:fill"
chromecast_device = "material/chromecast-device"
chromecast_device_fill = "material/chromecast-device:fill"
chronic = "material/chronic"
chronic_fill = "material/chronic:fill"
church = "material/church"
church_fill = "material/church:fill"
cinematic_blur = "material/cinematic-blur"
cinematic_blur_fill = "material/cinematic-blur:fill"
circle = "material/circle"
circle_fill = "material/circle:fill"
circle_notifications = "material/circle-notifications"
circle_notifications_fill = "material/circle-notifications:fill"
circles = "material/circles"
circles_fill = "material/circles:fill"
circles_ext = "material/circles-ext"
circles_ext_fill = "material/circles-ext:fill"
clarify = "material/clarify"
clarify_fill = "material/clarify:fill"
clean_hands = "material/clean-hands"
clean_hands_fill = "material/clean-hands:fill"
cleaning_bucket = "material/cleaning-bucket"
cleaning_bucket_fill = "material/cleaning-bucket:fill"
cleaning_services = "material/cleaning-services"
cleaning_services_fill = "material/cleaning-services:fill"
clear_all = "material/clear-all"
clear_all_fill = "material/clear-all:fill"
clear_day = "material/clear-day"
clear_day_fill = "material/clear-day:fill"
clear_night = "material/clear-night"
clear_night_fill = "material/clear-night:fill"
climate_mini_split = "material/climate-mini-split"
climate_mini_split_fill = "material/climate-mini-split:fill"
clinical_notes = "material/clinical-notes"
clinical_notes_fill = "material/clinical-notes:fill"
clock_loader_10 = "material/clock-loader-10"
clock_loader_10_fill = "material/clock-loader-10:fill"
clock_loader_20 = "material/clock-loader-20"
clock_loader_20_fill = "material/clock-loader-20:fill"
clock_loader_40 = "material/clock-loader-40"
clock_loader_40_fill = "material/clock-loader-40:fill"
clock_loader_60 = "material/clock-loader-60"
clock_loader_60_fill = "material/clock-loader-60:fill"
clock_loader_80 = "material/clock-loader-80"
clock_loader_80_fill = "material/clock-loader-80:fill"
clock_loader_90 = "material/clock-loader-90"
clock_loader_90_fill = "material/clock-loader-90:fill"
close = "material/close"
close_fill = "material/close:fill"
close_fullscreen = "material/close-fullscreen"
close_fullscreen_fill = "material/close-fullscreen:fill"
closed_caption = "material/closed-caption"
closed_caption_fill = "material/closed-caption:fill"
closed_caption_disabled = "material/closed-caption-disabled"
closed_caption_disabled_fill = "material/closed-caption-disabled:fill"
cloud = "material/cloud"
cloud_fill = "material/cloud:fill"
cloud_circle = "material/cloud-circle"
cloud_circle_fill = "material/cloud-circle:fill"
cloud_done = "material/cloud-done"
cloud_done_fill = "material/cloud-done:fill"
cloud_download = "material/cloud-download"
cloud_download_fill = "material/cloud-download:fill"
cloud_off = "material/cloud-off"
cloud_off_fill = "material/cloud-off:fill"
cloud_sync = "material/cloud-sync"
cloud_sync_fill = "material/cloud-sync:fill"
cloud_upload = "material/cloud-upload"
cloud_upload_fill = "material/cloud-upload:fill"
cloudy_snowing = "material/cloudy-snowing"
cloudy_snowing_fill = "material/cloudy-snowing:fill"
co_present = "material/co-present"
co_present_fill = "material/co-present:fill"
co2 = "material/co2"
co2_fill = "material/co2:fill"
code = "material/code"
code_fill = "material/code:fill"
code_blocks = "material/code-blocks"
code_blocks_fill = "material/code-blocks:fill"
code_off = "material/code-off"
code_off_fill = "material/code-off:fill"
coffee = "material/coffee"
coffee_fill = "material/coffee:fill"
coffee_maker = "material/coffee-maker"
coffee_maker_fill = "material/coffee-maker:fill"
cognition = "material/cognition"
cognition_fill = "material/cognition:fill"
collapse_all = "material/collapse-all"
collapse_all_fill = "material/collapse-all:fill"
collections_bookmark = "material/collections-bookmark"
collections_bookmark_fill = "material/collections-bookmark:fill"
colorize = "material/colorize"
colorize_fill = "material/colorize:fill"
colors = "material/colors"
colors_fill = "material/colors:fill"
comic_bubble = "material/comic-bubble"
comic_bubble_fill = "material/comic-bubble:fill"
comment = "material/comment"
comment_fill = "material/comment:fill"
comment_bank = "material/comment-bank"
comment_bank_fill = "material/comment-bank:fill"
comments_disabled = "material/comments-disabled"
comments_disabled_fill = "material/comments-disabled:fill"
commit = "material/commit"
commit_fill = "material/commit:fill"
communication = "material/communication"
communication_fill = "material/communication:fill"
communities = "material/communities"
communities_fill = "material/communities:fill"
commute = "material/commute"
commute_fill = "material/commute:fill"
compare = "material/compare"
compare_fill = "material/compare:fill"
compare_arrows = "material/compare-arrows"
compare_arrows_fill = "material/compare-arrows:fill"
compass_calibration = "material/compass-calibration"
compass_calibration_fill = "material/compass-calibration:fill"
component_exchange = "material/component-exchange"
component_exchange_fill = "material/component-exchange:fill"
compost = "material/compost"
compost_fill = "material/compost:fill"
compress = "material/compress"
compress_fill = "material/compress:fill"
computer = "material/computer"
computer_fill = "material/computer:fill"
concierge = "material/concierge"
concierge_fill = "material/concierge:fill"
conditions = "material/conditions"
conditions_fill = "material/conditions:fill"
confirmation_number = "material/confirmation-number"
confirmation_number_fill = "material/confirmation-number:fill"
congenital = "material/congenital"
congenital_fill = "material/congenital:fill"
connect_without_contact = "material/connect-without-contact"
connect_without_contact_fill = "material/connect-without-contact:fill"
connected_tv = "material/connected-tv"
connected_tv_fill = "material/connected-tv:fill"
connecting_airports = "material/connecting-airports"
connecting_airports_fill = "material/connecting-airports:fill"
construction = "material/construction"
construction_fill = "material/construction:fill"
contact_emergency = "material/contact-emergency"
contact_emergency_fill = "material/contact-emergency:fill"
contact_mail = "material/contact-mail"
contact_mail_fill = "material/contact-mail:fill"
contact_page = "material/contact-page"
contact_page_fill = "material/contact-page:fill"
contact_phone = "material/contact-phone"
contact_phone_fill = "material/contact-phone:fill"
contact_support = "material/contact-support"
contact_support_fill = "material/contact-support:fill"
contactless = "material/contactless"
contactless_fill = "material/contactless:fill"
contactless_off = "material/contactless-off"
contactless_off_fill = "material/contactless-off:fill"
contacts = "material/contacts"
contacts_fill = "material/contacts:fill"
content_copy = "material/content-copy"
content_copy_fill = "material/content-copy:fill"
content_cut = "material/content-cut"
content_cut_fill = "material/content-cut:fill"
content_paste = "material/content-paste"
content_paste_fill = "material/content-paste:fill"
content_paste_go = "material/content-paste-go"
content_paste_go_fill = "material/content-paste-go:fill"
content_paste_off = "material/content-paste-off"
content_paste_off_fill = "material/content-paste-off:fill"
content_paste_search = "material/content-paste-search"
content_paste_search_fill = "material/content-paste-search:fill"
contract = "material/contract"
contract_fill = "material/contract:fill"
contract_delete = "material/contract-delete"
contract_delete_fill = "material/contract-delete:fill"
contract_edit = "material/contract-edit"
contract_edit_fill = "material/contract-edit:fill"
contrast = "material/contrast"
contrast_fill = "material/contrast:fill"
contrast_rtl_off = "material/contrast-rtl-off"
contrast_rtl_off_fill = "material/contrast-rtl-off:fill"
control_camera = "material/control-camera"
control_camera_fill = "material/control-camera:fill"
control_point_duplicate = "material/control-point-duplicate"
control_point_duplicate_fill = "material/control-point-duplicate:fill"
controller_gen = "material/controller-gen"
controller_gen_fill = "material/controller-gen:fill"
conversion_path = "material/conversion-path"
conversion_path_fill = "material/conversion-path:fill"
conversion_path_off = "material/conversion-path-off"
conversion_path_off_fill = "material/conversion-path-off:fill"
conveyor_belt = "material/conveyor-belt"
conveyor_belt_fill = "material/conveyor-belt:fill"
cookie = "material/cookie"
cookie_fill = "material/cookie:fill"
cookie_off = "material/cookie-off"
cookie_off_fill = "material/cookie-off:fill"
cooking = "material/cooking"
cooking_fill = "material/cooking:fill"
cool_to_dry = "material/cool-to-dry"
cool_to_dry_fill = "material/cool-to-dry:fill"
copy_all = "material/copy-all"
copy_all_fill = "material/copy-all:fill"
copyright = "material/copyright"
copyright_fill = "material/copyright:fill"
coronavirus = "material/coronavirus"
coronavirus_fill = "material/coronavirus:fill"
corporate_fare = "material/corporate-fare"
corporate_fare_fill = "material/corporate-fare:fill"
cottage = "material/cottage"
cottage_fill = "material/cottage:fill"
counter_0 = "material/counter-0"
counter_0_fill = "material/counter-0:fill"
counter_1 = "material/counter-1"
counter_1_fill = "material/counter-1:fill"
counter_2 = "material/counter-2"
counter_2_fill = "material/counter-2:fill"
counter_3 = "material/counter-3"
counter_3_fill = "material/counter-3:fill"
counter_4 = "material/counter-4"
counter_4_fill = "material/counter-4:fill"
counter_5 = "material/counter-5"
counter_5_fill = "material/counter-5:fill"
counter_6 = "material/counter-6"
counter_6_fill = "material/counter-6:fill"
counter_7 = "material/counter-7"
counter_7_fill = "material/counter-7:fill"
counter_8 = "material/counter-8"
counter_8_fill = "material/counter-8:fill"
counter_9 = "material/counter-9"
counter_9_fill = "material/counter-9:fill"
countertops = "material/countertops"
countertops_fill = "material/countertops:fill"
create_new_folder = "material/create-new-folder"
create_new_folder_fill = "material/create-new-folder:fill"
credit_card = "material/credit-card"
credit_card_fill = "material/credit-card:fill"
credit_card_off = "material/credit-card-off"
credit_card_off_fill = "material/credit-card-off:fill"
credit_score = "material/credit-score"
credit_score_fill = "material/credit-score:fill"
crib = "material/crib"
crib_fill = "material/crib:fill"
crisis_alert = "material/crisis-alert"
crisis_alert_fill = "material/crisis-alert:fill"
crop = "material/crop"
crop_fill = "material/crop:fill"
crop_16_9 = "material/crop-16-9"
crop_16_9_fill = "material/crop-16-9:fill"
crop_3_2 = "material/crop-3-2"
crop_3_2_fill = "material/crop-3-2:fill"
crop_5_4 = "material/crop-5-4"
crop_5_4_fill = "material/crop-5-4:fill"
crop_7_5 = "material/crop-7-5"
crop_7_5_fill = "material/crop-7-5:fill"
crop_9_16 = "material/crop-9-16"
crop_9_16_fill = "material/crop-9-16:fill"
crop_free = "material/crop-free"
crop_free_fill = "material/crop-free:fill"
crop_landscape = "material/crop-landscape"
crop_landscape_fill = "material/crop-landscape:fill"
crop_portrait = "material/crop-portrait"
crop_portrait_fill = "material/crop-portrait:fill"
crop_rotate = "material/crop-rotate"
crop_rotate_fill = "material/crop-rotate:fill"
crop_square = "material/crop-square"
crop_square_fill = "material/crop-square:fill"
crossword = "material/crossword"
crossword_fill = "material/crossword:fill"
crowdsource = "material/crowdsource"
crowdsource_fill = "material/crowdsource:fill"
cruelty_free = "material/cruelty-free"
cruelty_free_fill = "material/cruelty-free:fill"
css = "material/css"
css_fill = "material/css:fill"
csv = "material/csv"
csv_fill = "material/csv:fill"
currency_bitcoin = "material/currency-bitcoin"
currency_bitcoin_fill = "material/currency-bitcoin:fill"
currency_exchange = "material/currency-exchange"
currency_exchange_fill = "material/currency-exchange:fill"
currency_franc = "material/currency-franc"
currency_franc_fill = "material/currency-franc:fill"
currency_lira = "material/currency-lira"
currency_lira_fill = "material/currency-lira:fill"
currency_pound = "material/currency-pound"
currency_pound_fill = "material/currency-pound:fill"
currency_ruble = "material/currency-ruble"
currency_ruble_fill = "material/currency-ruble:fill"
currency_rupee = "material/currency-rupee"
currency_rupee_fill = "material/currency-rupee:fill"
currency_yen = "material/currency-yen"
currency_yen_fill = "material/currency-yen:fill"
currency_yuan = "material/currency-yuan"
currency_yuan_fill = "material/currency-yuan:fill"
curtains = "material/curtains"
curtains_fill = "material/curtains:fill"
curtains_closed = "material/curtains-closed"
curtains_closed_fill = "material/curtains-closed:fill"
custom_typography = "material/custom-typography"
custom_typography_fill = "material/custom-typography:fill"
cut = "material/cut"
cut_fill = "material/cut:fill"
cycle = "material/cycle"
cycle_fill = "material/cycle:fill"
cyclone = "material/cyclone"
cyclone_fill = "material/cyclone:fill"
dangerous = "material/dangerous"
dangerous_fill = "material/dangerous:fill"
dark_mode = "material/dark-mode"
dark_mode_fill = "material/dark-mode:fill"
dashboard = "material/dashboard"
dashboard_fill = "material/dashboard:fill"
dashboard_customize = "material/dashboard-customize"
dashboard_customize_fill = "material/dashboard-customize:fill"
data_alert = "material/data-alert"
data_alert_fill = "material/data-alert:fill"
data_array = "material/data-array"
data_array_fill = "material/data-array:fill"
data_check = "material/data-check"
data_check_fill = "material/data-check:fill"
data_exploration = "material/data-exploration"
data_exploration_fill = "material/data-exploration:fill"
data_info_alert = "material/data-info-alert"
data_info_alert_fill = "material/data-info-alert:fill"
data_loss_prevention = "material/data-loss-prevention"
data_loss_prevention_fill = "material/data-loss-prevention:fill"
data_object = "material/data-object"
data_object_fill = "material/data-object:fill"
data_saver_on = "material/data-saver-on"
data_saver_on_fill = "material/data-saver-on:fill"
data_table = "material/data-table"
data_table_fill = "material/data-table:fill"
data_thresholding = "material/data-thresholding"
data_thresholding_fill = "material/data-thresholding:fill"
data_usage = "material/data-usage"
data_usage_fill = "material/data-usage:fill"
database = "material/database"
database_fill = "material/database:fill"
dataset = "material/dataset"
dataset_fill = "material/dataset:fill"
dataset_linked = "material/dataset-linked"
dataset_linked_fill = "material/dataset-linked:fill"
date_range = "material/date-range"
date_range_fill = "material/date-range:fill"
deblur = "material/deblur"
deblur_fill = "material/deblur:fill"
deceased = "material/deceased"
deceased_fill = "material/deceased:fill"
decimal_decrease = "material/decimal-decrease"
decimal_decrease_fill = "material/decimal-decrease:fill"
decimal_increase = "material/decimal-increase"
decimal_increase_fill = "material/decimal-increase:fill"
deck = "material/deck"
deck_fill = "material/deck:fill"
dehaze = "material/dehaze"
dehaze_fill = "material/dehaze:fill"
delete = "material/delete"
delete_fill = "material/delete:fill"
delete_forever = "material/delete-forever"
delete_forever_fill = "material/delete-forever:fill"
delete_sweep = "material/delete-sweep"
delete_sweep_fill = "material/delete-sweep:fill"
demography = "material/demography"
demography_fill = "material/demography:fill"
density_large = "material/density-large"
density_large_fill = "material/density-large:fill"
density_medium = "material/density-medium"
density_medium_fill = "material/density-medium:fill"
density_small = "material/density-small"
density_small_fill = "material/density-small:fill"
dentistry = "material/dentistry"
dentistry_fill = "material/dentistry:fill"
departure_board = "material/departure-board"
departure_board_fill = "material/departure-board:fill"
deployed_code = "material/deployed-code"
deployed_code_fill = "material/deployed-code:fill"
deployed_code_alert = "material/deployed-code-alert"
deployed_code_alert_fill = "material/deployed-code-alert:fill"
deployed_code_history = "material/deployed-code-history"
deployed_code_history_fill = "material/deployed-code-history:fill"
deployed_code_update = "material/deployed-code-update"
deployed_code_update_fill = "material/deployed-code-update:fill"
dermatology = "material/dermatology"
dermatology_fill = "material/dermatology:fill"
description = "material/description"
description_fill = "material/description:fill"
deselect = "material/deselect"
deselect_fill = "material/deselect:fill"
design_services = "material/design-services"
design_services_fill = "material/design-services:fill"
desk = "material/desk"
desk_fill = "material/desk:fill"
deskphone = "material/deskphone"
deskphone_fill = "material/deskphone:fill"
desktop_access_disabled = "material/desktop-access-disabled"
desktop_access_disabled_fill = "material/desktop-access-disabled:fill"
desktop_mac = "material/desktop-mac"
desktop_mac_fill = "material/desktop-mac:fill"
desktop_windows = "material/desktop-windows"
desktop_windows_fill = "material/desktop-windows:fill"
destruction = "material/destruction"
destruction_fill = "material/destruction:fill"
details = "material/details"
details_fill = "material/details:fill"
detection_and_zone = "material/detection-and-zone"
detection_and_zone_fill = "material/detection-and-zone:fill"
detector = "material/detector"
detector_fill = "material/detector:fill"
detector_alarm = "material/detector-alarm"
detector_alarm_fill = "material/detector-alarm:fill"
detector_battery = "material/detector-battery"
detector_battery_fill = "material/detector-battery:fill"
detector_co = "material/detector-co"
detector_co_fill = "material/detector-co:fill"
detector_offline = "material/detector-offline"
detector_offline_fill = "material/detector-offline:fill"
detector_smoke = "material/detector-smoke"
detector_smoke_fill = "material/detector-smoke:fill"
detector_status = "material/detector-status"
detector_status_fill = "material/detector-status:fill"
developer_board = "material/developer-board"
developer_board_fill = "material/developer-board:fill"
developer_board_off = "material/developer-board-off"
developer_board_off_fill = "material/developer-board-off:fill"
developer_guide = "material/developer-guide"
developer_guide_fill = "material/developer-guide:fill"
developer_mode = "material/developer-mode"
developer_mode_fill = "material/developer-mode:fill"
developer_mode_tv = "material/developer-mode-tv"
developer_mode_tv_fill = "material/developer-mode-tv:fill"
device_hub = "material/device-hub"
device_hub_fill = "material/device-hub:fill"
device_reset = "material/device-reset"
device_reset_fill = "material/device-reset:fill"
device_thermostat = "material/device-thermostat"
device_thermostat_fill = "material/device-thermostat:fill"
device_unknown = "material/device-unknown"
device_unknown_fill = "material/device-unknown:fill"
devices = "material/devices"
devices_fill = "material/devices:fill"
devices_fold = "material/devices-fold"
devices_fold_fill = "material/devices-fold:fill"
devices_off = "material/devices-off"
devices_off_fill = "material/devices-off:fill"
devices_other = "material/devices-other"
devices_other_fill = "material/devices-other:fill"
devices_wearables = "material/devices-wearables"
devices_wearables_fill = "material/devices-wearables:fill"
dew_point = "material/dew-point"
dew_point_fill = "material/dew-point:fill"
diagnosis = "material/diagnosis"
diagnosis_fill = "material/diagnosis:fill"
dialer_sip = "material/dialer-sip"
dialer_sip_fill = "material/dialer-sip:fill"
dialogs = "material/dialogs"
dialogs_fill = "material/dialogs:fill"
dialpad = "material/dialpad"
dialpad_fill = "material/dialpad:fill"
diamond = "material/diamond"
diamond_fill = "material/diamond:fill"
difference = "material/difference"
difference_fill = "material/difference:fill"
digital_out_of_home = "material/digital-out-of-home"
digital_out_of_home_fill = "material/digital-out-of-home:fill"
dining = "material/dining"
dining_fill = "material/dining:fill"
dinner_dining = "material/dinner-dining"
dinner_dining_fill = "material/dinner-dining:fill"
directions = "material/directions"
directions_fill = "material/directions:fill"
directions_alt = "material/directions-alt"
directions_alt_fill = "material/directions-alt:fill"
directions_alt_off = "material/directions-alt-off"
directions_alt_off_fill = "material/directions-alt-off:fill"
directions_bike = "material/directions-bike"
directions_bike_fill = "material/directions-bike:fill"
directions_boat = "material/directions-boat"
directions_boat_fill = "material/directions-boat:fill"
directions_bus = "material/directions-bus"
directions_bus_fill = "material/directions-bus:fill"
directions_car = "material/directions-car"
directions_car_fill = "material/directions-car:fill"
directions_off = "material/directions-off"
directions_off_fill = "material/directions-off:fill"
directions_railway = "material/directions-railway"
directions_railway_fill = "material/directions-railway:fill"
directions_run = "material/directions-run"
directions_run_fill = "material/directions-run:fill"
directions_subway = "material/directions-subway"
directions_subway_fill = "material/directions-subway:fill"
directions_walk = "material/directions-walk"
directions_walk_fill = "material/directions-walk:fill"
directory_sync = "material/directory-sync"
directory_sync_fill = "material/directory-sync:fill"
dirty_lens = "material/dirty-lens"
dirty_lens_fill = "material/dirty-lens:fill"
disabled_by_default = "material/disabled-by-default"
disabled_by_default_fill = "material/disabled-by-default:fill"
disabled_visible = "material/disabled-visible"
disabled_visible_fill = "material/disabled-visible:fill"
disc_full = "material/disc-full"
disc_full_fill = "material/disc-full:fill"
discover_tune = "material/discover-tune"
discover_tune_fill = "material/discover-tune:fill"
dishwasher_gen = "material/dishwasher-gen"
dishwasher_gen_fill = "material/dishwasher-gen:fill"
display_external_input = "material/display-external-input"
display_external_input_fill = "material/display-external-input:fill"
display_settings = "material/display-settings"
display_settings_fill = "material/display-settings:fill"
distance = "material/distance"
distance_fill = "material/distance:fill"
diversity_1 = "material/diversity-1"
diversity_1_fill = "material/diversity-1:fill"
diversity_2 = "material/diversity-2"
diversity_2_fill = "material/diversity-2:fill"
diversity_3 = "material/diversity-3"
diversity_3_fill = "material/diversity-3:fill"
diversity_4 = "material/diversity-4"
diversity_4_fill = "material/diversity-4:fill"
dns = "material/dns"
dns_fill = "material/dns:fill"
do_not_disturb_off = "material/do-not-disturb-off"
do_not_disturb_off_fill = "material/do-not-disturb-off:fill"
do_not_disturb_on = "material/do-not-disturb-on"
do_not_disturb_on_fill = "material/do-not-disturb-on:fill"
do_not_disturb_on_total_silence = "material/do-not-disturb-on-total-silence"
do_not_disturb_on_total_silence_fill = (
    "material/do-not-disturb-on-total-silence:fill"
)
do_not_step = "material/do-not-step"
do_not_step_fill = "material/do-not-step:fill"
do_not_touch = "material/do-not-touch"
do_not_touch_fill = "material/do-not-touch:fill"
dock = "material/dock"
dock_fill = "material/dock:fill"
dock_to_bottom = "material/dock-to-bottom"
dock_to_bottom_fill = "material/dock-to-bottom:fill"
dock_to_left = "material/dock-to-left"
dock_to_left_fill = "material/dock-to-left:fill"
dock_to_right = "material/dock-to-right"
dock_to_right_fill = "material/dock-to-right:fill"
docs_add_on = "material/docs-add-on"
docs_add_on_fill = "material/docs-add-on:fill"
docs_apps_script = "material/docs-apps-script"
docs_apps_script_fill = "material/docs-apps-script:fill"
document_scanner = "material/document-scanner"
document_scanner_fill = "material/document-scanner:fill"
domain = "material/domain"
domain_fill = "material/domain:fill"
domain_add = "material/domain-add"
domain_add_fill = "material/domain-add:fill"
domain_disabled = "material/domain-disabled"
domain_disabled_fill = "material/domain-disabled:fill"
domain_verification = "material/domain-verification"
domain_verification_fill = "material/domain-verification:fill"
domain_verification_off = "material/domain-verification-off"
domain_verification_off_fill = "material/domain-verification-off:fill"
domino_mask = "material/domino-mask"
domino_mask_fill = "material/domino-mask:fill"
done = "material/done"
done_fill = "material/done:fill"
done_all = "material/done-all"
done_all_fill = "material/done-all:fill"
done_outline = "material/done-outline"
done_outline_fill = "material/done-outline:fill"
donut_large = "material/donut-large"
donut_large_fill = "material/donut-large:fill"
donut_small = "material/donut-small"
donut_small_fill = "material/donut-small:fill"
door_back = "material/door-back"
door_back_fill = "material/door-back:fill"
door_front = "material/door-front"
door_front_fill = "material/door-front:fill"
door_open = "material/door-open"
door_open_fill = "material/door-open:fill"
door_sensor = "material/door-sensor"
door_sensor_fill = "material/door-sensor:fill"
door_sliding = "material/door-sliding"
door_sliding_fill = "material/door-sliding:fill"
doorbell = "material/doorbell"
doorbell_fill = "material/doorbell:fill"
doorbell_3p = "material/doorbell-3p"
doorbell_3p_fill = "material/doorbell-3p:fill"
doorbell_chime = "material/doorbell-chime"
doorbell_chime_fill = "material/doorbell-chime:fill"
double_arrow = "material/double-arrow"
double_arrow_fill = "material/double-arrow:fill"
downhill_skiing = "material/downhill-skiing"
downhill_skiing_fill = "material/downhill-skiing:fill"
download = "material/download"
download_fill = "material/download:fill"
download_done = "material/download-done"
download_done_fill = "material/download-done:fill"
download_for_offline = "material/download-for-offline"
download_for_offline_fill = "material/download-for-offline:fill"
downloading = "material/downloading"
downloading_fill = "material/downloading:fill"
draft = "material/draft"
draft_fill = "material/draft:fill"
draft_orders = "material/draft-orders"
draft_orders_fill = "material/draft-orders:fill"
drafts = "material/drafts"
drafts_fill = "material/drafts:fill"
drag_click = "material/drag-click"
drag_click_fill = "material/drag-click:fill"
drag_handle = "material/drag-handle"
drag_handle_fill = "material/drag-handle:fill"
drag_indicator = "material/drag-indicator"
drag_indicator_fill = "material/drag-indicator:fill"
drag_pan = "material/drag-pan"
drag_pan_fill = "material/drag-pan:fill"
draw = "material/draw"
draw_fill = "material/draw:fill"
draw_abstract = "material/draw-abstract"
draw_abstract_fill = "material/draw-abstract:fill"
draw_collage = "material/draw-collage"
draw_collage_fill = "material/draw-collage:fill"
dresser = "material/dresser"
dresser_fill = "material/dresser:fill"
drive_file_move = "material/drive-file-move"
drive_file_move_fill = "material/drive-file-move:fill"
drive_folder_upload = "material/drive-folder-upload"
drive_folder_upload_fill = "material/drive-folder-upload:fill"
dropdown = "material/dropdown"
dropdown_fill = "material/dropdown:fill"
dry = "material/dry"
dry_fill = "material/dry:fill"
dry_cleaning = "material/dry-cleaning"
dry_cleaning_fill = "material/dry-cleaning:fill"
dual_screen = "material/dual-screen"
dual_screen_fill = "material/dual-screen:fill"
duo = "material/duo"
duo_fill = "material/duo:fill"
dvr = "material/dvr"
dvr_fill = "material/dvr:fill"
dynamic_feed = "material/dynamic-feed"
dynamic_feed_fill = "material/dynamic-feed:fill"
dynamic_form = "material/dynamic-form"
dynamic_form_fill = "material/dynamic-form:fill"
e_mobiledata = "material/e-mobiledata"
e_mobiledata_fill = "material/e-mobiledata:fill"
e_mobiledata_badge = "material/e-mobiledata-badge"
e_mobiledata_badge_fill = "material/e-mobiledata-badge:fill"
e911_avatar = "material/e911-avatar"
e911_avatar_fill = "material/e911-avatar:fill"
e911_emergency = "material/e911-emergency"
e911_emergency_fill = "material/e911-emergency:fill"
earbuds = "material/earbuds"
earbuds_fill = "material/earbuds:fill"
earbuds_battery = "material/earbuds-battery"
earbuds_battery_fill = "material/earbuds-battery:fill"
early_on = "material/early-on"
early_on_fill = "material/early-on:fill"
earthquake = "material/earthquake"
earthquake_fill = "material/earthquake:fill"
east = "material/east"
east_fill = "material/east:fill"
ecg = "material/ecg"
ecg_fill = "material/ecg:fill"
ecg_heart = "material/ecg-heart"
ecg_heart_fill = "material/ecg-heart:fill"
eco = "material/eco"
eco_fill = "material/eco:fill"
eda = "material/eda"
eda_fill = "material/eda:fill"
edgesensor_high = "material/edgesensor-high"
edgesensor_high_fill = "material/edgesensor-high:fill"
edgesensor_low = "material/edgesensor-low"
edgesensor_low_fill = "material/edgesensor-low:fill"
edit = "material/edit"
edit_fill = "material/edit:fill"
edit_attributes = "material/edit-attributes"
edit_attributes_fill = "material/edit-attributes:fill"
edit_calendar = "material/edit-calendar"
edit_calendar_fill = "material/edit-calendar:fill"
edit_document = "material/edit-document"
edit_document_fill = "material/edit-document:fill"
edit_location = "material/edit-location"
edit_location_fill = "material/edit-location:fill"
edit_location_alt = "material/edit-location-alt"
edit_location_alt_fill = "material/edit-location-alt:fill"
edit_note = "material/edit-note"
edit_note_fill = "material/edit-note:fill"
edit_notifications = "material/edit-notifications"
edit_notifications_fill = "material/edit-notifications:fill"
edit_off = "material/edit-off"
edit_off_fill = "material/edit-off:fill"
edit_road = "material/edit-road"
edit_road_fill = "material/edit-road:fill"
edit_square = "material/edit-square"
edit_square_fill = "material/edit-square:fill"
egg = "material/egg"
egg_fill = "material/egg:fill"
egg_alt = "material/egg-alt"
egg_alt_fill = "material/egg-alt:fill"
eject = "material/eject"
eject_fill = "material/eject:fill"
elderly = "material/elderly"
elderly_fill = "material/elderly:fill"
elderly_woman = "material/elderly-woman"
elderly_woman_fill = "material/elderly-woman:fill"
electric_bike = "material/electric-bike"
electric_bike_fill = "material/electric-bike:fill"
electric_bolt = "material/electric-bolt"
electric_bolt_fill = "material/electric-bolt:fill"
electric_car = "material/electric-car"
electric_car_fill = "material/electric-car:fill"
electric_meter = "material/electric-meter"
electric_meter_fill = "material/electric-meter:fill"
electric_moped = "material/electric-moped"
electric_moped_fill = "material/electric-moped:fill"
electric_rickshaw = "material/electric-rickshaw"
electric_rickshaw_fill = "material/electric-rickshaw:fill"
electric_scooter = "material/electric-scooter"
electric_scooter_fill = "material/electric-scooter:fill"
electrical_services = "material/electrical-services"
electrical_services_fill = "material/electrical-services:fill"
elevation = "material/elevation"
elevation_fill = "material/elevation:fill"
elevator = "material/elevator"
elevator_fill = "material/elevator:fill"
emergency = "material/emergency"
emergency_fill = "material/emergency:fill"
emergency_heat = "material/emergency-heat"
emergency_heat_fill = "material/emergency-heat:fill"
emergency_home = "material/emergency-home"
emergency_home_fill = "material/emergency-home:fill"
emergency_recording = "material/emergency-recording"
emergency_recording_fill = "material/emergency-recording:fill"
emergency_share = "material/emergency-share"
emergency_share_fill = "material/emergency-share:fill"
emergency_share_off = "material/emergency-share-off"
emergency_share_off_fill = "material/emergency-share-off:fill"
emoji_events = "material/emoji-events"
emoji_events_fill = "material/emoji-events:fill"
emoji_flags = "material/emoji-flags"
emoji_flags_fill = "material/emoji-flags:fill"
emoji_food_beverage = "material/emoji-food-beverage"
emoji_food_beverage_fill = "material/emoji-food-beverage:fill"
emoji_nature = "material/emoji-nature"
emoji_nature_fill = "material/emoji-nature:fill"
emoji_objects = "material/emoji-objects"
emoji_objects_fill = "material/emoji-objects:fill"
emoji_people = "material/emoji-people"
emoji_people_fill = "material/emoji-people:fill"
emoji_symbols = "material/emoji-symbols"
emoji_symbols_fill = "material/emoji-symbols:fill"
emoji_transportation = "material/emoji-transportation"
emoji_transportation_fill = "material/emoji-transportation:fill"
emoticon = "material/emoticon"
emoticon_fill = "material/emoticon:fill"
empty_dashboard = "material/empty-dashboard"
empty_dashboard_fill = "material/empty-dashboard:fill"
enable = "material/enable"
enable_fill = "material/enable:fill"
encrypted = "material/encrypted"
encrypted_fill = "material/encrypted:fill"
endocrinology = "material/endocrinology"
endocrinology_fill = "material/endocrinology:fill"
energy_program_saving = "material/energy-program-saving"
energy_program_saving_fill = "material/energy-program-saving:fill"
energy_program_time_used = "material/energy-program-time-used"
energy_program_time_used_fill = "material/energy-program-time-used:fill"
energy_savings_leaf = "material/energy-savings-leaf"
energy_savings_leaf_fill = "material/energy-savings-leaf:fill"
engineering = "material/engineering"
engineering_fill = "material/engineering:fill"
enhanced_encryption = "material/enhanced-encryption"
enhanced_encryption_fill = "material/enhanced-encryption:fill"
ent = "material/ent"
ent_fill = "material/ent:fill"
equal = "material/equal"
equal_fill = "material/equal:fill"
equalizer = "material/equalizer"
equalizer_fill = "material/equalizer:fill"
error = "material/error"
error_fill = "material/error:fill"
error_med = "material/error-med"
error_med_fill = "material/error-med:fill"
escalator = "material/escalator"
escalator_fill = "material/escalator:fill"
escalator_warning = "material/escalator-warning"
escalator_warning_fill = "material/escalator-warning:fill"
euro = "material/euro"
euro_fill = "material/euro:fill"
euro_symbol = "material/euro-symbol"
euro_symbol_fill = "material/euro-symbol:fill"
ev_charger = "material/ev-charger"
ev_charger_fill = "material/ev-charger:fill"
ev_mobiledata_badge = "material/ev-mobiledata-badge"
ev_mobiledata_badge_fill = "material/ev-mobiledata-badge:fill"
ev_shadow = "material/ev-shadow"
ev_shadow_fill = "material/ev-shadow:fill"
ev_shadow_add = "material/ev-shadow-add"
ev_shadow_add_fill = "material/ev-shadow-add:fill"
ev_shadow_minus = "material/ev-shadow-minus"
ev_shadow_minus_fill = "material/ev-shadow-minus:fill"
ev_station = "material/ev-station"
ev_station_fill = "material/ev-station:fill"
event = "material/event"
event_fill = "material/event:fill"
event_available = "material/event-available"
event_available_fill = "material/event-available:fill"
event_busy = "material/event-busy"
event_busy_fill = "material/event-busy:fill"
event_list = "material/event-list"
event_list_fill = "material/event-list:fill"
event_note = "material/event-note"
event_note_fill = "material/event-note:fill"
event_repeat = "material/event-repeat"
event_repeat_fill = "material/event-repeat:fill"
event_seat = "material/event-seat"
event_seat_fill = "material/event-seat:fill"
event_upcoming = "material/event-upcoming"
event_upcoming_fill = "material/event-upcoming:fill"
exclamation = "material/exclamation"
exclamation_fill = "material/exclamation:fill"
exercise = "material/exercise"
exercise_fill = "material/exercise:fill"
exit_to_app = "material/exit-to-app"
exit_to_app_fill = "material/exit-to-app:fill"
expand = "material/expand"
expand_fill = "material/expand:fill"
expand_all = "material/expand-all"
expand_all_fill = "material/expand-all:fill"
expand_circle_down = "material/expand-circle-down"
expand_circle_down_fill = "material/expand-circle-down:fill"
expand_circle_right = "material/expand-circle-right"
expand_circle_right_fill = "material/expand-circle-right:fill"
expand_circle_up = "material/expand-circle-up"
expand_circle_up_fill = "material/expand-circle-up:fill"
expand_content = "material/expand-content"
expand_content_fill = "material/expand-content:fill"
expand_less = "material/expand-less"
expand_less_fill = "material/expand-less:fill"
expand_more = "material/expand-more"
expand_more_fill = "material/expand-more:fill"
explicit = "material/explicit"
explicit_fill = "material/explicit:fill"
explore = "material/explore"
explore_fill = "material/explore:fill"
explore_off = "material/explore-off"
explore_off_fill = "material/explore-off:fill"
explosion = "material/explosion"
explosion_fill = "material/explosion:fill"
export_notes = "material/export-notes"
export_notes_fill = "material/export-notes:fill"
exposure = "material/exposure"
exposure_fill = "material/exposure:fill"
exposure_neg_1 = "material/exposure-neg-1"
exposure_neg_1_fill = "material/exposure-neg-1:fill"
exposure_neg_2 = "material/exposure-neg-2"
exposure_neg_2_fill = "material/exposure-neg-2:fill"
exposure_plus_1 = "material/exposure-plus-1"
exposure_plus_1_fill = "material/exposure-plus-1:fill"
exposure_plus_2 = "material/exposure-plus-2"
exposure_plus_2_fill = "material/exposure-plus-2:fill"
exposure_zero = "material/exposure-zero"
exposure_zero_fill = "material/exposure-zero:fill"
extension = "material/extension"
extension_fill = "material/extension:fill"
extension_off = "material/extension-off"
extension_off_fill = "material/extension-off:fill"
eyeglasses = "material/eyeglasses"
eyeglasses_fill = "material/eyeglasses:fill"
face = "material/face"
face_fill = "material/face:fill"
face_2 = "material/face-2"
face_2_fill = "material/face-2:fill"
face_3 = "material/face-3"
face_3_fill = "material/face-3:fill"
face_4 = "material/face-4"
face_4_fill = "material/face-4:fill"
face_5 = "material/face-5"
face_5_fill = "material/face-5:fill"
face_6 = "material/face-6"
face_6_fill = "material/face-6:fill"
face_retouching_off = "material/face-retouching-off"
face_retouching_off_fill = "material/face-retouching-off:fill"
fact_check = "material/fact-check"
fact_check_fill = "material/fact-check:fill"
factory = "material/factory"
factory_fill = "material/factory:fill"
falling = "material/falling"
falling_fill = "material/falling:fill"
familiar_face_and_zone = "material/familiar-face-and-zone"
familiar_face_and_zone_fill = "material/familiar-face-and-zone:fill"
family_history = "material/family-history"
family_history_fill = "material/family-history:fill"
family_link = "material/family-link"
family_link_fill = "material/family-link:fill"
family_restroom = "material/family-restroom"
family_restroom_fill = "material/family-restroom:fill"
farsight_digital = "material/farsight-digital"
farsight_digital_fill = "material/farsight-digital:fill"
fast_forward = "material/fast-forward"
fast_forward_fill = "material/fast-forward:fill"
fast_rewind = "material/fast-rewind"
fast_rewind_fill = "material/fast-rewind:fill"
fastfood = "material/fastfood"
fastfood_fill = "material/fastfood:fill"
faucet = "material/faucet"
faucet_fill = "material/faucet:fill"
favorite = "material/favorite"
favorite_fill = "material/favorite:fill"
fax = "material/fax"
fax_fill = "material/fax:fill"
feature_search = "material/feature-search"
feature_search_fill = "material/feature-search:fill"
featured_play_list = "material/featured-play-list"
featured_play_list_fill = "material/featured-play-list:fill"
featured_video = "material/featured-video"
featured_video_fill = "material/featured-video:fill"
feed = "material/feed"
feed_fill = "material/feed:fill"
feedback = "material/feedback"
feedback_fill = "material/feedback:fill"
female = "material/female"
female_fill = "material/female:fill"
femur = "material/femur"
femur_fill = "material/femur:fill"
femur_alt = "material/femur-alt"
femur_alt_fill = "material/femur-alt:fill"
fence = "material/fence"
fence_fill = "material/fence:fill"
fertile = "material/fertile"
fertile_fill = "material/fertile:fill"
festival = "material/festival"
festival_fill = "material/festival:fill"
fiber_dvr = "material/fiber-dvr"
fiber_dvr_fill = "material/fiber-dvr:fill"
fiber_manual_record = "material/fiber-manual-record"
fiber_manual_record_fill = "material/fiber-manual-record:fill"
fiber_new = "material/fiber-new"
fiber_new_fill = "material/fiber-new:fill"
fiber_pin = "material/fiber-pin"
fiber_pin_fill = "material/fiber-pin:fill"
fiber_smart_record = "material/fiber-smart-record"
fiber_smart_record_fill = "material/fiber-smart-record:fill"
file_copy = "material/file-copy"
file_copy_fill = "material/file-copy:fill"
file_download_done = "material/file-download-done"
file_download_done_fill = "material/file-download-done:fill"
file_download_off = "material/file-download-off"
file_download_off_fill = "material/file-download-off:fill"
file_open = "material/file-open"
file_open_fill = "material/file-open:fill"
file_present = "material/file-present"
file_present_fill = "material/file-present:fill"
file_upload_off = "material/file-upload-off"
file_upload_off_fill = "material/file-upload-off:fill"
filter = "material/filter"
filter_fill = "material/filter:fill"
filter_1 = "material/filter-1"
filter_1_fill = "material/filter-1:fill"
filter_2 = "material/filter-2"
filter_2_fill = "material/filter-2:fill"
filter_3 = "material/filter-3"
filter_3_fill = "material/filter-3:fill"
filter_4 = "material/filter-4"
filter_4_fill = "material/filter-4:fill"
filter_5 = "material/filter-5"
filter_5_fill = "material/filter-5:fill"
filter_6 = "material/filter-6"
filter_6_fill = "material/filter-6:fill"
filter_7 = "material/filter-7"
filter_7_fill = "material/filter-7:fill"
filter_8 = "material/filter-8"
filter_8_fill = "material/filter-8:fill"
filter_9 = "material/filter-9"
filter_9_fill = "material/filter-9:fill"
filter_9_plus = "material/filter-9-plus"
filter_9_plus_fill = "material/filter-9-plus:fill"
filter_alt = "material/filter-alt"
filter_alt_fill = "material/filter-alt:fill"
filter_alt_off = "material/filter-alt-off"
filter_alt_off_fill = "material/filter-alt-off:fill"
filter_b_and_w = "material/filter-b-and-w"
filter_b_and_w_fill = "material/filter-b-and-w:fill"
filter_center_focus = "material/filter-center-focus"
filter_center_focus_fill = "material/filter-center-focus:fill"
filter_drama = "material/filter-drama"
filter_drama_fill = "material/filter-drama:fill"
filter_frames = "material/filter-frames"
filter_frames_fill = "material/filter-frames:fill"
filter_hdr = "material/filter-hdr"
filter_hdr_fill = "material/filter-hdr:fill"
filter_list = "material/filter-list"
filter_list_fill = "material/filter-list:fill"
filter_list_off = "material/filter-list-off"
filter_list_off_fill = "material/filter-list-off:fill"
filter_none = "material/filter-none"
filter_none_fill = "material/filter-none:fill"
filter_tilt_shift = "material/filter-tilt-shift"
filter_tilt_shift_fill = "material/filter-tilt-shift:fill"
filter_vintage = "material/filter-vintage"
filter_vintage_fill = "material/filter-vintage:fill"
finance = "material/finance"
finance_fill = "material/finance:fill"
finance_chip = "material/finance-chip"
finance_chip_fill = "material/finance-chip:fill"
find_in_page = "material/find-in-page"
find_in_page_fill = "material/find-in-page:fill"
find_replace = "material/find-replace"
find_replace_fill = "material/find-replace:fill"
fingerprint = "material/fingerprint"
fingerprint_fill = "material/fingerprint:fill"
fire_extinguisher = "material/fire-extinguisher"
fire_extinguisher_fill = "material/fire-extinguisher:fill"
fire_hydrant = "material/fire-hydrant"
fire_hydrant_fill = "material/fire-hydrant:fill"
fire_truck = "material/fire-truck"
fire_truck_fill = "material/fire-truck:fill"
fireplace = "material/fireplace"
fireplace_fill = "material/fireplace:fill"
first_page = "material/first-page"
first_page_fill = "material/first-page:fill"
fit_page = "material/fit-page"
fit_page_fill = "material/fit-page:fill"
fit_screen = "material/fit-screen"
fit_screen_fill = "material/fit-screen:fill"
fit_width = "material/fit-width"
fit_width_fill = "material/fit-width:fill"
fitness_center = "material/fitness-center"
fitness_center_fill = "material/fitness-center:fill"
flag = "material/flag"
flag_fill = "material/flag:fill"
flag_circle = "material/flag-circle"
flag_circle_fill = "material/flag-circle:fill"
flaky = "material/flaky"
flaky_fill = "material/flaky:fill"
flare = "material/flare"
flare_fill = "material/flare:fill"
flash_auto = "material/flash-auto"
flash_auto_fill = "material/flash-auto:fill"
flash_off = "material/flash-off"
flash_off_fill = "material/flash-off:fill"
flash_on = "material/flash-on"
flash_on_fill = "material/flash-on:fill"
flashlight_off = "material/flashlight-off"
flashlight_off_fill = "material/flashlight-off:fill"
flashlight_on = "material/flashlight-on"
flashlight_on_fill = "material/flashlight-on:fill"
flatware = "material/flatware"
flatware_fill = "material/flatware:fill"
flex_direction = "material/flex-direction"
flex_direction_fill = "material/flex-direction:fill"
flex_no_wrap = "material/flex-no-wrap"
flex_no_wrap_fill = "material/flex-no-wrap:fill"
flex_wrap = "material/flex-wrap"
flex_wrap_fill = "material/flex-wrap:fill"
flight = "material/flight"
flight_fill = "material/flight:fill"
flight_class = "material/flight-class"
flight_class_fill = "material/flight-class:fill"
flight_land = "material/flight-land"
flight_land_fill = "material/flight-land:fill"
flight_takeoff = "material/flight-takeoff"
flight_takeoff_fill = "material/flight-takeoff:fill"
flightsmode = "material/flightsmode"
flightsmode_fill = "material/flightsmode:fill"
flip = "material/flip"
flip_fill = "material/flip:fill"
flip_camera_android = "material/flip-camera-android"
flip_camera_android_fill = "material/flip-camera-android:fill"
flip_camera_ios = "material/flip-camera-ios"
flip_camera_ios_fill = "material/flip-camera-ios:fill"
flip_to_back = "material/flip-to-back"
flip_to_back_fill = "material/flip-to-back:fill"
flip_to_front = "material/flip-to-front"
flip_to_front_fill = "material/flip-to-front:fill"
flood = "material/flood"
flood_fill = "material/flood:fill"
floor = "material/floor"
floor_fill = "material/floor:fill"
floor_lamp = "material/floor-lamp"
floor_lamp_fill = "material/floor-lamp:fill"
flowsheet = "material/flowsheet"
flowsheet_fill = "material/flowsheet:fill"
fluid = "material/fluid"
fluid_fill = "material/fluid:fill"
fluid_balance = "material/fluid-balance"
fluid_balance_fill = "material/fluid-balance:fill"
fluid_med = "material/fluid-med"
fluid_med_fill = "material/fluid-med:fill"
fluorescent = "material/fluorescent"
fluorescent_fill = "material/fluorescent:fill"
flutter = "material/flutter"
flutter_fill = "material/flutter:fill"
flutter_dash = "material/flutter-dash"
flutter_dash_fill = "material/flutter-dash:fill"
fmd_bad = "material/fmd-bad"
fmd_bad_fill = "material/fmd-bad:fill"
foggy = "material/foggy"
foggy_fill = "material/foggy:fill"
folded_hands = "material/folded-hands"
folded_hands_fill = "material/folded-hands:fill"
folder = "material/folder"
folder_fill = "material/folder:fill"
folder_copy = "material/folder-copy"
folder_copy_fill = "material/folder-copy:fill"
folder_data = "material/folder-data"
folder_data_fill = "material/folder-data:fill"
folder_delete = "material/folder-delete"
folder_delete_fill = "material/folder-delete:fill"
folder_managed = "material/folder-managed"
folder_managed_fill = "material/folder-managed:fill"
folder_off = "material/folder-off"
folder_off_fill = "material/folder-off:fill"
folder_open = "material/folder-open"
folder_open_fill = "material/folder-open:fill"
folder_shared = "material/folder-shared"
folder_shared_fill = "material/folder-shared:fill"
folder_special = "material/folder-special"
folder_special_fill = "material/folder-special:fill"
folder_supervised = "material/folder-supervised"
folder_supervised_fill = "material/folder-supervised:fill"
folder_zip = "material/folder-zip"
folder_zip_fill = "material/folder-zip:fill"
follow_the_signs = "material/follow-the-signs"
follow_the_signs_fill = "material/follow-the-signs:fill"
font_download = "material/font-download"
font_download_fill = "material/font-download:fill"
font_download_off = "material/font-download-off"
font_download_off_fill = "material/font-download-off:fill"
food_bank = "material/food-bank"
food_bank_fill = "material/food-bank:fill"
foot_bones = "material/foot-bones"
foot_bones_fill = "material/foot-bones:fill"
footprint = "material/footprint"
footprint_fill = "material/footprint:fill"
forest = "material/forest"
forest_fill = "material/forest:fill"
fork_left = "material/fork-left"
fork_left_fill = "material/fork-left:fill"
fork_right = "material/fork-right"
fork_right_fill = "material/fork-right:fill"
forklift = "material/forklift"
forklift_fill = "material/forklift:fill"
format_align_center = "material/format-align-center"
format_align_center_fill = "material/format-align-center:fill"
format_align_justify = "material/format-align-justify"
format_align_justify_fill = "material/format-align-justify:fill"
format_align_left = "material/format-align-left"
format_align_left_fill = "material/format-align-left:fill"
format_align_right = "material/format-align-right"
format_align_right_fill = "material/format-align-right:fill"
format_bold = "material/format-bold"
format_bold_fill = "material/format-bold:fill"
format_clear = "material/format-clear"
format_clear_fill = "material/format-clear:fill"
format_color_fill = "material/format-color:fill"
format_color_fill_fill = "material/format-color-fill:fill"
format_color_reset = "material/format-color-reset"
format_color_reset_fill = "material/format-color-reset:fill"
format_color_text = "material/format-color-text"
format_color_text_fill = "material/format-color-text:fill"
format_h1 = "material/format-h1"
format_h1_fill = "material/format-h1:fill"
format_h2 = "material/format-h2"
format_h2_fill = "material/format-h2:fill"
format_h3 = "material/format-h3"
format_h3_fill = "material/format-h3:fill"
format_h4 = "material/format-h4"
format_h4_fill = "material/format-h4:fill"
format_h5 = "material/format-h5"
format_h5_fill = "material/format-h5:fill"
format_h6 = "material/format-h6"
format_h6_fill = "material/format-h6:fill"
format_image_left = "material/format-image-left"
format_image_left_fill = "material/format-image-left:fill"
format_image_right = "material/format-image-right"
format_image_right_fill = "material/format-image-right:fill"
format_indent_decrease = "material/format-indent-decrease"
format_indent_decrease_fill = "material/format-indent-decrease:fill"
format_indent_increase = "material/format-indent-increase"
format_indent_increase_fill = "material/format-indent-increase:fill"
format_ink_highlighter = "material/format-ink-highlighter"
format_ink_highlighter_fill = "material/format-ink-highlighter:fill"
format_italic = "material/format-italic"
format_italic_fill = "material/format-italic:fill"
format_letter_spacing = "material/format-letter-spacing"
format_letter_spacing_fill = "material/format-letter-spacing:fill"
format_letter_spacing_2 = "material/format-letter-spacing-2"
format_letter_spacing_2_fill = "material/format-letter-spacing-2:fill"
format_letter_spacing_standard = "material/format-letter-spacing-standard"
format_letter_spacing_standard_fill = (
    "material/format-letter-spacing-standard:fill"
)
format_letter_spacing_wide = "material/format-letter-spacing-wide"
format_letter_spacing_wide_fill = "material/format-letter-spacing-wide:fill"
format_letter_spacing_wider = "material/format-letter-spacing-wider"
format_letter_spacing_wider_fill = "material/format-letter-spacing-wider:fill"
format_line_spacing = "material/format-line-spacing"
format_line_spacing_fill = "material/format-line-spacing:fill"
format_list_bulleted = "material/format-list-bulleted"
format_list_bulleted_fill = "material/format-list-bulleted:fill"
format_list_bulleted_add = "material/format-list-bulleted-add"
format_list_bulleted_add_fill = "material/format-list-bulleted-add:fill"
format_list_numbered = "material/format-list-numbered"
format_list_numbered_fill = "material/format-list-numbered:fill"
format_list_numbered_rtl = "material/format-list-numbered-rtl"
format_list_numbered_rtl_fill = "material/format-list-numbered-rtl:fill"
format_overline = "material/format-overline"
format_overline_fill = "material/format-overline:fill"
format_paint = "material/format-paint"
format_paint_fill = "material/format-paint:fill"
format_paragraph = "material/format-paragraph"
format_paragraph_fill = "material/format-paragraph:fill"
format_quote = "material/format-quote"
format_quote_fill = "material/format-quote:fill"
format_shapes = "material/format-shapes"
format_shapes_fill = "material/format-shapes:fill"
format_size = "material/format-size"
format_size_fill = "material/format-size:fill"
format_strikethrough = "material/format-strikethrough"
format_strikethrough_fill = "material/format-strikethrough:fill"
format_text_clip = "material/format-text-clip"
format_text_clip_fill = "material/format-text-clip:fill"
format_text_overflow = "material/format-text-overflow"
format_text_overflow_fill = "material/format-text-overflow:fill"
format_text_wrap = "material/format-text-wrap"
format_text_wrap_fill = "material/format-text-wrap:fill"
format_textdirection_l_to_r = "material/format-textdirection-l-to-r"
format_textdirection_l_to_r_fill = "material/format-textdirection-l-to-r:fill"
format_textdirection_r_to_l = "material/format-textdirection-r-to-l"
format_textdirection_r_to_l_fill = "material/format-textdirection-r-to-l:fill"
format_underlined = "material/format-underlined"
format_underlined_fill = "material/format-underlined:fill"
format_underlined_squiggle = "material/format-underlined-squiggle"
format_underlined_squiggle_fill = "material/format-underlined-squiggle:fill"
forms_add_on = "material/forms-add-on"
forms_add_on_fill = "material/forms-add-on:fill"
forms_apps_script = "material/forms-apps-script"
forms_apps_script_fill = "material/forms-apps-script:fill"
fort = "material/fort"
fort_fill = "material/fort:fill"
forum = "material/forum"
forum_fill = "material/forum:fill"
forward = "material/forward"
forward_fill = "material/forward:fill"
forward_10 = "material/forward-10"
forward_10_fill = "material/forward-10:fill"
forward_30 = "material/forward-30"
forward_30_fill = "material/forward-30:fill"
forward_5 = "material/forward-5"
forward_5_fill = "material/forward-5:fill"
forward_circle = "material/forward-circle"
forward_circle_fill = "material/forward-circle:fill"
forward_media = "material/forward-media"
forward_media_fill = "material/forward-media:fill"
forward_to_inbox = "material/forward-to-inbox"
forward_to_inbox_fill = "material/forward-to-inbox:fill"
foundation = "material/foundation"
foundation_fill = "material/foundation:fill"
frame_inspect = "material/frame-inspect"
frame_inspect_fill = "material/frame-inspect:fill"
frame_person = "material/frame-person"
frame_person_fill = "material/frame-person:fill"
frame_person_off = "material/frame-person-off"
frame_person_off_fill = "material/frame-person-off:fill"
frame_reload = "material/frame-reload"
frame_reload_fill = "material/frame-reload:fill"
frame_source = "material/frame-source"
frame_source_fill = "material/frame-source:fill"
free_cancellation = "material/free-cancellation"
free_cancellation_fill = "material/free-cancellation:fill"
front_hand = "material/front-hand"
front_hand_fill = "material/front-hand:fill"
front_loader = "material/front-loader"
front_loader_fill = "material/front-loader:fill"
full_coverage = "material/full-coverage"
full_coverage_fill = "material/full-coverage:fill"
full_hd = "material/full-hd"
full_hd_fill = "material/full-hd:fill"
full_stacked_bar_chart = "material/full-stacked-bar-chart"
full_stacked_bar_chart_fill = "material/full-stacked-bar-chart:fill"
fullscreen = "material/fullscreen"
fullscreen_fill = "material/fullscreen:fill"
fullscreen_exit = "material/fullscreen-exit"
fullscreen_exit_fill = "material/fullscreen-exit:fill"
function = "material/function"
function_fill = "material/function:fill"
functions = "material/functions"
functions_fill = "material/functions:fill"
g_mobiledata = "material/g-mobiledata"
g_mobiledata_fill = "material/g-mobiledata:fill"
g_mobiledata_badge = "material/g-mobiledata-badge"
g_mobiledata_badge_fill = "material/g-mobiledata-badge:fill"
g_translate = "material/g-translate"
g_translate_fill = "material/g-translate:fill"
gallery_thumbnail = "material/gallery-thumbnail"
gallery_thumbnail_fill = "material/gallery-thumbnail:fill"
gamepad = "material/gamepad"
gamepad_fill = "material/gamepad:fill"
garage = "material/garage"
garage_fill = "material/garage:fill"
garage_home = "material/garage-home"
garage_home_fill = "material/garage-home:fill"
garden_cart = "material/garden-cart"
garden_cart_fill = "material/garden-cart:fill"
gas_meter = "material/gas-meter"
gas_meter_fill = "material/gas-meter:fill"
gastroenterology = "material/gastroenterology"
gastroenterology_fill = "material/gastroenterology:fill"
gate = "material/gate"
gate_fill = "material/gate:fill"
gavel = "material/gavel"
gavel_fill = "material/gavel:fill"
genetics = "material/genetics"
genetics_fill = "material/genetics:fill"
genres = "material/genres"
genres_fill = "material/genres:fill"
gesture = "material/gesture"
gesture_fill = "material/gesture:fill"
gesture_select = "material/gesture-select"
gesture_select_fill = "material/gesture-select:fill"
gif = "material/gif"
gif_fill = "material/gif:fill"
gif_box = "material/gif-box"
gif_box_fill = "material/gif-box:fill"
girl = "material/girl"
girl_fill = "material/girl:fill"
gite = "material/gite"
gite_fill = "material/gite:fill"
glass_cup = "material/glass-cup"
glass_cup_fill = "material/glass-cup:fill"
globe = "material/globe"
globe_fill = "material/globe:fill"
globe_asia = "material/globe-asia"
globe_asia_fill = "material/globe-asia:fill"
globe_uk = "material/globe-uk"
globe_uk_fill = "material/globe-uk:fill"
glucose = "material/glucose"
glucose_fill = "material/glucose:fill"
glyphs = "material/glyphs"
glyphs_fill = "material/glyphs:fill"
go_to_line = "material/go-to-line"
go_to_line_fill = "material/go-to-line:fill"
golf_course = "material/golf-course"
golf_course_fill = "material/golf-course:fill"
google_tv_remote = "material/google-tv-remote"
google_tv_remote_fill = "material/google-tv-remote:fill"
google_wifi = "material/google-wifi"
google_wifi_fill = "material/google-wifi:fill"
gpp_bad = "material/gpp-bad"
gpp_bad_fill = "material/gpp-bad:fill"
gpp_maybe = "material/gpp-maybe"
gpp_maybe_fill = "material/gpp-maybe:fill"
grade = "material/grade"
grade_fill = "material/grade:fill"
gradient = "material/gradient"
gradient_fill = "material/gradient:fill"
grading = "material/grading"
grading_fill = "material/grading:fill"
grain = "material/grain"
grain_fill = "material/grain:fill"
graphic_eq = "material/graphic-eq"
graphic_eq_fill = "material/graphic-eq:fill"
grass = "material/grass"
grass_fill = "material/grass:fill"
grid_3x3 = "material/grid-3x3"
grid_3x3_fill = "material/grid-3x3:fill"
grid_3x3_off = "material/grid-3x3-off"
grid_3x3_off_fill = "material/grid-3x3-off:fill"
grid_4x4 = "material/grid-4x4"
grid_4x4_fill = "material/grid-4x4:fill"
grid_goldenratio = "material/grid-goldenratio"
grid_goldenratio_fill = "material/grid-goldenratio:fill"
grid_guides = "material/grid-guides"
grid_guides_fill = "material/grid-guides:fill"
grid_off = "material/grid-off"
grid_off_fill = "material/grid-off:fill"
grid_on = "material/grid-on"
grid_on_fill = "material/grid-on:fill"
grid_view = "material/grid-view"
grid_view_fill = "material/grid-view:fill"
group = "material/group"
group_fill = "material/group:fill"
group_add = "material/group-add"
group_add_fill = "material/group-add:fill"
group_auto = "material/group-auto"
group_auto_fill = "material/group-auto:fill"
group_off = "material/group-off"
group_off_fill = "material/group-off:fill"
group_remove = "material/group-remove"
group_remove_fill = "material/group-remove:fill"
group_work = "material/group-work"
group_work_fill = "material/group-work:fill"
grouped_bar_chart = "material/grouped-bar-chart"
grouped_bar_chart_fill = "material/grouped-bar-chart:fill"
groups = "material/groups"
groups_fill = "material/groups:fill"
groups_2 = "material/groups-2"
groups_2_fill = "material/groups-2:fill"
groups_3 = "material/groups-3"
groups_3_fill = "material/groups-3:fill"
gynecology = "material/gynecology"
gynecology_fill = "material/gynecology:fill"
h_mobiledata = "material/h-mobiledata"
h_mobiledata_fill = "material/h-mobiledata:fill"
h_mobiledata_badge = "material/h-mobiledata-badge"
h_mobiledata_badge_fill = "material/h-mobiledata-badge:fill"
h_plus_mobiledata = "material/h-plus-mobiledata"
h_plus_mobiledata_fill = "material/h-plus-mobiledata:fill"
h_plus_mobiledata_badge = "material/h-plus-mobiledata-badge"
h_plus_mobiledata_badge_fill = "material/h-plus-mobiledata-badge:fill"
hail = "material/hail"
hail_fill = "material/hail:fill"
hallway = "material/hallway"
hallway_fill = "material/hallway:fill"
hand_bones = "material/hand-bones"
hand_bones_fill = "material/hand-bones:fill"
hand_gesture = "material/hand-gesture"
hand_gesture_fill = "material/hand-gesture:fill"
handshake = "material/handshake"
handshake_fill = "material/handshake:fill"
handyman = "material/handyman"
handyman_fill = "material/handyman:fill"
hangout_video = "material/hangout-video"
hangout_video_fill = "material/hangout-video:fill"
hangout_video_off = "material/hangout-video-off"
hangout_video_off_fill = "material/hangout-video-off:fill"
hard_drive = "material/hard-drive"
hard_drive_fill = "material/hard-drive:fill"
hard_drive_2 = "material/hard-drive-2"
hard_drive_2_fill = "material/hard-drive-2:fill"
hardware = "material/hardware"
hardware_fill = "material/hardware:fill"
hd = "material/hd"
hd_fill = "material/hd:fill"
hdr_auto = "material/hdr-auto"
hdr_auto_fill = "material/hdr-auto:fill"
hdr_auto_select = "material/hdr-auto-select"
hdr_auto_select_fill = "material/hdr-auto-select:fill"
hdr_enhanced_select = "material/hdr-enhanced-select"
hdr_enhanced_select_fill = "material/hdr-enhanced-select:fill"
hdr_off = "material/hdr-off"
hdr_off_fill = "material/hdr-off:fill"
hdr_off_select = "material/hdr-off-select"
hdr_off_select_fill = "material/hdr-off-select:fill"
hdr_on = "material/hdr-on"
hdr_on_fill = "material/hdr-on:fill"
hdr_on_select = "material/hdr-on-select"
hdr_on_select_fill = "material/hdr-on-select:fill"
hdr_plus = "material/hdr-plus"
hdr_plus_fill = "material/hdr-plus:fill"
hdr_strong = "material/hdr-strong"
hdr_strong_fill = "material/hdr-strong:fill"
hdr_weak = "material/hdr-weak"
hdr_weak_fill = "material/hdr-weak:fill"
headphones = "material/headphones"
headphones_fill = "material/headphones:fill"
headphones_battery = "material/headphones-battery"
headphones_battery_fill = "material/headphones-battery:fill"
headset_mic = "material/headset-mic"
headset_mic_fill = "material/headset-mic:fill"
headset_off = "material/headset-off"
headset_off_fill = "material/headset-off:fill"
healing = "material/healing"
healing_fill = "material/healing:fill"
health_and_safety = "material/health-and-safety"
health_and_safety_fill = "material/health-and-safety:fill"
health_metrics = "material/health-metrics"
health_metrics_fill = "material/health-metrics:fill"
heap_snapshot_large = "material/heap-snapshot-large"
heap_snapshot_large_fill = "material/heap-snapshot-large:fill"
heap_snapshot_multiple = "material/heap-snapshot-multiple"
heap_snapshot_multiple_fill = "material/heap-snapshot-multiple:fill"
heap_snapshot_thumbnail = "material/heap-snapshot-thumbnail"
heap_snapshot_thumbnail_fill = "material/heap-snapshot-thumbnail:fill"
hearing = "material/hearing"
hearing_fill = "material/hearing:fill"
hearing_disabled = "material/hearing-disabled"
hearing_disabled_fill = "material/hearing-disabled:fill"
heart_broken = "material/heart-broken"
heart_broken_fill = "material/heart-broken:fill"
heart_check = "material/heart-check"
heart_check_fill = "material/heart-check:fill"
heart_minus = "material/heart-minus"
heart_minus_fill = "material/heart-minus:fill"
heart_plus = "material/heart-plus"
heart_plus_fill = "material/heart-plus:fill"
heat_pump = "material/heat-pump"
heat_pump_fill = "material/heat-pump:fill"
heat_pump_balance = "material/heat-pump-balance"
heat_pump_balance_fill = "material/heat-pump-balance:fill"
height = "material/height"
height_fill = "material/height:fill"
helicopter = "material/helicopter"
helicopter_fill = "material/helicopter:fill"
help = "material/help"
help_fill = "material/help:fill"
help_center = "material/help-center"
help_center_fill = "material/help-center:fill"
help_clinic = "material/help-clinic"
help_clinic_fill = "material/help-clinic:fill"
hematology = "material/hematology"
hematology_fill = "material/hematology:fill"
hevc = "material/hevc"
hevc_fill = "material/hevc:fill"
hexagon = "material/hexagon"
hexagon_fill = "material/hexagon:fill"
hide = "material/hide"
hide_fill = "material/hide:fill"
hide_image = "material/hide-image"
hide_image_fill = "material/hide-image:fill"
hide_source = "material/hide-source"
hide_source_fill = "material/hide-source:fill"
high_density = "material/high-density"
high_density_fill = "material/high-density:fill"
high_quality = "material/high-quality"
high_quality_fill = "material/high-quality:fill"
high_res = "material/high-res"
high_res_fill = "material/high-res:fill"
highlight = "material/highlight"
highlight_fill = "material/highlight:fill"
highlighter_size_1 = "material/highlighter-size-1"
highlighter_size_1_fill = "material/highlighter-size-1:fill"
highlighter_size_2 = "material/highlighter-size-2"
highlighter_size_2_fill = "material/highlighter-size-2:fill"
highlighter_size_3 = "material/highlighter-size-3"
highlighter_size_3_fill = "material/highlighter-size-3:fill"
highlighter_size_4 = "material/highlighter-size-4"
highlighter_size_4_fill = "material/highlighter-size-4:fill"
highlighter_size_5 = "material/highlighter-size-5"
highlighter_size_5_fill = "material/highlighter-size-5:fill"
hiking = "material/hiking"
hiking_fill = "material/hiking:fill"
history = "material/history"
history_fill = "material/history:fill"
history_edu = "material/history-edu"
history_edu_fill = "material/history-edu:fill"
history_toggle_off = "material/history-toggle-off"
history_toggle_off_fill = "material/history-toggle-off:fill"
hive = "material/hive"
hive_fill = "material/hive:fill"
hls = "material/hls"
hls_fill = "material/hls:fill"
hls_off = "material/hls-off"
hls_off_fill = "material/hls-off:fill"
holiday_village = "material/holiday-village"
holiday_village_fill = "material/holiday-village:fill"
home = "material/home"
home_fill = "material/home:fill"
home_app_logo = "material/home-app-logo"
home_app_logo_fill = "material/home-app-logo:fill"
home_health = "material/home-health"
home_health_fill = "material/home-health:fill"
home_iot_device = "material/home-iot-device"
home_iot_device_fill = "material/home-iot-device:fill"
home_max = "material/home-max"
home_max_fill = "material/home-max:fill"
home_max_dots = "material/home-max-dots"
home_max_dots_fill = "material/home-max-dots:fill"
home_mini = "material/home-mini"
home_mini_fill = "material/home-mini:fill"
home_pin = "material/home-pin"
home_pin_fill = "material/home-pin:fill"
home_repair_service = "material/home-repair-service"
home_repair_service_fill = "material/home-repair-service:fill"
home_speaker = "material/home-speaker"
home_speaker_fill = "material/home-speaker:fill"
home_storage = "material/home-storage"
home_storage_fill = "material/home-storage:fill"
home_work = "material/home-work"
home_work_fill = "material/home-work:fill"
horizontal_distribute = "material/horizontal-distribute"
horizontal_distribute_fill = "material/horizontal-distribute:fill"
horizontal_rule = "material/horizontal-rule"
horizontal_rule_fill = "material/horizontal-rule:fill"
horizontal_split = "material/horizontal-split"
horizontal_split_fill = "material/horizontal-split:fill"
hot_tub = "material/hot-tub"
hot_tub_fill = "material/hot-tub:fill"
hotel = "material/hotel"
hotel_fill = "material/hotel:fill"
hotel_class = "material/hotel-class"
hotel_class_fill = "material/hotel-class:fill"
hourglass = "material/hourglass"
hourglass_fill = "material/hourglass:fill"
hourglass_bottom = "material/hourglass-bottom"
hourglass_bottom_fill = "material/hourglass-bottom:fill"
hourglass_disabled = "material/hourglass-disabled"
hourglass_disabled_fill = "material/hourglass-disabled:fill"
hourglass_empty = "material/hourglass-empty"
hourglass_empty_fill = "material/hourglass-empty:fill"
hourglass_top = "material/hourglass-top"
hourglass_top_fill = "material/hourglass-top:fill"
house = "material/house"
house_fill = "material/house:fill"
house_siding = "material/house-siding"
house_siding_fill = "material/house-siding:fill"
house_with_shield = "material/house-with-shield"
house_with_shield_fill = "material/house-with-shield:fill"
houseboat = "material/houseboat"
houseboat_fill = "material/houseboat:fill"
how_to_reg = "material/how-to-reg"
how_to_reg_fill = "material/how-to-reg:fill"
how_to_vote = "material/how-to-vote"
how_to_vote_fill = "material/how-to-vote:fill"
hr_resting = "material/hr-resting"
hr_resting_fill = "material/hr-resting:fill"
html = "material/html"
html_fill = "material/html:fill"
http = "material/http"
http_fill = "material/http:fill"
hub = "material/hub"
hub_fill = "material/hub:fill"
humerus = "material/humerus"
humerus_fill = "material/humerus:fill"
humerus_alt = "material/humerus-alt"
humerus_alt_fill = "material/humerus-alt:fill"
humidity_helper = "material/humidity-helper"
humidity_helper_fill = "material/humidity-helper:fill"
humidity_high = "material/humidity-high"
humidity_high_fill = "material/humidity-high:fill"
humidity_indoor = "material/humidity-indoor"
humidity_indoor_fill = "material/humidity-indoor:fill"
humidity_low = "material/humidity-low"
humidity_low_fill = "material/humidity-low:fill"
humidity_mid = "material/humidity-mid"
humidity_mid_fill = "material/humidity-mid:fill"
humidity_percentage = "material/humidity-percentage"
humidity_percentage_fill = "material/humidity-percentage:fill"
hvac = "material/hvac"
hvac_fill = "material/hvac:fill"
ice_skating = "material/ice-skating"
ice_skating_fill = "material/ice-skating:fill"
icecream = "material/icecream"
icecream_fill = "material/icecream:fill"
ifl = "material/ifl"
ifl_fill = "material/ifl:fill"
iframe = "material/iframe"
iframe_fill = "material/iframe:fill"
iframe_off = "material/iframe-off"
iframe_off_fill = "material/iframe-off:fill"
image = "material/image"
image_fill = "material/image:fill"
image_aspect_ratio = "material/image-aspect-ratio"
image_aspect_ratio_fill = "material/image-aspect-ratio:fill"
image_not_supported = "material/image-not-supported"
image_not_supported_fill = "material/image-not-supported:fill"
image_search = "material/image-search"
image_search_fill = "material/image-search:fill"
imagesearch_roller = "material/imagesearch-roller"
imagesearch_roller_fill = "material/imagesearch-roller:fill"
imagesmode = "material/imagesmode"
imagesmode_fill = "material/imagesmode:fill"
immunology = "material/immunology"
immunology_fill = "material/immunology:fill"
import_contacts = "material/import-contacts"
import_contacts_fill = "material/import-contacts:fill"
important_devices = "material/important-devices"
important_devices_fill = "material/important-devices:fill"
in_home_mode = "material/in-home-mode"
in_home_mode_fill = "material/in-home-mode:fill"
inactive_order = "material/inactive-order"
inactive_order_fill = "material/inactive-order:fill"
inbox = "material/inbox"
inbox_fill = "material/inbox:fill"
inbox_customize = "material/inbox-customize"
inbox_customize_fill = "material/inbox-customize:fill"
incomplete_circle = "material/incomplete-circle"
incomplete_circle_fill = "material/incomplete-circle:fill"
indeterminate_check_box = "material/indeterminate-check-box"
indeterminate_check_box_fill = "material/indeterminate-check-box:fill"
indeterminate_question_box = "material/indeterminate-question-box"
indeterminate_question_box_fill = "material/indeterminate-question-box:fill"
info = "material/info"
info_fill = "material/info:fill"
info_i = "material/info-i"
info_i_fill = "material/info-i:fill"
infrared = "material/infrared"
infrared_fill = "material/infrared:fill"
ink_eraser = "material/ink-eraser"
ink_eraser_fill = "material/ink-eraser:fill"
ink_eraser_off = "material/ink-eraser-off"
ink_eraser_off_fill = "material/ink-eraser-off:fill"
ink_highlighter = "material/ink-highlighter"
ink_highlighter_fill = "material/ink-highlighter:fill"
ink_marker = "material/ink-marker"
ink_marker_fill = "material/ink-marker:fill"
ink_pen = "material/ink-pen"
ink_pen_fill = "material/ink-pen:fill"
inpatient = "material/inpatient"
inpatient_fill = "material/inpatient:fill"
input = "material/input"
input_fill = "material/input:fill"
input_circle = "material/input-circle"
input_circle_fill = "material/input-circle:fill"
insert_chart = "material/insert-chart"
insert_chart_fill = "material/insert-chart:fill"
insert_page_break = "material/insert-page-break"
insert_page_break_fill = "material/insert-page-break:fill"
insert_text = "material/insert-text"
insert_text_fill = "material/insert-text:fill"
install_desktop = "material/install-desktop"
install_desktop_fill = "material/install-desktop:fill"
install_mobile = "material/install-mobile"
install_mobile_fill = "material/install-mobile:fill"
instant_mix = "material/instant-mix"
instant_mix_fill = "material/instant-mix:fill"
integration_instructions = "material/integration-instructions"
integration_instructions_fill = "material/integration-instructions:fill"
interactive_space = "material/interactive-space"
interactive_space_fill = "material/interactive-space:fill"
interests = "material/interests"
interests_fill = "material/interests:fill"
interpreter_mode = "material/interpreter-mode"
interpreter_mode_fill = "material/interpreter-mode:fill"
inventory = "material/inventory"
inventory_fill = "material/inventory:fill"
inventory_2 = "material/inventory-2"
inventory_2_fill = "material/inventory-2:fill"
invert_colors = "material/invert-colors"
invert_colors_fill = "material/invert-colors:fill"
invert_colors_off = "material/invert-colors-off"
invert_colors_off_fill = "material/invert-colors-off:fill"
ios_share = "material/ios-share"
ios_share_fill = "material/ios-share:fill"
iron = "material/iron"
iron_fill = "material/iron:fill"
jamboard_kiosk = "material/jamboard-kiosk"
jamboard_kiosk_fill = "material/jamboard-kiosk:fill"
javascript = "material/javascript"
javascript_fill = "material/javascript:fill"
join = "material/join"
join_fill = "material/join:fill"
join_inner = "material/join-inner"
join_inner_fill = "material/join-inner:fill"
join_left = "material/join-left"
join_left_fill = "material/join-left:fill"
join_right = "material/join-right"
join_right_fill = "material/join-right:fill"
joystick = "material/joystick"
joystick_fill = "material/joystick:fill"
jump_to_element = "material/jump-to-element"
jump_to_element_fill = "material/jump-to-element:fill"
kayaking = "material/kayaking"
kayaking_fill = "material/kayaking:fill"
kebab_dining = "material/kebab-dining"
kebab_dining_fill = "material/kebab-dining:fill"
keep_public = "material/keep-public"
keep_public_fill = "material/keep-public:fill"
kettle = "material/kettle"
kettle_fill = "material/kettle:fill"
key = "material/key"
key_fill = "material/key:fill"
key_off = "material/key-off"
key_off_fill = "material/key-off:fill"
key_visualizer = "material/key-visualizer"
key_visualizer_fill = "material/key-visualizer:fill"
keyboard = "material/keyboard"
keyboard_fill = "material/keyboard:fill"
keyboard_alt = "material/keyboard-alt"
keyboard_alt_fill = "material/keyboard-alt:fill"
keyboard_arrow_down = "material/keyboard-arrow-down"
keyboard_arrow_down_fill = "material/keyboard-arrow-down:fill"
keyboard_arrow_left = "material/keyboard-arrow-left"
keyboard_arrow_left_fill = "material/keyboard-arrow-left:fill"
keyboard_arrow_right = "material/keyboard-arrow-right"
keyboard_arrow_right_fill = "material/keyboard-arrow-right:fill"
keyboard_arrow_up = "material/keyboard-arrow-up"
keyboard_arrow_up_fill = "material/keyboard-arrow-up:fill"
keyboard_backspace = "material/keyboard-backspace"
keyboard_backspace_fill = "material/keyboard-backspace:fill"
keyboard_capslock = "material/keyboard-capslock"
keyboard_capslock_fill = "material/keyboard-capslock:fill"
keyboard_capslock_badge = "material/keyboard-capslock-badge"
keyboard_capslock_badge_fill = "material/keyboard-capslock-badge:fill"
keyboard_command_key = "material/keyboard-command-key"
keyboard_command_key_fill = "material/keyboard-command-key:fill"
keyboard_control_key = "material/keyboard-control-key"
keyboard_control_key_fill = "material/keyboard-control-key:fill"
keyboard_double_arrow_down = "material/keyboard-double-arrow-down"
keyboard_double_arrow_down_fill = "material/keyboard-double-arrow-down:fill"
keyboard_double_arrow_left = "material/keyboard-double-arrow-left"
keyboard_double_arrow_left_fill = "material/keyboard-double-arrow-left:fill"
keyboard_double_arrow_right = "material/keyboard-double-arrow-right"
keyboard_double_arrow_right_fill = "material/keyboard-double-arrow-right:fill"
keyboard_double_arrow_up = "material/keyboard-double-arrow-up"
keyboard_double_arrow_up_fill = "material/keyboard-double-arrow-up:fill"
keyboard_external_input = "material/keyboard-external-input"
keyboard_external_input_fill = "material/keyboard-external-input:fill"
keyboard_full = "material/keyboard-full"
keyboard_full_fill = "material/keyboard-full:fill"
keyboard_hide = "material/keyboard-hide"
keyboard_hide_fill = "material/keyboard-hide:fill"
keyboard_keys = "material/keyboard-keys"
keyboard_keys_fill = "material/keyboard-keys:fill"
keyboard_off = "material/keyboard-off"
keyboard_off_fill = "material/keyboard-off:fill"
keyboard_onscreen = "material/keyboard-onscreen"
keyboard_onscreen_fill = "material/keyboard-onscreen:fill"
keyboard_option_key = "material/keyboard-option-key"
keyboard_option_key_fill = "material/keyboard-option-key:fill"
keyboard_previous_language = "material/keyboard-previous-language"
keyboard_previous_language_fill = "material/keyboard-previous-language:fill"
keyboard_return = "material/keyboard-return"
keyboard_return_fill = "material/keyboard-return:fill"
keyboard_tab = "material/keyboard-tab"
keyboard_tab_fill = "material/keyboard-tab:fill"
keyboard_tab_rtl = "material/keyboard-tab-rtl"
keyboard_tab_rtl_fill = "material/keyboard-tab-rtl:fill"
keyboard_voice = "material/keyboard-voice"
keyboard_voice_fill = "material/keyboard-voice:fill"
king_bed = "material/king-bed"
king_bed_fill = "material/king-bed:fill"
kitchen = "material/kitchen"
kitchen_fill = "material/kitchen:fill"
kitesurfing = "material/kitesurfing"
kitesurfing_fill = "material/kitesurfing:fill"
lab_panel = "material/lab-panel"
lab_panel_fill = "material/lab-panel:fill"
lab_profile = "material/lab-profile"
lab_profile_fill = "material/lab-profile:fill"
lab_research = "material/lab-research"
lab_research_fill = "material/lab-research:fill"
label = "material/label"
label_fill = "material/label:fill"
label_important = "material/label-important"
label_important_fill = "material/label-important:fill"
label_off = "material/label-off"
label_off_fill = "material/label-off:fill"
labs = "material/labs"
labs_fill = "material/labs:fill"
lan = "material/lan"
lan_fill = "material/lan:fill"
landscape = "material/landscape"
landscape_fill = "material/landscape:fill"
landslide = "material/landslide"
landslide_fill = "material/landslide:fill"
language = "material/language"
language_fill = "material/language:fill"
language_chinese_array = "material/language-chinese-array"
language_chinese_array_fill = "material/language-chinese-array:fill"
language_chinese_cangjie = "material/language-chinese-cangjie"
language_chinese_cangjie_fill = "material/language-chinese-cangjie:fill"
language_chinese_dayi = "material/language-chinese-dayi"
language_chinese_dayi_fill = "material/language-chinese-dayi:fill"
language_chinese_pinyin = "material/language-chinese-pinyin"
language_chinese_pinyin_fill = "material/language-chinese-pinyin:fill"
language_chinese_quick = "material/language-chinese-quick"
language_chinese_quick_fill = "material/language-chinese-quick:fill"
language_chinese_wubi = "material/language-chinese-wubi"
language_chinese_wubi_fill = "material/language-chinese-wubi:fill"
language_french = "material/language-french"
language_french_fill = "material/language-french:fill"
language_gb_english = "material/language-gb-english"
language_gb_english_fill = "material/language-gb-english:fill"
language_international = "material/language-international"
language_international_fill = "material/language-international:fill"
language_korean_latin = "material/language-korean-latin"
language_korean_latin_fill = "material/language-korean-latin:fill"
language_pinyin = "material/language-pinyin"
language_pinyin_fill = "material/language-pinyin:fill"
language_spanish = "material/language-spanish"
language_spanish_fill = "material/language-spanish:fill"
language_us = "material/language-us"
language_us_fill = "material/language-us:fill"
language_us_colemak = "material/language-us-colemak"
language_us_colemak_fill = "material/language-us-colemak:fill"
language_us_dvorak = "material/language-us-dvorak"
language_us_dvorak_fill = "material/language-us-dvorak:fill"
laps = "material/laps"
laps_fill = "material/laps:fill"
laptop_chromebook = "material/laptop-chromebook"
laptop_chromebook_fill = "material/laptop-chromebook:fill"
laptop_mac = "material/laptop-mac"
laptop_mac_fill = "material/laptop-mac:fill"
laptop_windows = "material/laptop-windows"
laptop_windows_fill = "material/laptop-windows:fill"
lasso_select = "material/lasso-select"
lasso_select_fill = "material/lasso-select:fill"
last_page = "material/last-page"
last_page_fill = "material/last-page:fill"
laundry = "material/laundry"
laundry_fill = "material/laundry:fill"
layers = "material/layers"
layers_fill = "material/layers:fill"
layers_clear = "material/layers-clear"
layers_clear_fill = "material/layers-clear:fill"
lda = "material/lda"
lda_fill = "material/lda:fill"
leaderboard = "material/leaderboard"
leaderboard_fill = "material/leaderboard:fill"
leaf_spark = "material/leaf-spark"
leaf_spark_fill = "material/leaf-spark:fill"
leak_add = "material/leak-add"
leak_add_fill = "material/leak-add:fill"
leak_remove = "material/leak-remove"
leak_remove_fill = "material/leak-remove:fill"
left_click = "material/left-click"
left_click_fill = "material/left-click:fill"
left_panel_close = "material/left-panel-close"
left_panel_close_fill = "material/left-panel-close:fill"
left_panel_open = "material/left-panel-open"
left_panel_open_fill = "material/left-panel-open:fill"
legend_toggle = "material/legend-toggle"
legend_toggle_fill = "material/legend-toggle:fill"
lens = "material/lens"
lens_fill = "material/lens:fill"
lens_blur = "material/lens-blur"
lens_blur_fill = "material/lens-blur:fill"
letter_switch = "material/letter-switch"
letter_switch_fill = "material/letter-switch:fill"
library_add = "material/library-add"
library_add_fill = "material/library-add:fill"
library_add_check = "material/library-add-check"
library_add_check_fill = "material/library-add-check:fill"
library_books = "material/library-books"
library_books_fill = "material/library-books:fill"
library_music = "material/library-music"
library_music_fill = "material/library-music:fill"
lift_to_talk = "material/lift-to-talk"
lift_to_talk_fill = "material/lift-to-talk:fill"
light = "material/light"
light_fill = "material/light:fill"
light_group = "material/light-group"
light_group_fill = "material/light-group:fill"
light_mode = "material/light-mode"
light_mode_fill = "material/light-mode:fill"
lightbulb = "material/lightbulb"
lightbulb_fill = "material/lightbulb:fill"
lightbulb_circle = "material/lightbulb-circle"
lightbulb_circle_fill = "material/lightbulb-circle:fill"
line_axis = "material/line-axis"
line_axis_fill = "material/line-axis:fill"
line_curve = "material/line-curve"
line_curve_fill = "material/line-curve:fill"
line_end = "material/line-end"
line_end_fill = "material/line-end:fill"
line_end_arrow = "material/line-end-arrow"
line_end_arrow_fill = "material/line-end-arrow:fill"
line_end_arrow_notch = "material/line-end-arrow-notch"
line_end_arrow_notch_fill = "material/line-end-arrow-notch:fill"
line_end_circle = "material/line-end-circle"
line_end_circle_fill = "material/line-end-circle:fill"
line_end_diamond = "material/line-end-diamond"
line_end_diamond_fill = "material/line-end-diamond:fill"
line_end_square = "material/line-end-square"
line_end_square_fill = "material/line-end-square:fill"
line_start = "material/line-start"
line_start_fill = "material/line-start:fill"
line_start_arrow = "material/line-start-arrow"
line_start_arrow_fill = "material/line-start-arrow:fill"
line_start_arrow_notch = "material/line-start-arrow-notch"
line_start_arrow_notch_fill = "material/line-start-arrow-notch:fill"
line_start_circle = "material/line-start-circle"
line_start_circle_fill = "material/line-start-circle:fill"
line_start_diamond = "material/line-start-diamond"
line_start_diamond_fill = "material/line-start-diamond:fill"
line_start_square = "material/line-start-square"
line_start_square_fill = "material/line-start-square:fill"
line_style = "material/line-style"
line_style_fill = "material/line-style:fill"
line_weight = "material/line-weight"
line_weight_fill = "material/line-weight:fill"
linear_scale = "material/linear-scale"
linear_scale_fill = "material/linear-scale:fill"
link = "material/link"
link_fill = "material/link:fill"
link_off = "material/link-off"
link_off_fill = "material/link-off:fill"
linked_camera = "material/linked-camera"
linked_camera_fill = "material/linked-camera:fill"
liquor = "material/liquor"
liquor_fill = "material/liquor:fill"
list = "material/list"
list_fill = "material/list:fill"
list_alt = "material/list-alt"
list_alt_fill = "material/list-alt:fill"
list_alt_add = "material/list-alt-add"
list_alt_add_fill = "material/list-alt-add:fill"
lists = "material/lists"
lists_fill = "material/lists:fill"
live_help = "material/live-help"
live_help_fill = "material/live-help:fill"
live_tv = "material/live-tv"
live_tv_fill = "material/live-tv:fill"
living = "material/living"
living_fill = "material/living:fill"
local_activity = "material/local-activity"
local_activity_fill = "material/local-activity:fill"
local_atm = "material/local-atm"
local_atm_fill = "material/local-atm:fill"
local_bar = "material/local-bar"
local_bar_fill = "material/local-bar:fill"
local_cafe = "material/local-cafe"
local_cafe_fill = "material/local-cafe:fill"
local_car_wash = "material/local-car-wash"
local_car_wash_fill = "material/local-car-wash:fill"
local_convenience_store = "material/local-convenience-store"
local_convenience_store_fill = "material/local-convenience-store:fill"
local_dining = "material/local-dining"
local_dining_fill = "material/local-dining:fill"
local_drink = "material/local-drink"
local_drink_fill = "material/local-drink:fill"
local_fire_department = "material/local-fire-department"
local_fire_department_fill = "material/local-fire-department:fill"
local_florist = "material/local-florist"
local_florist_fill = "material/local-florist:fill"
local_gas_station = "material/local-gas-station"
local_gas_station_fill = "material/local-gas-station:fill"
local_hospital = "material/local-hospital"
local_hospital_fill = "material/local-hospital:fill"
local_laundry_service = "material/local-laundry-service"
local_laundry_service_fill = "material/local-laundry-service:fill"
local_library = "material/local-library"
local_library_fill = "material/local-library:fill"
local_mall = "material/local-mall"
local_mall_fill = "material/local-mall:fill"
local_parking = "material/local-parking"
local_parking_fill = "material/local-parking:fill"
local_pharmacy = "material/local-pharmacy"
local_pharmacy_fill = "material/local-pharmacy:fill"
local_pizza = "material/local-pizza"
local_pizza_fill = "material/local-pizza:fill"
local_police = "material/local-police"
local_police_fill = "material/local-police:fill"
local_post_office = "material/local-post-office"
local_post_office_fill = "material/local-post-office:fill"
local_see = "material/local-see"
local_see_fill = "material/local-see:fill"
local_shipping = "material/local-shipping"
local_shipping_fill = "material/local-shipping:fill"
local_taxi = "material/local-taxi"
local_taxi_fill = "material/local-taxi:fill"
location_away = "material/location-away"
location_away_fill = "material/location-away:fill"
location_chip = "material/location-chip"
location_chip_fill = "material/location-chip:fill"
location_city = "material/location-city"
location_city_fill = "material/location-city:fill"
location_disabled = "material/location-disabled"
location_disabled_fill = "material/location-disabled:fill"
location_home = "material/location-home"
location_home_fill = "material/location-home:fill"
location_off = "material/location-off"
location_off_fill = "material/location-off:fill"
location_on = "material/location-on"
location_on_fill = "material/location-on:fill"
location_searching = "material/location-searching"
location_searching_fill = "material/location-searching:fill"
lock = "material/lock"
lock_fill = "material/lock:fill"
lock_clock = "material/lock-clock"
lock_clock_fill = "material/lock-clock:fill"
lock_open = "material/lock-open"
lock_open_fill = "material/lock-open:fill"
lock_open_right = "material/lock-open-right"
lock_open_right_fill = "material/lock-open-right:fill"
lock_person = "material/lock-person"
lock_person_fill = "material/lock-person:fill"
lock_reset = "material/lock-reset"
lock_reset_fill = "material/lock-reset:fill"
login = "material/login"
login_fill = "material/login:fill"
logo_dev = "material/logo-dev"
logo_dev_fill = "material/logo-dev:fill"
logout = "material/logout"
logout_fill = "material/logout:fill"
looks = "material/looks"
looks_fill = "material/looks:fill"
looks_3 = "material/looks-3"
looks_3_fill = "material/looks-3:fill"
looks_4 = "material/looks-4"
looks_4_fill = "material/looks-4:fill"
looks_5 = "material/looks-5"
looks_5_fill = "material/looks-5:fill"
looks_6 = "material/looks-6"
looks_6_fill = "material/looks-6:fill"
looks_one = "material/looks-one"
looks_one_fill = "material/looks-one:fill"
looks_two = "material/looks-two"
looks_two_fill = "material/looks-two:fill"
loupe = "material/loupe"
loupe_fill = "material/loupe:fill"
low_density = "material/low-density"
low_density_fill = "material/low-density:fill"
low_priority = "material/low-priority"
low_priority_fill = "material/low-priority:fill"
loyalty = "material/loyalty"
loyalty_fill = "material/loyalty:fill"
lte_mobiledata = "material/lte-mobiledata"
lte_mobiledata_fill = "material/lte-mobiledata:fill"
lte_mobiledata_badge = "material/lte-mobiledata-badge"
lte_mobiledata_badge_fill = "material/lte-mobiledata-badge:fill"
lte_plus_mobiledata = "material/lte-plus-mobiledata"
lte_plus_mobiledata_fill = "material/lte-plus-mobiledata:fill"
lte_plus_mobiledata_badge = "material/lte-plus-mobiledata-badge"
lte_plus_mobiledata_badge_fill = "material/lte-plus-mobiledata-badge:fill"
luggage = "material/luggage"
luggage_fill = "material/luggage:fill"
lunch_dining = "material/lunch-dining"
lunch_dining_fill = "material/lunch-dining:fill"
lyrics = "material/lyrics"
lyrics_fill = "material/lyrics:fill"
macro_auto = "material/macro-auto"
macro_auto_fill = "material/macro-auto:fill"
macro_off = "material/macro-off"
macro_off_fill = "material/macro-off:fill"
magnification_large = "material/magnification-large"
magnification_large_fill = "material/magnification-large:fill"
magnification_small = "material/magnification-small"
magnification_small_fill = "material/magnification-small:fill"
magnify_docked = "material/magnify-docked"
magnify_docked_fill = "material/magnify-docked:fill"
magnify_fullscreen = "material/magnify-fullscreen"
magnify_fullscreen_fill = "material/magnify-fullscreen:fill"
mail = "material/mail"
mail_fill = "material/mail:fill"
mail_lock = "material/mail-lock"
mail_lock_fill = "material/mail-lock:fill"
male = "material/male"
male_fill = "material/male:fill"
man = "material/man"
man_fill = "material/man:fill"
man_2 = "material/man-2"
man_2_fill = "material/man-2:fill"
man_3 = "material/man-3"
man_3_fill = "material/man-3:fill"
man_4 = "material/man-4"
man_4_fill = "material/man-4:fill"
manage_accounts = "material/manage-accounts"
manage_accounts_fill = "material/manage-accounts:fill"
manage_history = "material/manage-history"
manage_history_fill = "material/manage-history:fill"
manage_search = "material/manage-search"
manage_search_fill = "material/manage-search:fill"
manga = "material/manga"
manga_fill = "material/manga:fill"
map = "material/map"
map_fill = "material/map:fill"
maps_ugc = "material/maps-ugc"
maps_ugc_fill = "material/maps-ugc:fill"
margin = "material/margin"
margin_fill = "material/margin:fill"
mark_as_unread = "material/mark-as-unread"
mark_as_unread_fill = "material/mark-as-unread:fill"
mark_chat_read = "material/mark-chat-read"
mark_chat_read_fill = "material/mark-chat-read:fill"
mark_chat_unread = "material/mark-chat-unread"
mark_chat_unread_fill = "material/mark-chat-unread:fill"
mark_email_read = "material/mark-email-read"
mark_email_read_fill = "material/mark-email-read:fill"
mark_email_unread = "material/mark-email-unread"
mark_email_unread_fill = "material/mark-email-unread:fill"
mark_unread_chat_alt = "material/mark-unread-chat-alt"
mark_unread_chat_alt_fill = "material/mark-unread-chat-alt:fill"
markdown = "material/markdown"
markdown_fill = "material/markdown:fill"
markdown_copy = "material/markdown-copy"
markdown_copy_fill = "material/markdown-copy:fill"
markdown_paste = "material/markdown-paste"
markdown_paste_fill = "material/markdown-paste:fill"
markunread_mailbox = "material/markunread-mailbox"
markunread_mailbox_fill = "material/markunread-mailbox:fill"
masked_transitions = "material/masked-transitions"
masked_transitions_fill = "material/masked-transitions:fill"
masks = "material/masks"
masks_fill = "material/masks:fill"
match_case = "material/match-case"
match_case_fill = "material/match-case:fill"
match_word = "material/match-word"
match_word_fill = "material/match-word:fill"
matter = "material/matter"
matter_fill = "material/matter:fill"
maximize = "material/maximize"
maximize_fill = "material/maximize:fill"
measuring_tape = "material/measuring-tape"
measuring_tape_fill = "material/measuring-tape:fill"
media_bluetooth_off = "material/media-bluetooth-off"
media_bluetooth_off_fill = "material/media-bluetooth-off:fill"
media_bluetooth_on = "material/media-bluetooth-on"
media_bluetooth_on_fill = "material/media-bluetooth-on:fill"
media_link = "material/media-link"
media_link_fill = "material/media-link:fill"
mediation = "material/mediation"
mediation_fill = "material/mediation:fill"
medical_information = "material/medical-information"
medical_information_fill = "material/medical-information:fill"
medical_mask = "material/medical-mask"
medical_mask_fill = "material/medical-mask:fill"
medical_services = "material/medical-services"
medical_services_fill = "material/medical-services:fill"
medication = "material/medication"
medication_fill = "material/medication:fill"
medication_liquid = "material/medication-liquid"
medication_liquid_fill = "material/medication-liquid:fill"
meeting_room = "material/meeting-room"
meeting_room_fill = "material/meeting-room:fill"
memory = "material/memory"
memory_fill = "material/memory:fill"
memory_alt = "material/memory-alt"
memory_alt_fill = "material/memory-alt:fill"
menstrual_health = "material/menstrual-health"
menstrual_health_fill = "material/menstrual-health:fill"
menu = "material/menu"
menu_fill = "material/menu:fill"
menu_book = "material/menu-book"
menu_book_fill = "material/menu-book:fill"
menu_open = "material/menu-open"
menu_open_fill = "material/menu-open:fill"
merge = "material/merge"
merge_fill = "material/merge:fill"
merge_type = "material/merge-type"
merge_type_fill = "material/merge-type:fill"
metabolism = "material/metabolism"
metabolism_fill = "material/metabolism:fill"
mfg_nest_yale_lock = "material/mfg-nest-yale-lock"
mfg_nest_yale_lock_fill = "material/mfg-nest-yale-lock:fill"
mic = "material/mic"
mic_fill = "material/mic:fill"
mic_double = "material/mic-double"
mic_double_fill = "material/mic-double:fill"
mic_external_off = "material/mic-external-off"
mic_external_off_fill = "material/mic-external-off:fill"
mic_external_on = "material/mic-external-on"
mic_external_on_fill = "material/mic-external-on:fill"
mic_off = "material/mic-off"
mic_off_fill = "material/mic-off:fill"
microbiology = "material/microbiology"
microbiology_fill = "material/microbiology:fill"
microwave = "material/microwave"
microwave_fill = "material/microwave:fill"
microwave_gen = "material/microwave-gen"
microwave_gen_fill = "material/microwave-gen:fill"
military_tech = "material/military-tech"
military_tech_fill = "material/military-tech:fill"
mimo = "material/mimo"
mimo_fill = "material/mimo:fill"
mimo_disconnect = "material/mimo-disconnect"
mimo_disconnect_fill = "material/mimo-disconnect:fill"
mindfulness = "material/mindfulness"
mindfulness_fill = "material/mindfulness:fill"
minimize = "material/minimize"
minimize_fill = "material/minimize:fill"
minor_crash = "material/minor-crash"
minor_crash_fill = "material/minor-crash:fill"
missed_video_call = "material/missed-video-call"
missed_video_call_fill = "material/missed-video-call:fill"
mist = "material/mist"
mist_fill = "material/mist:fill"
mixture_med = "material/mixture-med"
mixture_med_fill = "material/mixture-med:fill"
mms = "material/mms"
mms_fill = "material/mms:fill"
mobile_friendly = "material/mobile-friendly"
mobile_friendly_fill = "material/mobile-friendly:fill"
mobile_off = "material/mobile-off"
mobile_off_fill = "material/mobile-off:fill"
mobile_screen_share = "material/mobile-screen-share"
mobile_screen_share_fill = "material/mobile-screen-share:fill"
mobiledata_off = "material/mobiledata-off"
mobiledata_off_fill = "material/mobiledata-off:fill"
mode_comment = "material/mode-comment"
mode_comment_fill = "material/mode-comment:fill"
mode_cool = "material/mode-cool"
mode_cool_fill = "material/mode-cool:fill"
mode_cool_off = "material/mode-cool-off"
mode_cool_off_fill = "material/mode-cool-off:fill"
mode_dual = "material/mode-dual"
mode_dual_fill = "material/mode-dual:fill"
mode_fan = "material/mode-fan"
mode_fan_fill = "material/mode-fan:fill"
mode_fan_off = "material/mode-fan-off"
mode_fan_off_fill = "material/mode-fan-off:fill"
mode_heat = "material/mode-heat"
mode_heat_fill = "material/mode-heat:fill"
mode_heat_cool = "material/mode-heat-cool"
mode_heat_cool_fill = "material/mode-heat-cool:fill"
mode_heat_off = "material/mode-heat-off"
mode_heat_off_fill = "material/mode-heat-off:fill"
mode_night = "material/mode-night"
mode_night_fill = "material/mode-night:fill"
mode_of_travel = "material/mode-of-travel"
mode_of_travel_fill = "material/mode-of-travel:fill"
mode_off_on = "material/mode-off-on"
mode_off_on_fill = "material/mode-off-on:fill"
mode_standby = "material/mode-standby"
mode_standby_fill = "material/mode-standby:fill"
model_training = "material/model-training"
model_training_fill = "material/model-training:fill"
monetization_on = "material/monetization-on"
monetization_on_fill = "material/monetization-on:fill"
money = "material/money"
money_fill = "material/money:fill"
money_off = "material/money-off"
money_off_fill = "material/money-off:fill"
monitor = "material/monitor"
monitor_fill = "material/monitor:fill"
monitor_heart = "material/monitor-heart"
monitor_heart_fill = "material/monitor-heart:fill"
monitor_weight = "material/monitor-weight"
monitor_weight_fill = "material/monitor-weight:fill"
monitor_weight_gain = "material/monitor-weight-gain"
monitor_weight_gain_fill = "material/monitor-weight-gain:fill"
monitor_weight_loss = "material/monitor-weight-loss"
monitor_weight_loss_fill = "material/monitor-weight-loss:fill"
monitoring = "material/monitoring"
monitoring_fill = "material/monitoring:fill"
monochrome_photos = "material/monochrome-photos"
monochrome_photos_fill = "material/monochrome-photos:fill"
mood = "material/mood"
mood_fill = "material/mood:fill"
mood_bad = "material/mood-bad"
mood_bad_fill = "material/mood-bad:fill"
mop = "material/mop"
mop_fill = "material/mop:fill"
more = "material/more"
more_fill = "material/more:fill"
more_down = "material/more-down"
more_down_fill = "material/more-down:fill"
more_horiz = "material/more-horiz"
more_horiz_fill = "material/more-horiz:fill"
more_time = "material/more-time"
more_time_fill = "material/more-time:fill"
more_up = "material/more-up"
more_up_fill = "material/more-up:fill"
more_vert = "material/more-vert"
more_vert_fill = "material/more-vert:fill"
mosque = "material/mosque"
mosque_fill = "material/mosque:fill"
motion_blur = "material/motion-blur"
motion_blur_fill = "material/motion-blur:fill"
motion_mode = "material/motion-mode"
motion_mode_fill = "material/motion-mode:fill"
motion_photos_auto = "material/motion-photos-auto"
motion_photos_auto_fill = "material/motion-photos-auto:fill"
motion_photos_off = "material/motion-photos-off"
motion_photos_off_fill = "material/motion-photos-off:fill"
motion_photos_on = "material/motion-photos-on"
motion_photos_on_fill = "material/motion-photos-on:fill"
motion_photos_paused = "material/motion-photos-paused"
motion_photos_paused_fill = "material/motion-photos-paused:fill"
motion_sensor_active = "material/motion-sensor-active"
motion_sensor_active_fill = "material/motion-sensor-active:fill"
motion_sensor_alert = "material/motion-sensor-alert"
motion_sensor_alert_fill = "material/motion-sensor-alert:fill"
motion_sensor_idle = "material/motion-sensor-idle"
motion_sensor_idle_fill = "material/motion-sensor-idle:fill"
motion_sensor_urgent = "material/motion-sensor-urgent"
motion_sensor_urgent_fill = "material/motion-sensor-urgent:fill"
motorcycle = "material/motorcycle"
motorcycle_fill = "material/motorcycle:fill"
mountain_flag = "material/mountain-flag"
mountain_flag_fill = "material/mountain-flag:fill"
mouse = "material/mouse"
mouse_fill = "material/mouse:fill"
move = "material/move"
move_fill = "material/move:fill"
move_down = "material/move-down"
move_down_fill = "material/move-down:fill"
move_group = "material/move-group"
move_group_fill = "material/move-group:fill"
move_item = "material/move-item"
move_item_fill = "material/move-item:fill"
move_location = "material/move-location"
move_location_fill = "material/move-location:fill"
move_selection_down = "material/move-selection-down"
move_selection_down_fill = "material/move-selection-down:fill"
move_selection_left = "material/move-selection-left"
move_selection_left_fill = "material/move-selection-left:fill"
move_selection_right = "material/move-selection-right"
move_selection_right_fill = "material/move-selection-right:fill"
move_selection_up = "material/move-selection-up"
move_selection_up_fill = "material/move-selection-up:fill"
move_to_inbox = "material/move-to-inbox"
move_to_inbox_fill = "material/move-to-inbox:fill"
move_up = "material/move-up"
move_up_fill = "material/move-up:fill"
moved_location = "material/moved-location"
moved_location_fill = "material/moved-location:fill"
movie = "material/movie"
movie_fill = "material/movie:fill"
movie_edit = "material/movie-edit"
movie_edit_fill = "material/movie-edit:fill"
movie_info = "material/movie-info"
movie_info_fill = "material/movie-info:fill"
moving = "material/moving"
moving_fill = "material/moving:fill"
moving_beds = "material/moving-beds"
moving_beds_fill = "material/moving-beds:fill"
moving_ministry = "material/moving-ministry"
moving_ministry_fill = "material/moving-ministry:fill"
mp = "material/mp"
mp_fill = "material/mp:fill"
multicooker = "material/multicooker"
multicooker_fill = "material/multicooker:fill"
multiline_chart = "material/multiline-chart"
multiline_chart_fill = "material/multiline-chart:fill"
multiple_stop = "material/multiple-stop"
multiple_stop_fill = "material/multiple-stop:fill"
museum = "material/museum"
museum_fill = "material/museum:fill"
music_note = "material/music-note"
music_note_fill = "material/music-note:fill"
music_off = "material/music-off"
music_off_fill = "material/music-off:fill"
music_video = "material/music-video"
music_video_fill = "material/music-video:fill"
my_location = "material/my-location"
my_location_fill = "material/my-location:fill"
mystery = "material/mystery"
mystery_fill = "material/mystery:fill"
nat = "material/nat"
nat_fill = "material/nat:fill"
nature = "material/nature"
nature_fill = "material/nature:fill"
nature_people = "material/nature-people"
nature_people_fill = "material/nature-people:fill"
navigate_before = "material/navigate-before"
navigate_before_fill = "material/navigate-before:fill"
navigate_next = "material/navigate-next"
navigate_next_fill = "material/navigate-next:fill"
navigation = "material/navigation"
navigation_fill = "material/navigation:fill"
near_me = "material/near-me"
near_me_fill = "material/near-me:fill"
near_me_disabled = "material/near-me-disabled"
near_me_disabled_fill = "material/near-me-disabled:fill"
nearby = "material/nearby"
nearby_fill = "material/nearby:fill"
nearby_error = "material/nearby-error"
nearby_error_fill = "material/nearby-error:fill"
nearby_off = "material/nearby-off"
nearby_off_fill = "material/nearby-off:fill"
nephrology = "material/nephrology"
nephrology_fill = "material/nephrology:fill"
nest_audio = "material/nest-audio"
nest_audio_fill = "material/nest-audio:fill"
nest_cam_floodlight = "material/nest-cam-floodlight"
nest_cam_floodlight_fill = "material/nest-cam-floodlight:fill"
nest_cam_indoor = "material/nest-cam-indoor"
nest_cam_indoor_fill = "material/nest-cam-indoor:fill"
nest_cam_iq = "material/nest-cam-iq"
nest_cam_iq_fill = "material/nest-cam-iq:fill"
nest_cam_iq_outdoor = "material/nest-cam-iq-outdoor"
nest_cam_iq_outdoor_fill = "material/nest-cam-iq-outdoor:fill"
nest_cam_magnet_mount = "material/nest-cam-magnet-mount"
nest_cam_magnet_mount_fill = "material/nest-cam-magnet-mount:fill"
nest_cam_outdoor = "material/nest-cam-outdoor"
nest_cam_outdoor_fill = "material/nest-cam-outdoor:fill"
nest_cam_stand = "material/nest-cam-stand"
nest_cam_stand_fill = "material/nest-cam-stand:fill"
nest_cam_wall_mount = "material/nest-cam-wall-mount"
nest_cam_wall_mount_fill = "material/nest-cam-wall-mount:fill"
nest_cam_wired_stand = "material/nest-cam-wired-stand"
nest_cam_wired_stand_fill = "material/nest-cam-wired-stand:fill"
nest_clock_farsight_analog = "material/nest-clock-farsight-analog"
nest_clock_farsight_analog_fill = "material/nest-clock-farsight-analog:fill"
nest_clock_farsight_digital = "material/nest-clock-farsight-digital"
nest_clock_farsight_digital_fill = "material/nest-clock-farsight-digital:fill"
nest_connect = "material/nest-connect"
nest_connect_fill = "material/nest-connect:fill"
nest_detect = "material/nest-detect"
nest_detect_fill = "material/nest-detect:fill"
nest_display = "material/nest-display"
nest_display_fill = "material/nest-display:fill"
nest_display_max = "material/nest-display-max"
nest_display_max_fill = "material/nest-display-max:fill"
nest_doorbell_visitor = "material/nest-doorbell-visitor"
nest_doorbell_visitor_fill = "material/nest-doorbell-visitor:fill"
nest_eco_leaf = "material/nest-eco-leaf"
nest_eco_leaf_fill = "material/nest-eco-leaf:fill"
nest_farsight_weather = "material/nest-farsight-weather"
nest_farsight_weather_fill = "material/nest-farsight-weather:fill"
nest_found_savings = "material/nest-found-savings"
nest_found_savings_fill = "material/nest-found-savings:fill"
nest_heat_link_e = "material/nest-heat-link-e"
nest_heat_link_e_fill = "material/nest-heat-link-e:fill"
nest_heat_link_gen_3 = "material/nest-heat-link-gen-3"
nest_heat_link_gen_3_fill = "material/nest-heat-link-gen-3:fill"
nest_hello_doorbell = "material/nest-hello-doorbell"
nest_hello_doorbell_fill = "material/nest-hello-doorbell:fill"
nest_mini = "material/nest-mini"
nest_mini_fill = "material/nest-mini:fill"
nest_multi_room = "material/nest-multi-room"
nest_multi_room_fill = "material/nest-multi-room:fill"
nest_protect = "material/nest-protect"
nest_protect_fill = "material/nest-protect:fill"
nest_remote = "material/nest-remote"
nest_remote_fill = "material/nest-remote:fill"
nest_remote_comfort_sensor = "material/nest-remote-comfort-sensor"
nest_remote_comfort_sensor_fill = "material/nest-remote-comfort-sensor:fill"
nest_secure_alarm = "material/nest-secure-alarm"
nest_secure_alarm_fill = "material/nest-secure-alarm:fill"
nest_sunblock = "material/nest-sunblock"
nest_sunblock_fill = "material/nest-sunblock:fill"
nest_tag = "material/nest-tag"
nest_tag_fill = "material/nest-tag:fill"
nest_thermostat = "material/nest-thermostat"
nest_thermostat_fill = "material/nest-thermostat:fill"
nest_thermostat_e_eu = "material/nest-thermostat-e-eu"
nest_thermostat_e_eu_fill = "material/nest-thermostat-e-eu:fill"
nest_thermostat_gen_3 = "material/nest-thermostat-gen-3"
nest_thermostat_gen_3_fill = "material/nest-thermostat-gen-3:fill"
nest_thermostat_sensor = "material/nest-thermostat-sensor"
nest_thermostat_sensor_fill = "material/nest-thermostat-sensor:fill"
nest_thermostat_sensor_eu = "material/nest-thermostat-sensor-eu"
nest_thermostat_sensor_eu_fill = "material/nest-thermostat-sensor-eu:fill"
nest_thermostat_zirconium_eu = "material/nest-thermostat-zirconium-eu"
nest_thermostat_zirconium_eu_fill = "material/nest-thermostat-zirconium-eu:fill"
nest_true_radiant = "material/nest-true-radiant"
nest_true_radiant_fill = "material/nest-true-radiant:fill"
nest_wake_on_approach = "material/nest-wake-on-approach"
nest_wake_on_approach_fill = "material/nest-wake-on-approach:fill"
nest_wake_on_press = "material/nest-wake-on-press"
nest_wake_on_press_fill = "material/nest-wake-on-press:fill"
nest_wifi_gale = "material/nest-wifi-gale"
nest_wifi_gale_fill = "material/nest-wifi-gale:fill"
nest_wifi_point = "material/nest-wifi-point"
nest_wifi_point_fill = "material/nest-wifi-point:fill"
nest_wifi_pro = "material/nest-wifi-pro"
nest_wifi_pro_fill = "material/nest-wifi-pro:fill"
nest_wifi_pro_2 = "material/nest-wifi-pro-2"
nest_wifi_pro_2_fill = "material/nest-wifi-pro-2:fill"
nest_wifi_router = "material/nest-wifi-router"
nest_wifi_router_fill = "material/nest-wifi-router:fill"
network_cell = "material/network-cell"
network_cell_fill = "material/network-cell:fill"
network_check = "material/network-check"
network_check_fill = "material/network-check:fill"
network_intelligence_history = "material/network-intelligence-history"
network_intelligence_history_fill = "material/network-intelligence-history:fill"
network_intelligence_update = "material/network-intelligence-update"
network_intelligence_update_fill = "material/network-intelligence-update:fill"
network_locked = "material/network-locked"
network_locked_fill = "material/network-locked:fill"
network_manage = "material/network-manage"
network_manage_fill = "material/network-manage:fill"
network_node = "material/network-node"
network_node_fill = "material/network-node:fill"
network_ping = "material/network-ping"
network_ping_fill = "material/network-ping:fill"
network_wifi = "material/network-wifi"
network_wifi_fill = "material/network-wifi:fill"
network_wifi_1_bar = "material/network-wifi-1-bar"
network_wifi_1_bar_fill = "material/network-wifi-1-bar:fill"
network_wifi_1_bar_locked = "material/network-wifi-1-bar-locked"
network_wifi_1_bar_locked_fill = "material/network-wifi-1-bar-locked:fill"
network_wifi_2_bar = "material/network-wifi-2-bar"
network_wifi_2_bar_fill = "material/network-wifi-2-bar:fill"
network_wifi_2_bar_locked = "material/network-wifi-2-bar-locked"
network_wifi_2_bar_locked_fill = "material/network-wifi-2-bar-locked:fill"
network_wifi_3_bar = "material/network-wifi-3-bar"
network_wifi_3_bar_fill = "material/network-wifi-3-bar:fill"
network_wifi_3_bar_locked = "material/network-wifi-3-bar-locked"
network_wifi_3_bar_locked_fill = "material/network-wifi-3-bar-locked:fill"
neurology = "material/neurology"
neurology_fill = "material/neurology:fill"
new_label = "material/new-label"
new_label_fill = "material/new-label:fill"
new_releases = "material/new-releases"
new_releases_fill = "material/new-releases:fill"
new_window = "material/new-window"
new_window_fill = "material/new-window:fill"
news = "material/news"
news_fill = "material/news:fill"
newsmode = "material/newsmode"
newsmode_fill = "material/newsmode:fill"
newspaper = "material/newspaper"
newspaper_fill = "material/newspaper:fill"
next_plan = "material/next-plan"
next_plan_fill = "material/next-plan:fill"
next_week = "material/next-week"
next_week_fill = "material/next-week:fill"
nfc = "material/nfc"
nfc_fill = "material/nfc:fill"
night_shelter = "material/night-shelter"
night_shelter_fill = "material/night-shelter:fill"
night_sight_auto = "material/night-sight-auto"
night_sight_auto_fill = "material/night-sight-auto:fill"
night_sight_auto_off = "material/night-sight-auto-off"
night_sight_auto_off_fill = "material/night-sight-auto-off:fill"
night_sight_max = "material/night-sight-max"
night_sight_max_fill = "material/night-sight-max:fill"
nightlife = "material/nightlife"
nightlife_fill = "material/nightlife:fill"
nightlight = "material/nightlight"
nightlight_fill = "material/nightlight:fill"
nights_stay = "material/nights-stay"
nights_stay_fill = "material/nights-stay:fill"
no_accounts = "material/no-accounts"
no_accounts_fill = "material/no-accounts:fill"
no_adult_content = "material/no-adult-content"
no_adult_content_fill = "material/no-adult-content:fill"
no_backpack = "material/no-backpack"
no_backpack_fill = "material/no-backpack:fill"
no_crash = "material/no-crash"
no_crash_fill = "material/no-crash:fill"
no_drinks = "material/no-drinks"
no_drinks_fill = "material/no-drinks:fill"
no_encryption = "material/no-encryption"
no_encryption_fill = "material/no-encryption:fill"
no_flash = "material/no-flash"
no_flash_fill = "material/no-flash:fill"
no_food = "material/no-food"
no_food_fill = "material/no-food:fill"
no_luggage = "material/no-luggage"
no_luggage_fill = "material/no-luggage:fill"
no_meals = "material/no-meals"
no_meals_fill = "material/no-meals:fill"
no_meeting_room = "material/no-meeting-room"
no_meeting_room_fill = "material/no-meeting-room:fill"
no_photography = "material/no-photography"
no_photography_fill = "material/no-photography:fill"
no_sim = "material/no-sim"
no_sim_fill = "material/no-sim:fill"
no_sound = "material/no-sound"
no_sound_fill = "material/no-sound:fill"
no_stroller = "material/no-stroller"
no_stroller_fill = "material/no-stroller:fill"
no_transfer = "material/no-transfer"
no_transfer_fill = "material/no-transfer:fill"
noise_aware = "material/noise-aware"
noise_aware_fill = "material/noise-aware:fill"
noise_control_off = "material/noise-control-off"
noise_control_off_fill = "material/noise-control-off:fill"
noise_control_on = "material/noise-control-on"
noise_control_on_fill = "material/noise-control-on:fill"
nordic_walking = "material/nordic-walking"
nordic_walking_fill = "material/nordic-walking:fill"
north = "material/north"
north_fill = "material/north:fill"
north_east = "material/north-east"
north_east_fill = "material/north-east:fill"
north_west = "material/north-west"
north_west_fill = "material/north-west:fill"
not_accessible = "material/not-accessible"
not_accessible_fill = "material/not-accessible:fill"
not_accessible_forward = "material/not-accessible-forward"
not_accessible_forward_fill = "material/not-accessible-forward:fill"
not_listed_location = "material/not-listed-location"
not_listed_location_fill = "material/not-listed-location:fill"
not_started = "material/not-started"
not_started_fill = "material/not-started:fill"
note = "material/note"
note_fill = "material/note:fill"
note_add = "material/note-add"
note_add_fill = "material/note-add:fill"
note_alt = "material/note-alt"
note_alt_fill = "material/note-alt:fill"
note_stack = "material/note-stack"
note_stack_fill = "material/note-stack:fill"
note_stack_add = "material/note-stack-add"
note_stack_add_fill = "material/note-stack-add:fill"
notes = "material/notes"
notes_fill = "material/notes:fill"
notification_add = "material/notification-add"
notification_add_fill = "material/notification-add:fill"
notification_important = "material/notification-important"
notification_important_fill = "material/notification-important:fill"
notification_multiple = "material/notification-multiple"
notification_multiple_fill = "material/notification-multiple:fill"
notifications = "material/notifications"
notifications_fill = "material/notifications:fill"
notifications_active = "material/notifications-active"
notifications_active_fill = "material/notifications-active:fill"
notifications_off = "material/notifications-off"
notifications_off_fill = "material/notifications-off:fill"
notifications_paused = "material/notifications-paused"
notifications_paused_fill = "material/notifications-paused:fill"
numbers = "material/numbers"
numbers_fill = "material/numbers:fill"
nutrition = "material/nutrition"
nutrition_fill = "material/nutrition:fill"
ods = "material/ods"
ods_fill = "material/ods:fill"
odt = "material/odt"
odt_fill = "material/odt:fill"
offline_bolt = "material/offline-bolt"
offline_bolt_fill = "material/offline-bolt:fill"
offline_pin = "material/offline-pin"
offline_pin_fill = "material/offline-pin:fill"
offline_share = "material/offline-share"
offline_share_fill = "material/offline-share:fill"
oil_barrel = "material/oil-barrel"
oil_barrel_fill = "material/oil-barrel:fill"
on_device_training = "material/on-device-training"
on_device_training_fill = "material/on-device-training:fill"
oncology = "material/oncology"
oncology_fill = "material/oncology:fill"
online_prediction = "material/online-prediction"
online_prediction_fill = "material/online-prediction:fill"
onsen = "material/onsen"
onsen_fill = "material/onsen:fill"
opacity = "material/opacity"
opacity_fill = "material/opacity:fill"
open_in_browser = "material/open-in-browser"
open_in_browser_fill = "material/open-in-browser:fill"
open_in_full = "material/open-in-full"
open_in_full_fill = "material/open-in-full:fill"
open_in_new = "material/open-in-new"
open_in_new_fill = "material/open-in-new:fill"
open_in_new_down = "material/open-in-new-down"
open_in_new_down_fill = "material/open-in-new-down:fill"
open_in_new_off = "material/open-in-new-off"
open_in_new_off_fill = "material/open-in-new-off:fill"
open_in_phone = "material/open-in-phone"
open_in_phone_fill = "material/open-in-phone:fill"
open_jam = "material/open-jam"
open_jam_fill = "material/open-jam:fill"
open_with = "material/open-with"
open_with_fill = "material/open-with:fill"
ophthalmology = "material/ophthalmology"
ophthalmology_fill = "material/ophthalmology:fill"
oral_disease = "material/oral-disease"
oral_disease_fill = "material/oral-disease:fill"
order_approve = "material/order-approve"
order_approve_fill = "material/order-approve:fill"
order_play = "material/order-play"
order_play_fill = "material/order-play:fill"
orthopedics = "material/orthopedics"
orthopedics_fill = "material/orthopedics:fill"
other_admission = "material/other-admission"
other_admission_fill = "material/other-admission:fill"
other_houses = "material/other-houses"
other_houses_fill = "material/other-houses:fill"
outbound = "material/outbound"
outbound_fill = "material/outbound:fill"
outbox = "material/outbox"
outbox_fill = "material/outbox:fill"
outbox_alt = "material/outbox-alt"
outbox_alt_fill = "material/outbox-alt:fill"
outdoor_garden = "material/outdoor-garden"
outdoor_garden_fill = "material/outdoor-garden:fill"
outdoor_grill = "material/outdoor-grill"
outdoor_grill_fill = "material/outdoor-grill:fill"
outgoing_mail = "material/outgoing-mail"
outgoing_mail_fill = "material/outgoing-mail:fill"
outlet = "material/outlet"
outlet_fill = "material/outlet:fill"
outpatient = "material/outpatient"
outpatient_fill = "material/outpatient:fill"
outpatient_med = "material/outpatient-med"
outpatient_med_fill = "material/outpatient-med:fill"
output = "material/output"
output_fill = "material/output:fill"
output_circle = "material/output-circle"
output_circle_fill = "material/output-circle:fill"
oven_gen = "material/oven-gen"
oven_gen_fill = "material/oven-gen:fill"
overview = "material/overview"
overview_fill = "material/overview:fill"
overview_key = "material/overview-key"
overview_key_fill = "material/overview-key:fill"
oxygen_saturation = "material/oxygen-saturation"
oxygen_saturation_fill = "material/oxygen-saturation:fill"
pace = "material/pace"
pace_fill = "material/pace:fill"
pacemaker = "material/pacemaker"
pacemaker_fill = "material/pacemaker:fill"
package = "material/package"
package_fill = "material/package:fill"
package_2 = "material/package-2"
package_2_fill = "material/package-2:fill"
padding = "material/padding"
padding_fill = "material/padding:fill"
page_control = "material/page-control"
page_control_fill = "material/page-control:fill"
page_info = "material/page-info"
page_info_fill = "material/page-info:fill"
pages = "material/pages"
pages_fill = "material/pages:fill"
pageview = "material/pageview"
pageview_fill = "material/pageview:fill"
paid = "material/paid"
paid_fill = "material/paid:fill"
palette = "material/palette"
palette_fill = "material/palette:fill"
pallet = "material/pallet"
pallet_fill = "material/pallet:fill"
pan_tool = "material/pan-tool"
pan_tool_fill = "material/pan-tool:fill"
pan_tool_alt = "material/pan-tool-alt"
pan_tool_alt_fill = "material/pan-tool-alt:fill"
pan_zoom = "material/pan-zoom"
pan_zoom_fill = "material/pan-zoom:fill"
panorama = "material/panorama"
panorama_fill = "material/panorama:fill"
panorama_fish_eye = "material/panorama-fish-eye"
panorama_fish_eye_fill = "material/panorama-fish-eye:fill"
panorama_horizontal = "material/panorama-horizontal"
panorama_horizontal_fill = "material/panorama-horizontal:fill"
panorama_photosphere = "material/panorama-photosphere"
panorama_photosphere_fill = "material/panorama-photosphere:fill"
panorama_vertical = "material/panorama-vertical"
panorama_vertical_fill = "material/panorama-vertical:fill"
panorama_wide_angle = "material/panorama-wide-angle"
panorama_wide_angle_fill = "material/panorama-wide-angle:fill"
paragliding = "material/paragliding"
paragliding_fill = "material/paragliding:fill"
park = "material/park"
park_fill = "material/park:fill"
partly_cloudy_day = "material/partly-cloudy-day"
partly_cloudy_day_fill = "material/partly-cloudy-day:fill"
partly_cloudy_night = "material/partly-cloudy-night"
partly_cloudy_night_fill = "material/partly-cloudy-night:fill"
partner_exchange = "material/partner-exchange"
partner_exchange_fill = "material/partner-exchange:fill"
partner_reports = "material/partner-reports"
partner_reports_fill = "material/partner-reports:fill"
party_mode = "material/party-mode"
party_mode_fill = "material/party-mode:fill"
passkey = "material/passkey"
passkey_fill = "material/passkey:fill"
password = "material/password"
password_fill = "material/password:fill"
patient_list = "material/patient-list"
patient_list_fill = "material/patient-list:fill"
pattern = "material/pattern"
pattern_fill = "material/pattern:fill"
pause = "material/pause"
pause_fill = "material/pause:fill"
pause_circle = "material/pause-circle"
pause_circle_fill = "material/pause-circle:fill"
pause_presentation = "material/pause-presentation"
pause_presentation_fill = "material/pause-presentation:fill"
payments = "material/payments"
payments_fill = "material/payments:fill"
pedal_bike = "material/pedal-bike"
pedal_bike_fill = "material/pedal-bike:fill"
pediatrics = "material/pediatrics"
pediatrics_fill = "material/pediatrics:fill"
pen_size_1 = "material/pen-size-1"
pen_size_1_fill = "material/pen-size-1:fill"
pen_size_2 = "material/pen-size-2"
pen_size_2_fill = "material/pen-size-2:fill"
pen_size_3 = "material/pen-size-3"
pen_size_3_fill = "material/pen-size-3:fill"
pen_size_4 = "material/pen-size-4"
pen_size_4_fill = "material/pen-size-4:fill"
pen_size_5 = "material/pen-size-5"
pen_size_5_fill = "material/pen-size-5:fill"
pending = "material/pending"
pending_fill = "material/pending:fill"
pending_actions = "material/pending-actions"
pending_actions_fill = "material/pending-actions:fill"
pentagon = "material/pentagon"
pentagon_fill = "material/pentagon:fill"
percent = "material/percent"
percent_fill = "material/percent:fill"
pergola = "material/pergola"
pergola_fill = "material/pergola:fill"
perm_camera_mic = "material/perm-camera-mic"
perm_camera_mic_fill = "material/perm-camera-mic:fill"
perm_contact_calendar = "material/perm-contact-calendar"
perm_contact_calendar_fill = "material/perm-contact-calendar:fill"
perm_data_setting = "material/perm-data-setting"
perm_data_setting_fill = "material/perm-data-setting:fill"
perm_device_information = "material/perm-device-information"
perm_device_information_fill = "material/perm-device-information:fill"
perm_media = "material/perm-media"
perm_media_fill = "material/perm-media:fill"
perm_phone_msg = "material/perm-phone-msg"
perm_phone_msg_fill = "material/perm-phone-msg:fill"
perm_scan_wifi = "material/perm-scan-wifi"
perm_scan_wifi_fill = "material/perm-scan-wifi:fill"
person = "material/person"
person_fill = "material/person:fill"
person_2 = "material/person-2"
person_2_fill = "material/person-2:fill"
person_3 = "material/person-3"
person_3_fill = "material/person-3:fill"
person_4 = "material/person-4"
person_4_fill = "material/person-4:fill"
person_add = "material/person-add"
person_add_fill = "material/person-add:fill"
person_add_disabled = "material/person-add-disabled"
person_add_disabled_fill = "material/person-add-disabled:fill"
person_alert = "material/person-alert"
person_alert_fill = "material/person-alert:fill"
person_apron = "material/person-apron"
person_apron_fill = "material/person-apron:fill"
person_book = "material/person-book"
person_book_fill = "material/person-book:fill"
person_cancel = "material/person-cancel"
person_cancel_fill = "material/person-cancel:fill"
person_celebrate = "material/person-celebrate"
person_celebrate_fill = "material/person-celebrate:fill"
person_check = "material/person-check"
person_check_fill = "material/person-check:fill"
person_off = "material/person-off"
person_off_fill = "material/person-off:fill"
person_pin = "material/person-pin"
person_pin_fill = "material/person-pin:fill"
person_pin_circle = "material/person-pin-circle"
person_pin_circle_fill = "material/person-pin-circle:fill"
person_play = "material/person-play"
person_play_fill = "material/person-play:fill"
person_raised_hand = "material/person-raised-hand"
person_raised_hand_fill = "material/person-raised-hand:fill"
person_remove = "material/person-remove"
person_remove_fill = "material/person-remove:fill"
person_search = "material/person-search"
person_search_fill = "material/person-search:fill"
personal_injury = "material/personal-injury"
personal_injury_fill = "material/personal-injury:fill"
pest_control = "material/pest-control"
pest_control_fill = "material/pest-control:fill"
pest_control_rodent = "material/pest-control-rodent"
pest_control_rodent_fill = "material/pest-control-rodent:fill"
pet_supplies = "material/pet-supplies"
pet_supplies_fill = "material/pet-supplies:fill"
pets = "material/pets"
pets_fill = "material/pets:fill"
phishing = "material/phishing"
phishing_fill = "material/phishing:fill"
phone_android = "material/phone-android"
phone_android_fill = "material/phone-android:fill"
phone_bluetooth_speaker = "material/phone-bluetooth-speaker"
phone_bluetooth_speaker_fill = "material/phone-bluetooth-speaker:fill"
phone_callback = "material/phone-callback"
phone_callback_fill = "material/phone-callback:fill"
phone_disabled = "material/phone-disabled"
phone_disabled_fill = "material/phone-disabled:fill"
phone_enabled = "material/phone-enabled"
phone_enabled_fill = "material/phone-enabled:fill"
phone_forwarded = "material/phone-forwarded"
phone_forwarded_fill = "material/phone-forwarded:fill"
phone_in_talk = "material/phone-in-talk"
phone_in_talk_fill = "material/phone-in-talk:fill"
phone_iphone = "material/phone-iphone"
phone_iphone_fill = "material/phone-iphone:fill"
phone_locked = "material/phone-locked"
phone_locked_fill = "material/phone-locked:fill"
phone_missed = "material/phone-missed"
phone_missed_fill = "material/phone-missed:fill"
phone_paused = "material/phone-paused"
phone_paused_fill = "material/phone-paused:fill"
phonelink_erase = "material/phonelink-erase"
phonelink_erase_fill = "material/phonelink-erase:fill"
phonelink_lock = "material/phonelink-lock"
phonelink_lock_fill = "material/phonelink-lock:fill"
phonelink_off = "material/phonelink-off"
phonelink_off_fill = "material/phonelink-off:fill"
phonelink_ring = "material/phonelink-ring"
phonelink_ring_fill = "material/phonelink-ring:fill"
phonelink_ring_off = "material/phonelink-ring-off"
phonelink_ring_off_fill = "material/phonelink-ring-off:fill"
phonelink_setup = "material/phonelink-setup"
phonelink_setup_fill = "material/phonelink-setup:fill"
photo = "material/photo"
photo_fill = "material/photo:fill"
photo_album = "material/photo-album"
photo_album_fill = "material/photo-album:fill"
photo_camera = "material/photo-camera"
photo_camera_fill = "material/photo-camera:fill"
photo_camera_back = "material/photo-camera-back"
photo_camera_back_fill = "material/photo-camera-back:fill"
photo_camera_front = "material/photo-camera-front"
photo_camera_front_fill = "material/photo-camera-front:fill"
photo_frame = "material/photo-frame"
photo_frame_fill = "material/photo-frame:fill"
photo_library = "material/photo-library"
photo_library_fill = "material/photo-library:fill"
photo_prints = "material/photo-prints"
photo_prints_fill = "material/photo-prints:fill"
photo_size_select_large = "material/photo-size-select-large"
photo_size_select_large_fill = "material/photo-size-select-large:fill"
photo_size_select_small = "material/photo-size-select-small"
photo_size_select_small_fill = "material/photo-size-select-small:fill"
php = "material/php"
php_fill = "material/php:fill"
physical_therapy = "material/physical-therapy"
physical_therapy_fill = "material/physical-therapy:fill"
piano = "material/piano"
piano_fill = "material/piano:fill"
piano_off = "material/piano-off"
piano_off_fill = "material/piano-off:fill"
picture_as_pdf = "material/picture-as-pdf"
picture_as_pdf_fill = "material/picture-as-pdf:fill"
picture_in_picture = "material/picture-in-picture"
picture_in_picture_fill = "material/picture-in-picture:fill"
picture_in_picture_alt = "material/picture-in-picture-alt"
picture_in_picture_alt_fill = "material/picture-in-picture-alt:fill"
picture_in_picture_center = "material/picture-in-picture-center"
picture_in_picture_center_fill = "material/picture-in-picture-center:fill"
picture_in_picture_large = "material/picture-in-picture-large"
picture_in_picture_large_fill = "material/picture-in-picture-large:fill"
picture_in_picture_medium = "material/picture-in-picture-medium"
picture_in_picture_medium_fill = "material/picture-in-picture-medium:fill"
picture_in_picture_small = "material/picture-in-picture-small"
picture_in_picture_small_fill = "material/picture-in-picture-small:fill"
pie_chart = "material/pie-chart"
pie_chart_fill = "material/pie-chart:fill"
pill = "material/pill"
pill_fill = "material/pill:fill"
pill_off = "material/pill-off"
pill_off_fill = "material/pill-off:fill"
pin = "material/pin"
pin_fill = "material/pin:fill"
pin_drop = "material/pin-drop"
pin_drop_fill = "material/pin-drop:fill"
pin_end = "material/pin-end"
pin_end_fill = "material/pin-end:fill"
pin_invoke = "material/pin-invoke"
pin_invoke_fill = "material/pin-invoke:fill"
pinch = "material/pinch"
pinch_fill = "material/pinch:fill"
pinch_zoom_in = "material/pinch-zoom-in"
pinch_zoom_in_fill = "material/pinch-zoom-in:fill"
pinch_zoom_out = "material/pinch-zoom-out"
pinch_zoom_out_fill = "material/pinch-zoom-out:fill"
pip = "material/pip"
pip_fill = "material/pip:fill"
pip_exit = "material/pip-exit"
pip_exit_fill = "material/pip-exit:fill"
pivot_table_chart = "material/pivot-table-chart"
pivot_table_chart_fill = "material/pivot-table-chart:fill"
place_item = "material/place-item"
place_item_fill = "material/place-item:fill"
plagiarism = "material/plagiarism"
plagiarism_fill = "material/plagiarism:fill"
planner_banner_ad_pt = "material/planner-banner-ad-pt"
planner_banner_ad_pt_fill = "material/planner-banner-ad-pt:fill"
play_arrow = "material/play-arrow"
play_arrow_fill = "material/play-arrow:fill"
play_circle = "material/play-circle"
play_circle_fill = "material/play-circle:fill"
play_disabled = "material/play-disabled"
play_disabled_fill = "material/play-disabled:fill"
play_for_work = "material/play-for-work"
play_for_work_fill = "material/play-for-work:fill"
play_lesson = "material/play-lesson"
play_lesson_fill = "material/play-lesson:fill"
play_pause = "material/play-pause"
play_pause_fill = "material/play-pause:fill"
play_shapes = "material/play-shapes"
play_shapes_fill = "material/play-shapes:fill"
playing_cards = "material/playing-cards"
playing_cards_fill = "material/playing-cards:fill"
playlist_add = "material/playlist-add"
playlist_add_fill = "material/playlist-add:fill"
playlist_add_check = "material/playlist-add-check"
playlist_add_check_fill = "material/playlist-add-check:fill"
playlist_add_check_circle = "material/playlist-add-check-circle"
playlist_add_check_circle_fill = "material/playlist-add-check-circle:fill"
playlist_add_circle = "material/playlist-add-circle"
playlist_add_circle_fill = "material/playlist-add-circle:fill"
playlist_play = "material/playlist-play"
playlist_play_fill = "material/playlist-play:fill"
playlist_remove = "material/playlist-remove"
playlist_remove_fill = "material/playlist-remove:fill"
plumbing = "material/plumbing"
plumbing_fill = "material/plumbing:fill"
podcasts = "material/podcasts"
podcasts_fill = "material/podcasts:fill"
podiatry = "material/podiatry"
podiatry_fill = "material/podiatry:fill"
podium = "material/podium"
podium_fill = "material/podium:fill"
point_of_sale = "material/point-of-sale"
point_of_sale_fill = "material/point-of-sale:fill"
point_scan = "material/point-scan"
point_scan_fill = "material/point-scan:fill"
policy = "material/policy"
policy_fill = "material/policy:fill"
polyline = "material/polyline"
polyline_fill = "material/polyline:fill"
polymer = "material/polymer"
polymer_fill = "material/polymer:fill"
pool = "material/pool"
pool_fill = "material/pool:fill"
portable_wifi_off = "material/portable-wifi-off"
portable_wifi_off_fill = "material/portable-wifi-off:fill"
position_bottom_left = "material/position-bottom-left"
position_bottom_left_fill = "material/position-bottom-left:fill"
position_bottom_right = "material/position-bottom-right"
position_bottom_right_fill = "material/position-bottom-right:fill"
position_top_right = "material/position-top-right"
position_top_right_fill = "material/position-top-right:fill"
post = "material/post"
post_fill = "material/post:fill"
post_add = "material/post-add"
post_add_fill = "material/post-add:fill"
potted_plant = "material/potted-plant"
potted_plant_fill = "material/potted-plant:fill"
power = "material/power"
power_fill = "material/power:fill"
power_input = "material/power-input"
power_input_fill = "material/power-input:fill"
power_off = "material/power-off"
power_off_fill = "material/power-off:fill"
power_settings_new = "material/power-settings-new"
power_settings_new_fill = "material/power-settings-new:fill"
prayer_times = "material/prayer-times"
prayer_times_fill = "material/prayer-times:fill"
precision_manufacturing = "material/precision-manufacturing"
precision_manufacturing_fill = "material/precision-manufacturing:fill"
pregnancy = "material/pregnancy"
pregnancy_fill = "material/pregnancy:fill"
pregnant_woman = "material/pregnant-woman"
pregnant_woman_fill = "material/pregnant-woman:fill"
preliminary = "material/preliminary"
preliminary_fill = "material/preliminary:fill"
prescriptions = "material/prescriptions"
prescriptions_fill = "material/prescriptions:fill"
present_to_all = "material/present-to-all"
present_to_all_fill = "material/present-to-all:fill"
preview = "material/preview"
preview_fill = "material/preview:fill"
preview_off = "material/preview-off"
preview_off_fill = "material/preview-off:fill"
price_change = "material/price-change"
price_change_fill = "material/price-change:fill"
price_check = "material/price-check"
price_check_fill = "material/price-check:fill"
print = "material/print"
print_fill = "material/print:fill"
print_add = "material/print-add"
print_add_fill = "material/print-add:fill"
print_connect = "material/print-connect"
print_connect_fill = "material/print-connect:fill"
print_disabled = "material/print-disabled"
print_disabled_fill = "material/print-disabled:fill"
print_error = "material/print-error"
print_error_fill = "material/print-error:fill"
print_lock = "material/print-lock"
print_lock_fill = "material/print-lock:fill"
priority = "material/priority"
priority_fill = "material/priority:fill"
priority_high = "material/priority-high"
priority_high_fill = "material/priority-high:fill"
privacy = "material/privacy"
privacy_fill = "material/privacy:fill"
privacy_tip = "material/privacy-tip"
privacy_tip_fill = "material/privacy-tip:fill"
private_connectivity = "material/private-connectivity"
private_connectivity_fill = "material/private-connectivity:fill"
problem = "material/problem"
problem_fill = "material/problem:fill"
procedure = "material/procedure"
procedure_fill = "material/procedure:fill"
process_chart = "material/process-chart"
process_chart_fill = "material/process-chart:fill"
production_quantity_limits = "material/production-quantity-limits"
production_quantity_limits_fill = "material/production-quantity-limits:fill"
productivity = "material/productivity"
productivity_fill = "material/productivity:fill"
progress_activity = "material/progress-activity"
progress_activity_fill = "material/progress-activity:fill"
propane = "material/propane"
propane_fill = "material/propane:fill"
propane_tank = "material/propane-tank"
propane_tank_fill = "material/propane-tank:fill"
psychiatry = "material/psychiatry"
psychiatry_fill = "material/psychiatry:fill"
psychology = "material/psychology"
psychology_fill = "material/psychology:fill"
psychology_alt = "material/psychology-alt"
psychology_alt_fill = "material/psychology-alt:fill"
public = "material/public"
public_fill = "material/public:fill"
public_off = "material/public-off"
public_off_fill = "material/public-off:fill"
publish = "material/publish"
publish_fill = "material/publish:fill"
published_with_changes = "material/published-with-changes"
published_with_changes_fill = "material/published-with-changes:fill"
pulmonology = "material/pulmonology"
pulmonology_fill = "material/pulmonology:fill"
punch_clock = "material/punch-clock"
punch_clock_fill = "material/punch-clock:fill"
push_pin = "material/push-pin"
push_pin_fill = "material/push-pin:fill"
qr_code = "material/qr-code"
qr_code_fill = "material/qr-code:fill"
qr_code_2 = "material/qr-code-2"
qr_code_2_fill = "material/qr-code-2:fill"
qr_code_2_add = "material/qr-code-2-add"
qr_code_2_add_fill = "material/qr-code-2-add:fill"
qr_code_scanner = "material/qr-code-scanner"
qr_code_scanner_fill = "material/qr-code-scanner:fill"
query_stats = "material/query-stats"
query_stats_fill = "material/query-stats:fill"
question_exchange = "material/question-exchange"
question_exchange_fill = "material/question-exchange:fill"
question_mark = "material/question-mark"
question_mark_fill = "material/question-mark:fill"
queue_music = "material/queue-music"
queue_music_fill = "material/queue-music:fill"
queue_play_next = "material/queue-play-next"
queue_play_next_fill = "material/queue-play-next:fill"
quick_phrases = "material/quick-phrases"
quick_phrases_fill = "material/quick-phrases:fill"
quick_reference = "material/quick-reference"
quick_reference_fill = "material/quick-reference:fill"
quick_reference_all = "material/quick-reference-all"
quick_reference_all_fill = "material/quick-reference-all:fill"
quickreply = "material/quickreply"
quickreply_fill = "material/quickreply:fill"
quiet_time = "material/quiet-time"
quiet_time_fill = "material/quiet-time:fill"
quiet_time_active = "material/quiet-time-active"
quiet_time_active_fill = "material/quiet-time-active:fill"
quiz = "material/quiz"
quiz_fill = "material/quiz:fill"
r_mobiledata = "material/r-mobiledata"
r_mobiledata_fill = "material/r-mobiledata:fill"
radar = "material/radar"
radar_fill = "material/radar:fill"
radio = "material/radio"
radio_fill = "material/radio:fill"
radio_button_checked = "material/radio-button-checked"
radio_button_checked_fill = "material/radio-button-checked:fill"
radio_button_partial = "material/radio-button-partial"
radio_button_partial_fill = "material/radio-button-partial:fill"
radio_button_unchecked = "material/radio-button-unchecked"
radio_button_unchecked_fill = "material/radio-button-unchecked:fill"
radiology = "material/radiology"
radiology_fill = "material/radiology:fill"
railway_alert = "material/railway-alert"
railway_alert_fill = "material/railway-alert:fill"
rainy = "material/rainy"
rainy_fill = "material/rainy:fill"
rainy_heavy = "material/rainy-heavy"
rainy_heavy_fill = "material/rainy-heavy:fill"
rainy_light = "material/rainy-light"
rainy_light_fill = "material/rainy-light:fill"
rainy_snow = "material/rainy-snow"
rainy_snow_fill = "material/rainy-snow:fill"
ramen_dining = "material/ramen-dining"
ramen_dining_fill = "material/ramen-dining:fill"
ramp_left = "material/ramp-left"
ramp_left_fill = "material/ramp-left:fill"
ramp_right = "material/ramp-right"
ramp_right_fill = "material/ramp-right:fill"
range_hood = "material/range-hood"
range_hood_fill = "material/range-hood:fill"
rate_review = "material/rate-review"
rate_review_fill = "material/rate-review:fill"
raven = "material/raven"
raven_fill = "material/raven:fill"
raw_off = "material/raw-off"
raw_off_fill = "material/raw-off:fill"
raw_on = "material/raw-on"
raw_on_fill = "material/raw-on:fill"
read_more = "material/read-more"
read_more_fill = "material/read-more:fill"
readiness_score = "material/readiness-score"
readiness_score_fill = "material/readiness-score:fill"
real_estate_agent = "material/real-estate-agent"
real_estate_agent_fill = "material/real-estate-agent:fill"
rear_camera = "material/rear-camera"
rear_camera_fill = "material/rear-camera:fill"
rebase = "material/rebase"
rebase_fill = "material/rebase:fill"
rebase_edit = "material/rebase-edit"
rebase_edit_fill = "material/rebase-edit:fill"
receipt = "material/receipt"
receipt_fill = "material/receipt:fill"
receipt_long = "material/receipt-long"
receipt_long_fill = "material/receipt-long:fill"
recent_actors = "material/recent-actors"
recent_actors_fill = "material/recent-actors:fill"
recent_patient = "material/recent-patient"
recent_patient_fill = "material/recent-patient:fill"
recommend = "material/recommend"
recommend_fill = "material/recommend:fill"
record_voice_over = "material/record-voice-over"
record_voice_over_fill = "material/record-voice-over:fill"
rectangle = "material/rectangle"
rectangle_fill = "material/rectangle:fill"
recycling = "material/recycling"
recycling_fill = "material/recycling:fill"
redeem = "material/redeem"
redeem_fill = "material/redeem:fill"
redo = "material/redo"
redo_fill = "material/redo:fill"
reduce_capacity = "material/reduce-capacity"
reduce_capacity_fill = "material/reduce-capacity:fill"
refresh = "material/refresh"
refresh_fill = "material/refresh:fill"
regular_expression = "material/regular-expression"
regular_expression_fill = "material/regular-expression:fill"
relax = "material/relax"
relax_fill = "material/relax:fill"
release_alert = "material/release-alert"
release_alert_fill = "material/release-alert:fill"
remember_me = "material/remember-me"
remember_me_fill = "material/remember-me:fill"
reminder = "material/reminder"
reminder_fill = "material/reminder:fill"
remote_gen = "material/remote-gen"
remote_gen_fill = "material/remote-gen:fill"
remove = "material/remove"
remove_fill = "material/remove:fill"
remove_done = "material/remove-done"
remove_done_fill = "material/remove-done:fill"
remove_from_queue = "material/remove-from-queue"
remove_from_queue_fill = "material/remove-from-queue:fill"
remove_moderator = "material/remove-moderator"
remove_moderator_fill = "material/remove-moderator:fill"
remove_road = "material/remove-road"
remove_road_fill = "material/remove-road:fill"
remove_selection = "material/remove-selection"
remove_selection_fill = "material/remove-selection:fill"
remove_shopping_cart = "material/remove-shopping-cart"
remove_shopping_cart_fill = "material/remove-shopping-cart:fill"
reopen_window = "material/reopen-window"
reopen_window_fill = "material/reopen-window:fill"
reorder = "material/reorder"
reorder_fill = "material/reorder:fill"
repartition = "material/repartition"
repartition_fill = "material/repartition:fill"
repeat = "material/repeat"
repeat_fill = "material/repeat:fill"
repeat_on = "material/repeat-on"
repeat_on_fill = "material/repeat-on:fill"
repeat_one = "material/repeat-one"
repeat_one_fill = "material/repeat-one:fill"
repeat_one_on = "material/repeat-one-on"
repeat_one_on_fill = "material/repeat-one-on:fill"
replay = "material/replay"
replay_fill = "material/replay:fill"
replay_10 = "material/replay-10"
replay_10_fill = "material/replay-10:fill"
replay_30 = "material/replay-30"
replay_30_fill = "material/replay-30:fill"
replay_5 = "material/replay-5"
replay_5_fill = "material/replay-5:fill"
reply = "material/reply"
reply_fill = "material/reply:fill"
reply_all = "material/reply-all"
reply_all_fill = "material/reply-all:fill"
report = "material/report"
report_fill = "material/report:fill"
report_off = "material/report-off"
report_off_fill = "material/report-off:fill"
request_page = "material/request-page"
request_page_fill = "material/request-page:fill"
request_quote = "material/request-quote"
request_quote_fill = "material/request-quote:fill"
reset_image = "material/reset-image"
reset_image_fill = "material/reset-image:fill"
reset_tv = "material/reset-tv"
reset_tv_fill = "material/reset-tv:fill"
reset_wrench = "material/reset-wrench"
reset_wrench_fill = "material/reset-wrench:fill"
resize = "material/resize"
resize_fill = "material/resize:fill"
respiratory_rate = "material/respiratory-rate"
respiratory_rate_fill = "material/respiratory-rate:fill"
restart_alt = "material/restart-alt"
restart_alt_fill = "material/restart-alt:fill"
restaurant = "material/restaurant"
restaurant_fill = "material/restaurant:fill"
restaurant_menu = "material/restaurant-menu"
restaurant_menu_fill = "material/restaurant-menu:fill"
restore_from_trash = "material/restore-from-trash"
restore_from_trash_fill = "material/restore-from-trash:fill"
restore_page = "material/restore-page"
restore_page_fill = "material/restore-page:fill"
resume = "material/resume"
resume_fill = "material/resume:fill"
reviews = "material/reviews"
reviews_fill = "material/reviews:fill"
rewarded_ads = "material/rewarded-ads"
rewarded_ads_fill = "material/rewarded-ads:fill"
rheumatology = "material/rheumatology"
rheumatology_fill = "material/rheumatology:fill"
rib_cage = "material/rib-cage"
rib_cage_fill = "material/rib-cage:fill"
rice_bowl = "material/rice-bowl"
rice_bowl_fill = "material/rice-bowl:fill"
right_click = "material/right-click"
right_click_fill = "material/right-click:fill"
right_panel_close = "material/right-panel-close"
right_panel_close_fill = "material/right-panel-close:fill"
right_panel_open = "material/right-panel-open"
right_panel_open_fill = "material/right-panel-open:fill"
ring_volume = "material/ring-volume"
ring_volume_fill = "material/ring-volume:fill"
ripples = "material/ripples"
ripples_fill = "material/ripples:fill"
robot = "material/robot"
robot_fill = "material/robot:fill"
robot_2 = "material/robot-2"
robot_2_fill = "material/robot-2:fill"
rocket = "material/rocket"
rocket_fill = "material/rocket:fill"
rocket_launch = "material/rocket-launch"
rocket_launch_fill = "material/rocket-launch:fill"
roller_shades = "material/roller-shades"
roller_shades_fill = "material/roller-shades:fill"
roller_shades_closed = "material/roller-shades-closed"
roller_shades_closed_fill = "material/roller-shades-closed:fill"
roller_skating = "material/roller-skating"
roller_skating_fill = "material/roller-skating:fill"
roofing = "material/roofing"
roofing_fill = "material/roofing:fill"
room_preferences = "material/room-preferences"
room_preferences_fill = "material/room-preferences:fill"
room_service = "material/room-service"
room_service_fill = "material/room-service:fill"
rotate_90_degrees_ccw = "material/rotate-90-degrees-ccw"
rotate_90_degrees_ccw_fill = "material/rotate-90-degrees-ccw:fill"
rotate_90_degrees_cw = "material/rotate-90-degrees-cw"
rotate_90_degrees_cw_fill = "material/rotate-90-degrees-cw:fill"
rotate_left = "material/rotate-left"
rotate_left_fill = "material/rotate-left:fill"
rotate_right = "material/rotate-right"
rotate_right_fill = "material/rotate-right:fill"
roundabout_left = "material/roundabout-left"
roundabout_left_fill = "material/roundabout-left:fill"
roundabout_right = "material/roundabout-right"
roundabout_right_fill = "material/roundabout-right:fill"
rounded_corner = "material/rounded-corner"
rounded_corner_fill = "material/rounded-corner:fill"
route = "material/route"
route_fill = "material/route:fill"
router = "material/router"
router_fill = "material/router:fill"
routine = "material/routine"
routine_fill = "material/routine:fill"
rowing = "material/rowing"
rowing_fill = "material/rowing:fill"
rss_feed = "material/rss-feed"
rss_feed_fill = "material/rss-feed:fill"
rsvp = "material/rsvp"
rsvp_fill = "material/rsvp:fill"
rtt = "material/rtt"
rtt_fill = "material/rtt:fill"
rule = "material/rule"
rule_fill = "material/rule:fill"
rule_folder = "material/rule-folder"
rule_folder_fill = "material/rule-folder:fill"
rule_settings = "material/rule-settings"
rule_settings_fill = "material/rule-settings:fill"
run_circle = "material/run-circle"
run_circle_fill = "material/run-circle:fill"
running_with_errors = "material/running-with-errors"
running_with_errors_fill = "material/running-with-errors:fill"
rv_hookup = "material/rv-hookup"
rv_hookup_fill = "material/rv-hookup:fill"
safety_check = "material/safety-check"
safety_check_fill = "material/safety-check:fill"
safety_check_off = "material/safety-check-off"
safety_check_off_fill = "material/safety-check-off:fill"
safety_divider = "material/safety-divider"
safety_divider_fill = "material/safety-divider:fill"
sailing = "material/sailing"
sailing_fill = "material/sailing:fill"
salinity = "material/salinity"
salinity_fill = "material/salinity:fill"
sanitizer = "material/sanitizer"
sanitizer_fill = "material/sanitizer:fill"
satellite = "material/satellite"
satellite_fill = "material/satellite:fill"
satellite_alt = "material/satellite-alt"
satellite_alt_fill = "material/satellite-alt:fill"
sauna = "material/sauna"
sauna_fill = "material/sauna:fill"
save = "material/save"
save_fill = "material/save:fill"
save_as = "material/save-as"
save_as_fill = "material/save-as:fill"
saved_search = "material/saved-search"
saved_search_fill = "material/saved-search:fill"
savings = "material/savings"
savings_fill = "material/savings:fill"
scale = "material/scale"
scale_fill = "material/scale:fill"
scan = "material/scan"
scan_fill = "material/scan:fill"
scan_delete = "material/scan-delete"
scan_delete_fill = "material/scan-delete:fill"
scanner = "material/scanner"
scanner_fill = "material/scanner:fill"
scatter_plot = "material/scatter-plot"
scatter_plot_fill = "material/scatter-plot:fill"
scene = "material/scene"
scene_fill = "material/scene:fill"
schedule = "material/schedule"
schedule_fill = "material/schedule:fill"
schedule_send = "material/schedule-send"
schedule_send_fill = "material/schedule-send:fill"
schema = "material/schema"
schema_fill = "material/schema:fill"
school = "material/school"
school_fill = "material/school:fill"
science = "material/science"
science_fill = "material/science:fill"
score = "material/score"
score_fill = "material/score:fill"
scoreboard = "material/scoreboard"
scoreboard_fill = "material/scoreboard:fill"
screen_lock_landscape = "material/screen-lock-landscape"
screen_lock_landscape_fill = "material/screen-lock-landscape:fill"
screen_lock_portrait = "material/screen-lock-portrait"
screen_lock_portrait_fill = "material/screen-lock-portrait:fill"
screen_lock_rotation = "material/screen-lock-rotation"
screen_lock_rotation_fill = "material/screen-lock-rotation:fill"
screen_record = "material/screen-record"
screen_record_fill = "material/screen-record:fill"
screen_rotation = "material/screen-rotation"
screen_rotation_fill = "material/screen-rotation:fill"
screen_rotation_alt = "material/screen-rotation-alt"
screen_rotation_alt_fill = "material/screen-rotation-alt:fill"
screen_rotation_up = "material/screen-rotation-up"
screen_rotation_up_fill = "material/screen-rotation-up:fill"
screen_search_desktop = "material/screen-search-desktop"
screen_search_desktop_fill = "material/screen-search-desktop:fill"
screen_share = "material/screen-share"
screen_share_fill = "material/screen-share:fill"
screenshot = "material/screenshot"
screenshot_fill = "material/screenshot:fill"
screenshot_frame = "material/screenshot-frame"
screenshot_frame_fill = "material/screenshot-frame:fill"
screenshot_keyboard = "material/screenshot-keyboard"
screenshot_keyboard_fill = "material/screenshot-keyboard:fill"
screenshot_monitor = "material/screenshot-monitor"
screenshot_monitor_fill = "material/screenshot-monitor:fill"
screenshot_region = "material/screenshot-region"
screenshot_region_fill = "material/screenshot-region:fill"
screenshot_tablet = "material/screenshot-tablet"
screenshot_tablet_fill = "material/screenshot-tablet:fill"
scrollable_header = "material/scrollable-header"
scrollable_header_fill = "material/scrollable-header:fill"
scuba_diving = "material/scuba-diving"
scuba_diving_fill = "material/scuba-diving:fill"
sd = "material/sd"
sd_fill = "material/sd:fill"
sd_card = "material/sd-card"
sd_card_fill = "material/sd-card:fill"
sd_card_alert = "material/sd-card-alert"
sd_card_alert_fill = "material/sd-card-alert:fill"
search = "material/search"
search_fill = "material/search:fill"
search_check = "material/search-check"
search_check_fill = "material/search-check:fill"
search_off = "material/search-off"
search_off_fill = "material/search-off:fill"
security = "material/security"
security_fill = "material/security:fill"
security_update_good = "material/security-update-good"
security_update_good_fill = "material/security-update-good:fill"
security_update_warning = "material/security-update-warning"
security_update_warning_fill = "material/security-update-warning:fill"
segment = "material/segment"
segment_fill = "material/segment:fill"
select = "material/select"
select_fill = "material/select:fill"
select_all = "material/select-all"
select_all_fill = "material/select-all:fill"
select_check_box = "material/select-check-box"
select_check_box_fill = "material/select-check-box:fill"
select_to_speak = "material/select-to-speak"
select_to_speak_fill = "material/select-to-speak:fill"
select_window = "material/select-window"
select_window_fill = "material/select-window:fill"
select_window_off = "material/select-window-off"
select_window_off_fill = "material/select-window-off:fill"
self_care = "material/self-care"
self_care_fill = "material/self-care:fill"
self_improvement = "material/self-improvement"
self_improvement_fill = "material/self-improvement:fill"
sell = "material/sell"
sell_fill = "material/sell:fill"
send = "material/send"
send_fill = "material/send:fill"
send_and_archive = "material/send-and-archive"
send_and_archive_fill = "material/send-and-archive:fill"
send_money = "material/send-money"
send_money_fill = "material/send-money:fill"
send_time_extension = "material/send-time-extension"
send_time_extension_fill = "material/send-time-extension:fill"
send_to_mobile = "material/send-to-mobile"
send_to_mobile_fill = "material/send-to-mobile:fill"
sensor_door = "material/sensor-door"
sensor_door_fill = "material/sensor-door:fill"
sensor_occupied = "material/sensor-occupied"
sensor_occupied_fill = "material/sensor-occupied:fill"
sensor_window = "material/sensor-window"
sensor_window_fill = "material/sensor-window:fill"
sensors = "material/sensors"
sensors_fill = "material/sensors:fill"
sensors_krx = "material/sensors-krx"
sensors_krx_fill = "material/sensors-krx:fill"
sensors_off = "material/sensors-off"
sensors_off_fill = "material/sensors-off:fill"
sentiment_calm = "material/sentiment-calm"
sentiment_calm_fill = "material/sentiment-calm:fill"
sentiment_content = "material/sentiment-content"
sentiment_content_fill = "material/sentiment-content:fill"
sentiment_dissatisfied = "material/sentiment-dissatisfied"
sentiment_dissatisfied_fill = "material/sentiment-dissatisfied:fill"
sentiment_excited = "material/sentiment-excited"
sentiment_excited_fill = "material/sentiment-excited:fill"
sentiment_extremely_dissatisfied = "material/sentiment-extremely-dissatisfied"
sentiment_extremely_dissatisfied_fill = (
    "material/sentiment-extremely-dissatisfied:fill"
)
sentiment_frustrated = "material/sentiment-frustrated"
sentiment_frustrated_fill = "material/sentiment-frustrated:fill"
sentiment_neutral = "material/sentiment-neutral"
sentiment_neutral_fill = "material/sentiment-neutral:fill"
sentiment_sad = "material/sentiment-sad"
sentiment_sad_fill = "material/sentiment-sad:fill"
sentiment_satisfied = "material/sentiment-satisfied"
sentiment_satisfied_fill = "material/sentiment-satisfied:fill"
sentiment_stressed = "material/sentiment-stressed"
sentiment_stressed_fill = "material/sentiment-stressed:fill"
sentiment_very_dissatisfied = "material/sentiment-very-dissatisfied"
sentiment_very_dissatisfied_fill = "material/sentiment-very-dissatisfied:fill"
sentiment_very_satisfied = "material/sentiment-very-satisfied"
sentiment_very_satisfied_fill = "material/sentiment-very-satisfied:fill"
sentiment_worried = "material/sentiment-worried"
sentiment_worried_fill = "material/sentiment-worried:fill"
set_meal = "material/set-meal"
set_meal_fill = "material/set-meal:fill"
settings = "material/settings"
settings_fill = "material/settings:fill"
settings_accessibility = "material/settings-accessibility"
settings_accessibility_fill = "material/settings-accessibility:fill"
settings_account_box = "material/settings-account-box"
settings_account_box_fill = "material/settings-account-box:fill"
settings_alert = "material/settings-alert"
settings_alert_fill = "material/settings-alert:fill"
settings_applications = "material/settings-applications"
settings_applications_fill = "material/settings-applications:fill"
settings_b_roll = "material/settings-b-roll"
settings_b_roll_fill = "material/settings-b-roll:fill"
settings_backup_restore = "material/settings-backup-restore"
settings_backup_restore_fill = "material/settings-backup-restore:fill"
settings_bluetooth = "material/settings-bluetooth"
settings_bluetooth_fill = "material/settings-bluetooth:fill"
settings_brightness = "material/settings-brightness"
settings_brightness_fill = "material/settings-brightness:fill"
settings_cell = "material/settings-cell"
settings_cell_fill = "material/settings-cell:fill"
settings_cinematic_blur = "material/settings-cinematic-blur"
settings_cinematic_blur_fill = "material/settings-cinematic-blur:fill"
settings_ethernet = "material/settings-ethernet"
settings_ethernet_fill = "material/settings-ethernet:fill"
settings_input_antenna = "material/settings-input-antenna"
settings_input_antenna_fill = "material/settings-input-antenna:fill"
settings_input_component = "material/settings-input-component"
settings_input_component_fill = "material/settings-input-component:fill"
settings_input_hdmi = "material/settings-input-hdmi"
settings_input_hdmi_fill = "material/settings-input-hdmi:fill"
settings_input_svideo = "material/settings-input-svideo"
settings_input_svideo_fill = "material/settings-input-svideo:fill"
settings_motion_mode = "material/settings-motion-mode"
settings_motion_mode_fill = "material/settings-motion-mode:fill"
settings_night_sight = "material/settings-night-sight"
settings_night_sight_fill = "material/settings-night-sight:fill"
settings_overscan = "material/settings-overscan"
settings_overscan_fill = "material/settings-overscan:fill"
settings_panorama = "material/settings-panorama"
settings_panorama_fill = "material/settings-panorama:fill"
settings_phone = "material/settings-phone"
settings_phone_fill = "material/settings-phone:fill"
settings_photo_camera = "material/settings-photo-camera"
settings_photo_camera_fill = "material/settings-photo-camera:fill"
settings_power = "material/settings-power"
settings_power_fill = "material/settings-power:fill"
settings_remote = "material/settings-remote"
settings_remote_fill = "material/settings-remote:fill"
settings_slow_motion = "material/settings-slow-motion"
settings_slow_motion_fill = "material/settings-slow-motion:fill"
settings_system_daydream = "material/settings-system-daydream"
settings_system_daydream_fill = "material/settings-system-daydream:fill"
settings_timelapse = "material/settings-timelapse"
settings_timelapse_fill = "material/settings-timelapse:fill"
settings_video_camera = "material/settings-video-camera"
settings_video_camera_fill = "material/settings-video-camera:fill"
settings_voice = "material/settings-voice"
settings_voice_fill = "material/settings-voice:fill"
settop_component = "material/settop-component"
settop_component_fill = "material/settop-component:fill"
severe_cold = "material/severe-cold"
severe_cold_fill = "material/severe-cold:fill"
shadow = "material/shadow"
shadow_fill = "material/shadow:fill"
shadow_add = "material/shadow-add"
shadow_add_fill = "material/shadow-add:fill"
shadow_minus = "material/shadow-minus"
shadow_minus_fill = "material/shadow-minus:fill"
shape_line = "material/shape-line"
shape_line_fill = "material/shape-line:fill"
shapes = "material/shapes"
shapes_fill = "material/shapes:fill"
share = "material/share"
share_fill = "material/share:fill"
share_location = "material/share-location"
share_location_fill = "material/share-location:fill"
share_off = "material/share-off"
share_off_fill = "material/share-off:fill"
share_reviews = "material/share-reviews"
share_reviews_fill = "material/share-reviews:fill"
share_windows = "material/share-windows"
share_windows_fill = "material/share-windows:fill"
sheets_rtl = "material/sheets-rtl"
sheets_rtl_fill = "material/sheets-rtl:fill"
shelf_auto_hide = "material/shelf-auto-hide"
shelf_auto_hide_fill = "material/shelf-auto-hide:fill"
shelf_position = "material/shelf-position"
shelf_position_fill = "material/shelf-position:fill"
shelves = "material/shelves"
shelves_fill = "material/shelves:fill"
shield = "material/shield"
shield_fill = "material/shield:fill"
shield_lock = "material/shield-lock"
shield_lock_fill = "material/shield-lock:fill"
shield_locked = "material/shield-locked"
shield_locked_fill = "material/shield-locked:fill"
shield_moon = "material/shield-moon"
shield_moon_fill = "material/shield-moon:fill"
shield_person = "material/shield-person"
shield_person_fill = "material/shield-person:fill"
shield_spark = "material/shield-spark"
shield_spark_fill = "material/shield-spark:fill"
shield_with_heart = "material/shield-with-heart"
shield_with_heart_fill = "material/shield-with-heart:fill"
shield_with_house = "material/shield-with-house"
shield_with_house_fill = "material/shield-with-house:fill"
shift = "material/shift"
shift_fill = "material/shift:fill"
shift_lock = "material/shift-lock"
shift_lock_fill = "material/shift-lock:fill"
shop = "material/shop"
shop_fill = "material/shop:fill"
shop_two = "material/shop-two"
shop_two_fill = "material/shop-two:fill"
shopping_bag = "material/shopping-bag"
shopping_bag_fill = "material/shopping-bag:fill"
shopping_basket = "material/shopping-basket"
shopping_basket_fill = "material/shopping-basket:fill"
shopping_cart = "material/shopping-cart"
shopping_cart_fill = "material/shopping-cart:fill"
shopping_cart_checkout = "material/shopping-cart-checkout"
shopping_cart_checkout_fill = "material/shopping-cart-checkout:fill"
short_stay = "material/short-stay"
short_stay_fill = "material/short-stay:fill"
short_text = "material/short-text"
short_text_fill = "material/short-text:fill"
show_chart = "material/show-chart"
show_chart_fill = "material/show-chart:fill"
shower = "material/shower"
shower_fill = "material/shower:fill"
shuffle = "material/shuffle"
shuffle_fill = "material/shuffle:fill"
shuffle_on = "material/shuffle-on"
shuffle_on_fill = "material/shuffle-on:fill"
shutter_speed = "material/shutter-speed"
shutter_speed_fill = "material/shutter-speed:fill"
shutter_speed_add = "material/shutter-speed-add"
shutter_speed_add_fill = "material/shutter-speed-add:fill"
shutter_speed_minus = "material/shutter-speed-minus"
shutter_speed_minus_fill = "material/shutter-speed-minus:fill"
sick = "material/sick"
sick_fill = "material/sick:fill"
side_navigation = "material/side-navigation"
side_navigation_fill = "material/side-navigation:fill"
sign_language = "material/sign-language"
sign_language_fill = "material/sign-language:fill"
signal_cellular_0_bar = "material/signal-cellular-0-bar"
signal_cellular_0_bar_fill = "material/signal-cellular-0-bar:fill"
signal_cellular_1_bar = "material/signal-cellular-1-bar"
signal_cellular_1_bar_fill = "material/signal-cellular-1-bar:fill"
signal_cellular_2_bar = "material/signal-cellular-2-bar"
signal_cellular_2_bar_fill = "material/signal-cellular-2-bar:fill"
signal_cellular_3_bar = "material/signal-cellular-3-bar"
signal_cellular_3_bar_fill = "material/signal-cellular-3-bar:fill"
signal_cellular_4_bar = "material/signal-cellular-4-bar"
signal_cellular_4_bar_fill = "material/signal-cellular-4-bar:fill"
signal_cellular_add = "material/signal-cellular-add"
signal_cellular_add_fill = "material/signal-cellular-add:fill"
signal_cellular_alt = "material/signal-cellular-alt"
signal_cellular_alt_fill = "material/signal-cellular-alt:fill"
signal_cellular_alt_1_bar = "material/signal-cellular-alt-1-bar"
signal_cellular_alt_1_bar_fill = "material/signal-cellular-alt-1-bar:fill"
signal_cellular_alt_2_bar = "material/signal-cellular-alt-2-bar"
signal_cellular_alt_2_bar_fill = "material/signal-cellular-alt-2-bar:fill"
signal_cellular_connected_no_internet_0_bar = (
    "material/signal-cellular-connected-no-internet-0-bar"
)
signal_cellular_connected_no_internet_0_bar_fill = (
    "material/signal-cellular-connected-no-internet-0-bar:fill"
)
signal_cellular_connected_no_internet_4_bar = (
    "material/signal-cellular-connected-no-internet-4-bar"
)
signal_cellular_connected_no_internet_4_bar_fill = (
    "material/signal-cellular-connected-no-internet-4-bar:fill"
)
signal_cellular_nodata = "material/signal-cellular-nodata"
signal_cellular_nodata_fill = "material/signal-cellular-nodata:fill"
signal_cellular_null = "material/signal-cellular-null"
signal_cellular_null_fill = "material/signal-cellular-null:fill"
signal_cellular_off = "material/signal-cellular-off"
signal_cellular_off_fill = "material/signal-cellular-off:fill"
signal_cellular_pause = "material/signal-cellular-pause"
signal_cellular_pause_fill = "material/signal-cellular-pause:fill"
signal_disconnected = "material/signal-disconnected"
signal_disconnected_fill = "material/signal-disconnected:fill"
signal_wifi_0_bar = "material/signal-wifi-0-bar"
signal_wifi_0_bar_fill = "material/signal-wifi-0-bar:fill"
signal_wifi_4_bar = "material/signal-wifi-4-bar"
signal_wifi_4_bar_fill = "material/signal-wifi-4-bar:fill"
signal_wifi_bad = "material/signal-wifi-bad"
signal_wifi_bad_fill = "material/signal-wifi-bad:fill"
signal_wifi_off = "material/signal-wifi-off"
signal_wifi_off_fill = "material/signal-wifi-off:fill"
signal_wifi_statusbar_not_connected = (
    "material/signal-wifi-statusbar-not-connected"
)
signal_wifi_statusbar_not_connected_fill = (
    "material/signal-wifi-statusbar-not-connected:fill"
)
signal_wifi_statusbar_null = "material/signal-wifi-statusbar-null"
signal_wifi_statusbar_null_fill = "material/signal-wifi-statusbar-null:fill"
signature = "material/signature"
signature_fill = "material/signature:fill"
signpost = "material/signpost"
signpost_fill = "material/signpost:fill"
sim_card = "material/sim-card"
sim_card_fill = "material/sim-card:fill"
sim_card_download = "material/sim-card-download"
sim_card_download_fill = "material/sim-card-download:fill"
single_bed = "material/single-bed"
single_bed_fill = "material/single-bed:fill"
sip = "material/sip"
sip_fill = "material/sip:fill"
skateboarding = "material/skateboarding"
skateboarding_fill = "material/skateboarding:fill"
skeleton = "material/skeleton"
skeleton_fill = "material/skeleton:fill"
skip_next = "material/skip-next"
skip_next_fill = "material/skip-next:fill"
skip_previous = "material/skip-previous"
skip_previous_fill = "material/skip-previous:fill"
skull = "material/skull"
skull_fill = "material/skull:fill"
sledding = "material/sledding"
sledding_fill = "material/sledding:fill"
sleep_score = "material/sleep-score"
sleep_score_fill = "material/sleep-score:fill"
slide_library = "material/slide-library"
slide_library_fill = "material/slide-library:fill"
sliders = "material/sliders"
sliders_fill = "material/sliders:fill"
slideshow = "material/slideshow"
slideshow_fill = "material/slideshow:fill"
slow_motion_video = "material/slow-motion-video"
slow_motion_video_fill = "material/slow-motion-video:fill"
smart_display = "material/smart-display"
smart_display_fill = "material/smart-display:fill"
smart_outlet = "material/smart-outlet"
smart_outlet_fill = "material/smart-outlet:fill"
smart_screen = "material/smart-screen"
smart_screen_fill = "material/smart-screen:fill"
smart_toy = "material/smart-toy"
smart_toy_fill = "material/smart-toy:fill"
smart_ventilation = "material/smart-ventilation"
smart_ventilation_fill = "material/smart-ventilation:fill"
smartphone = "material/smartphone"
smartphone_fill = "material/smartphone:fill"
smb_share = "material/smb-share"
smb_share_fill = "material/smb-share:fill"
smoke_free = "material/smoke-free"
smoke_free_fill = "material/smoke-free:fill"
smoking_rooms = "material/smoking-rooms"
smoking_rooms_fill = "material/smoking-rooms:fill"
sms = "material/sms"
sms_fill = "material/sms:fill"
snippet_folder = "material/snippet-folder"
snippet_folder_fill = "material/snippet-folder:fill"
snooze = "material/snooze"
snooze_fill = "material/snooze:fill"
snowboarding = "material/snowboarding"
snowboarding_fill = "material/snowboarding:fill"
snowing = "material/snowing"
snowing_fill = "material/snowing:fill"
snowing_heavy = "material/snowing-heavy"
snowing_heavy_fill = "material/snowing-heavy:fill"
snowmobile = "material/snowmobile"
snowmobile_fill = "material/snowmobile:fill"
snowshoeing = "material/snowshoeing"
snowshoeing_fill = "material/snowshoeing:fill"
soap = "material/soap"
soap_fill = "material/soap:fill"
social_distance = "material/social-distance"
social_distance_fill = "material/social-distance:fill"
social_leaderboard = "material/social-leaderboard"
social_leaderboard_fill = "material/social-leaderboard:fill"
solar_power = "material/solar-power"
solar_power_fill = "material/solar-power:fill"
sort = "material/sort"
sort_fill = "material/sort:fill"
sort_by_alpha = "material/sort-by-alpha"
sort_by_alpha_fill = "material/sort-by-alpha:fill"
sos = "material/sos"
sos_fill = "material/sos:fill"
sound_detection_dog_barking = "material/sound-detection-dog-barking"
sound_detection_dog_barking_fill = "material/sound-detection-dog-barking:fill"
sound_detection_glass_break = "material/sound-detection-glass-break"
sound_detection_glass_break_fill = "material/sound-detection-glass-break:fill"
sound_detection_loud_sound = "material/sound-detection-loud-sound"
sound_detection_loud_sound_fill = "material/sound-detection-loud-sound:fill"
sound_sampler = "material/sound-sampler"
sound_sampler_fill = "material/sound-sampler:fill"
soup_kitchen = "material/soup-kitchen"
soup_kitchen_fill = "material/soup-kitchen:fill"
source_notes = "material/source-notes"
source_notes_fill = "material/source-notes:fill"
south = "material/south"
south_fill = "material/south:fill"
south_america = "material/south-america"
south_america_fill = "material/south-america:fill"
south_east = "material/south-east"
south_east_fill = "material/south-east:fill"
south_west = "material/south-west"
south_west_fill = "material/south-west:fill"
spa = "material/spa"
spa_fill = "material/spa:fill"
space_bar = "material/space-bar"
space_bar_fill = "material/space-bar:fill"
space_dashboard = "material/space-dashboard"
space_dashboard_fill = "material/space-dashboard:fill"
spatial_audio = "material/spatial-audio"
spatial_audio_fill = "material/spatial-audio:fill"
spatial_audio_off = "material/spatial-audio-off"
spatial_audio_off_fill = "material/spatial-audio-off:fill"
spatial_tracking = "material/spatial-tracking"
spatial_tracking_fill = "material/spatial-tracking:fill"
speaker = "material/speaker"
speaker_fill = "material/speaker:fill"
speaker_group = "material/speaker-group"
speaker_group_fill = "material/speaker-group:fill"
speaker_notes = "material/speaker-notes"
speaker_notes_fill = "material/speaker-notes:fill"
speaker_notes_off = "material/speaker-notes-off"
speaker_notes_off_fill = "material/speaker-notes-off:fill"
speaker_phone = "material/speaker-phone"
speaker_phone_fill = "material/speaker-phone:fill"
special_character = "material/special-character"
special_character_fill = "material/special-character:fill"
specific_gravity = "material/specific-gravity"
specific_gravity_fill = "material/specific-gravity:fill"
speech_to_text = "material/speech-to-text"
speech_to_text_fill = "material/speech-to-text:fill"
speed = "material/speed"
speed_fill = "material/speed:fill"
spellcheck = "material/spellcheck"
spellcheck_fill = "material/spellcheck:fill"
splitscreen = "material/splitscreen"
splitscreen_fill = "material/splitscreen:fill"
splitscreen_bottom = "material/splitscreen-bottom"
splitscreen_bottom_fill = "material/splitscreen-bottom:fill"
splitscreen_left = "material/splitscreen-left"
splitscreen_left_fill = "material/splitscreen-left:fill"
splitscreen_right = "material/splitscreen-right"
splitscreen_right_fill = "material/splitscreen-right:fill"
splitscreen_top = "material/splitscreen-top"
splitscreen_top_fill = "material/splitscreen-top:fill"
spo2 = "material/spo2"
spo2_fill = "material/spo2:fill"
spoke = "material/spoke"
spoke_fill = "material/spoke:fill"
sports = "material/sports"
sports_fill = "material/sports:fill"
sports_bar = "material/sports-bar"
sports_bar_fill = "material/sports-bar:fill"
sports_baseball = "material/sports-baseball"
sports_baseball_fill = "material/sports-baseball:fill"
sports_basketball = "material/sports-basketball"
sports_basketball_fill = "material/sports-basketball:fill"
sports_cricket = "material/sports-cricket"
sports_cricket_fill = "material/sports-cricket:fill"
sports_esports = "material/sports-esports"
sports_esports_fill = "material/sports-esports:fill"
sports_football = "material/sports-football"
sports_football_fill = "material/sports-football:fill"
sports_golf = "material/sports-golf"
sports_golf_fill = "material/sports-golf:fill"
sports_gymnastics = "material/sports-gymnastics"
sports_gymnastics_fill = "material/sports-gymnastics:fill"
sports_handball = "material/sports-handball"
sports_handball_fill = "material/sports-handball:fill"
sports_hockey = "material/sports-hockey"
sports_hockey_fill = "material/sports-hockey:fill"
sports_kabaddi = "material/sports-kabaddi"
sports_kabaddi_fill = "material/sports-kabaddi:fill"
sports_martial_arts = "material/sports-martial-arts"
sports_martial_arts_fill = "material/sports-martial-arts:fill"
sports_mma = "material/sports-mma"
sports_mma_fill = "material/sports-mma:fill"
sports_motorsports = "material/sports-motorsports"
sports_motorsports_fill = "material/sports-motorsports:fill"
sports_rugby = "material/sports-rugby"
sports_rugby_fill = "material/sports-rugby:fill"
sports_score = "material/sports-score"
sports_score_fill = "material/sports-score:fill"
sports_soccer = "material/sports-soccer"
sports_soccer_fill = "material/sports-soccer:fill"
sports_tennis = "material/sports-tennis"
sports_tennis_fill = "material/sports-tennis:fill"
sports_volleyball = "material/sports-volleyball"
sports_volleyball_fill = "material/sports-volleyball:fill"
sprinkler = "material/sprinkler"
sprinkler_fill = "material/sprinkler:fill"
sprint = "material/sprint"
sprint_fill = "material/sprint:fill"
square = "material/square"
square_fill = "material/square:fill"
square_foot = "material/square-foot"
square_foot_fill = "material/square-foot:fill"
ssid_chart = "material/ssid-chart"
ssid_chart_fill = "material/ssid-chart:fill"
stack = "material/stack"
stack_fill = "material/stack:fill"
stack_off = "material/stack-off"
stack_off_fill = "material/stack-off:fill"
stack_star = "material/stack-star"
stack_star_fill = "material/stack-star:fill"
stacked_bar_chart = "material/stacked-bar-chart"
stacked_bar_chart_fill = "material/stacked-bar-chart:fill"
stacked_email = "material/stacked-email"
stacked_email_fill = "material/stacked-email:fill"
stacked_inbox = "material/stacked-inbox"
stacked_inbox_fill = "material/stacked-inbox:fill"
stacked_line_chart = "material/stacked-line-chart"
stacked_line_chart_fill = "material/stacked-line-chart:fill"
stadia_controller = "material/stadia-controller"
stadia_controller_fill = "material/stadia-controller:fill"
stadium = "material/stadium"
stadium_fill = "material/stadium:fill"
stairs = "material/stairs"
stairs_fill = "material/stairs:fill"
star = "material/star"
star_fill = "material/star:fill"
star_half = "material/star-half"
star_half_fill = "material/star-half:fill"
star_rate = "material/star-rate"
star_rate_fill = "material/star-rate:fill"
star_rate_half = "material/star-rate-half"
star_rate_half_fill = "material/star-rate-half:fill"
stars = "material/stars"
stars_fill = "material/stars:fill"
start = "material/start"
start_fill = "material/start:fill"
stat_1 = "material/stat-1"
stat_1_fill = "material/stat-1:fill"
stat_2 = "material/stat-2"
stat_2_fill = "material/stat-2:fill"
stat_3 = "material/stat-3"
stat_3_fill = "material/stat-3:fill"
stat_minus_1 = "material/stat-minus-1"
stat_minus_1_fill = "material/stat-minus-1:fill"
stat_minus_2 = "material/stat-minus-2"
stat_minus_2_fill = "material/stat-minus-2:fill"
stat_minus_3 = "material/stat-minus-3"
stat_minus_3_fill = "material/stat-minus-3:fill"
stay_current_landscape = "material/stay-current-landscape"
stay_current_landscape_fill = "material/stay-current-landscape:fill"
stay_current_portrait = "material/stay-current-portrait"
stay_current_portrait_fill = "material/stay-current-portrait:fill"
stay_primary_landscape = "material/stay-primary-landscape"
stay_primary_landscape_fill = "material/stay-primary-landscape:fill"
stay_primary_portrait = "material/stay-primary-portrait"
stay_primary_portrait_fill = "material/stay-primary-portrait:fill"
step = "material/step"
step_fill = "material/step:fill"
step_into = "material/step-into"
step_into_fill = "material/step-into:fill"
step_out = "material/step-out"
step_out_fill = "material/step-out:fill"
step_over = "material/step-over"
step_over_fill = "material/step-over:fill"
steppers = "material/steppers"
steppers_fill = "material/steppers:fill"
steps = "material/steps"
steps_fill = "material/steps:fill"
stethoscope = "material/stethoscope"
stethoscope_fill = "material/stethoscope:fill"
stethoscope_arrow = "material/stethoscope-arrow"
stethoscope_arrow_fill = "material/stethoscope-arrow:fill"
stethoscope_check = "material/stethoscope-check"
stethoscope_check_fill = "material/stethoscope-check:fill"
sticky_note = "material/sticky-note"
sticky_note_fill = "material/sticky-note:fill"
sticky_note_2 = "material/sticky-note-2"
sticky_note_2_fill = "material/sticky-note-2:fill"
stock_media = "material/stock-media"
stock_media_fill = "material/stock-media:fill"
stop = "material/stop"
stop_fill = "material/stop:fill"
stop_circle = "material/stop-circle"
stop_circle_fill = "material/stop-circle:fill"
stop_screen_share = "material/stop-screen-share"
stop_screen_share_fill = "material/stop-screen-share:fill"
storage = "material/storage"
storage_fill = "material/storage:fill"
store = "material/store"
store_fill = "material/store:fill"
storefront = "material/storefront"
storefront_fill = "material/storefront:fill"
storm = "material/storm"
storm_fill = "material/storm:fill"
straight = "material/straight"
straight_fill = "material/straight:fill"
straighten = "material/straighten"
straighten_fill = "material/straighten:fill"
strategy = "material/strategy"
strategy_fill = "material/strategy:fill"
stream = "material/stream"
stream_fill = "material/stream:fill"
stream_apps = "material/stream-apps"
stream_apps_fill = "material/stream-apps:fill"
streetview = "material/streetview"
streetview_fill = "material/streetview:fill"
stress_management = "material/stress-management"
stress_management_fill = "material/stress-management:fill"
strikethrough_s = "material/strikethrough-s"
strikethrough_s_fill = "material/strikethrough-s:fill"
stroke_full = "material/stroke-full"
stroke_full_fill = "material/stroke-full:fill"
stroke_partial = "material/stroke-partial"
stroke_partial_fill = "material/stroke-partial:fill"
stroller = "material/stroller"
stroller_fill = "material/stroller:fill"
style = "material/style"
style_fill = "material/style:fill"
styler = "material/styler"
styler_fill = "material/styler:fill"
stylus = "material/stylus"
stylus_fill = "material/stylus:fill"
stylus_laser_pointer = "material/stylus-laser-pointer"
stylus_laser_pointer_fill = "material/stylus-laser-pointer:fill"
stylus_note = "material/stylus-note"
stylus_note_fill = "material/stylus-note:fill"
subdirectory_arrow_left = "material/subdirectory-arrow-left"
subdirectory_arrow_left_fill = "material/subdirectory-arrow-left:fill"
subdirectory_arrow_right = "material/subdirectory-arrow-right"
subdirectory_arrow_right_fill = "material/subdirectory-arrow-right:fill"
subheader = "material/subheader"
subheader_fill = "material/subheader:fill"
subject = "material/subject"
subject_fill = "material/subject:fill"
subscript = "material/subscript"
subscript_fill = "material/subscript:fill"
subscriptions = "material/subscriptions"
subscriptions_fill = "material/subscriptions:fill"
subtitles = "material/subtitles"
subtitles_fill = "material/subtitles:fill"
subtitles_off = "material/subtitles-off"
subtitles_off_fill = "material/subtitles-off:fill"
subway = "material/subway"
subway_fill = "material/subway:fill"
summarize = "material/summarize"
summarize_fill = "material/summarize:fill"
sunny = "material/sunny"
sunny_fill = "material/sunny:fill"
sunny_snowing = "material/sunny-snowing"
sunny_snowing_fill = "material/sunny-snowing:fill"
superscript = "material/superscript"
superscript_fill = "material/superscript:fill"
supervised_user_circle = "material/supervised-user-circle"
supervised_user_circle_fill = "material/supervised-user-circle:fill"
supervised_user_circle_off = "material/supervised-user-circle-off"
supervised_user_circle_off_fill = "material/supervised-user-circle-off:fill"
supervisor_account = "material/supervisor-account"
supervisor_account_fill = "material/supervisor-account:fill"
support = "material/support"
support_fill = "material/support:fill"
support_agent = "material/support-agent"
support_agent_fill = "material/support-agent:fill"
surfing = "material/surfing"
surfing_fill = "material/surfing:fill"
surgical = "material/surgical"
surgical_fill = "material/surgical:fill"
surround_sound = "material/surround-sound"
surround_sound_fill = "material/surround-sound:fill"
swap_calls = "material/swap-calls"
swap_calls_fill = "material/swap-calls:fill"
swap_driving_apps_wheel = "material/swap-driving-apps-wheel"
swap_driving_apps_wheel_fill = "material/swap-driving-apps-wheel:fill"
swap_horiz = "material/swap-horiz"
swap_horiz_fill = "material/swap-horiz:fill"
swap_horizontal_circle = "material/swap-horizontal-circle"
swap_horizontal_circle_fill = "material/swap-horizontal-circle:fill"
swap_vert = "material/swap-vert"
swap_vert_fill = "material/swap-vert:fill"
swap_vertical_circle = "material/swap-vertical-circle"
swap_vertical_circle_fill = "material/swap-vertical-circle:fill"
sweep = "material/sweep"
sweep_fill = "material/sweep:fill"
swipe = "material/swipe"
swipe_fill = "material/swipe:fill"
swipe_down = "material/swipe-down"
swipe_down_fill = "material/swipe-down:fill"
swipe_down_alt = "material/swipe-down-alt"
swipe_down_alt_fill = "material/swipe-down-alt:fill"
swipe_left = "material/swipe-left"
swipe_left_fill = "material/swipe-left:fill"
swipe_left_alt = "material/swipe-left-alt"
swipe_left_alt_fill = "material/swipe-left-alt:fill"
swipe_right = "material/swipe-right"
swipe_right_fill = "material/swipe-right:fill"
swipe_right_alt = "material/swipe-right-alt"
swipe_right_alt_fill = "material/swipe-right-alt:fill"
swipe_up = "material/swipe-up"
swipe_up_fill = "material/swipe-up:fill"
swipe_up_alt = "material/swipe-up-alt"
swipe_up_alt_fill = "material/swipe-up-alt:fill"
swipe_vertical = "material/swipe-vertical"
swipe_vertical_fill = "material/swipe-vertical:fill"
switch = "material/switch"
switch_fill = "material/switch:fill"
switch_access = "material/switch-access"
switch_access_fill = "material/switch-access:fill"
switch_access_shortcut = "material/switch-access-shortcut"
switch_access_shortcut_fill = "material/switch-access-shortcut:fill"
switch_access_shortcut_add = "material/switch-access-shortcut-add"
switch_access_shortcut_add_fill = "material/switch-access-shortcut-add:fill"
switch_account = "material/switch-account"
switch_account_fill = "material/switch-account:fill"
switch_camera = "material/switch-camera"
switch_camera_fill = "material/switch-camera:fill"
switch_left = "material/switch-left"
switch_left_fill = "material/switch-left:fill"
switch_right = "material/switch-right"
switch_right_fill = "material/switch-right:fill"
switch_video = "material/switch-video"
switch_video_fill = "material/switch-video:fill"
switches = "material/switches"
switches_fill = "material/switches:fill"
sword_rose = "material/sword-rose"
sword_rose_fill = "material/sword-rose:fill"
swords = "material/swords"
swords_fill = "material/swords:fill"
symptoms = "material/symptoms"
symptoms_fill = "material/symptoms:fill"
synagogue = "material/synagogue"
synagogue_fill = "material/synagogue:fill"
sync = "material/sync"
sync_fill = "material/sync:fill"
sync_alt = "material/sync-alt"
sync_alt_fill = "material/sync-alt:fill"
sync_disabled = "material/sync-disabled"
sync_disabled_fill = "material/sync-disabled:fill"
sync_lock = "material/sync-lock"
sync_lock_fill = "material/sync-lock:fill"
sync_problem = "material/sync-problem"
sync_problem_fill = "material/sync-problem:fill"
sync_saved_locally = "material/sync-saved-locally"
sync_saved_locally_fill = "material/sync-saved-locally:fill"
syringe = "material/syringe"
syringe_fill = "material/syringe:fill"
system_update = "material/system-update"
system_update_fill = "material/system-update:fill"
system_update_alt = "material/system-update-alt"
system_update_alt_fill = "material/system-update-alt:fill"
tab = "material/tab"
tab_fill = "material/tab:fill"
tab_close = "material/tab-close"
tab_close_fill = "material/tab-close:fill"
tab_close_right = "material/tab-close-right"
tab_close_right_fill = "material/tab-close-right:fill"
tab_duplicate = "material/tab-duplicate"
tab_duplicate_fill = "material/tab-duplicate:fill"
tab_group = "material/tab-group"
tab_group_fill = "material/tab-group:fill"
tab_move = "material/tab-move"
tab_move_fill = "material/tab-move:fill"
tab_new_right = "material/tab-new-right"
tab_new_right_fill = "material/tab-new-right:fill"
tab_recent = "material/tab-recent"
tab_recent_fill = "material/tab-recent:fill"
tab_unselected = "material/tab-unselected"
tab_unselected_fill = "material/tab-unselected:fill"
table = "material/table"
table_fill = "material/table:fill"
table_bar = "material/table-bar"
table_bar_fill = "material/table-bar:fill"
table_chart = "material/table-chart"
table_chart_fill = "material/table-chart:fill"
table_chart_view = "material/table-chart-view"
table_chart_view_fill = "material/table-chart-view:fill"
table_lamp = "material/table-lamp"
table_lamp_fill = "material/table-lamp:fill"
table_restaurant = "material/table-restaurant"
table_restaurant_fill = "material/table-restaurant:fill"
table_rows = "material/table-rows"
table_rows_fill = "material/table-rows:fill"
table_rows_narrow = "material/table-rows-narrow"
table_rows_narrow_fill = "material/table-rows-narrow:fill"
table_view = "material/table-view"
table_view_fill = "material/table-view:fill"
tablet = "material/tablet"
tablet_fill = "material/tablet:fill"
tablet_android = "material/tablet-android"
tablet_android_fill = "material/tablet-android:fill"
tablet_mac = "material/tablet-mac"
tablet_mac_fill = "material/tablet-mac:fill"
tabs = "material/tabs"
tabs_fill = "material/tabs:fill"
tactic = "material/tactic"
tactic_fill = "material/tactic:fill"
tag = "material/tag"
tag_fill = "material/tag:fill"
takeout_dining = "material/takeout-dining"
takeout_dining_fill = "material/takeout-dining:fill"
tamper_detection_off = "material/tamper-detection-off"
tamper_detection_off_fill = "material/tamper-detection-off:fill"
tamper_detection_on = "material/tamper-detection-on"
tamper_detection_on_fill = "material/tamper-detection-on:fill"
tap_and_play = "material/tap-and-play"
tap_and_play_fill = "material/tap-and-play:fill"
tapas = "material/tapas"
tapas_fill = "material/tapas:fill"
target = "material/target"
target_fill = "material/target:fill"
task = "material/task"
task_fill = "material/task:fill"
task_alt = "material/task-alt"
task_alt_fill = "material/task-alt:fill"
taunt = "material/taunt"
taunt_fill = "material/taunt:fill"
taxi_alert = "material/taxi-alert"
taxi_alert_fill = "material/taxi-alert:fill"
team_dashboard = "material/team-dashboard"
team_dashboard_fill = "material/team-dashboard:fill"
temp_preferences_eco = "material/temp-preferences-eco"
temp_preferences_eco_fill = "material/temp-preferences-eco:fill"
temple_buddhist = "material/temple-buddhist"
temple_buddhist_fill = "material/temple-buddhist:fill"
temple_hindu = "material/temple-hindu"
temple_hindu_fill = "material/temple-hindu:fill"
tenancy = "material/tenancy"
tenancy_fill = "material/tenancy:fill"
terminal = "material/terminal"
terminal_fill = "material/terminal:fill"
text_ad = "material/text-ad"
text_ad_fill = "material/text-ad:fill"
text_decrease = "material/text-decrease"
text_decrease_fill = "material/text-decrease:fill"
text_fields = "material/text-fields"
text_fields_fill = "material/text-fields:fill"
text_format = "material/text-format"
text_format_fill = "material/text-format:fill"
text_increase = "material/text-increase"
text_increase_fill = "material/text-increase:fill"
text_rotate_up = "material/text-rotate-up"
text_rotate_up_fill = "material/text-rotate-up:fill"
text_rotate_vertical = "material/text-rotate-vertical"
text_rotate_vertical_fill = "material/text-rotate-vertical:fill"
text_rotation_angledown = "material/text-rotation-angledown"
text_rotation_angledown_fill = "material/text-rotation-angledown:fill"
text_rotation_angleup = "material/text-rotation-angleup"
text_rotation_angleup_fill = "material/text-rotation-angleup:fill"
text_rotation_down = "material/text-rotation-down"
text_rotation_down_fill = "material/text-rotation-down:fill"
text_rotation_none = "material/text-rotation-none"
text_rotation_none_fill = "material/text-rotation-none:fill"
text_select_end = "material/text-select-end"
text_select_end_fill = "material/text-select-end:fill"
text_select_jump_to_beginning = "material/text-select-jump-to-beginning"
text_select_jump_to_beginning_fill = (
    "material/text-select-jump-to-beginning:fill"
)
text_select_jump_to_end = "material/text-select-jump-to-end"
text_select_jump_to_end_fill = "material/text-select-jump-to-end:fill"
text_select_move_back_character = "material/text-select-move-back-character"
text_select_move_back_character_fill = (
    "material/text-select-move-back-character:fill"
)
text_select_move_back_word = "material/text-select-move-back-word"
text_select_move_back_word_fill = "material/text-select-move-back-word:fill"
text_select_move_down = "material/text-select-move-down"
text_select_move_down_fill = "material/text-select-move-down:fill"
text_select_move_forward_character = (
    "material/text-select-move-forward-character"
)
text_select_move_forward_character_fill = (
    "material/text-select-move-forward-character:fill"
)
text_select_move_forward_word = "material/text-select-move-forward-word"
text_select_move_forward_word_fill = (
    "material/text-select-move-forward-word:fill"
)
text_select_move_up = "material/text-select-move-up"
text_select_move_up_fill = "material/text-select-move-up:fill"
text_select_start = "material/text-select-start"
text_select_start_fill = "material/text-select-start:fill"
text_snippet = "material/text-snippet"
text_snippet_fill = "material/text-snippet:fill"
text_to_speech = "material/text-to-speech"
text_to_speech_fill = "material/text-to-speech:fill"
texture = "material/texture"
texture_fill = "material/texture:fill"
texture_add = "material/texture-add"
texture_add_fill = "material/texture-add:fill"
texture_minus = "material/texture-minus"
texture_minus_fill = "material/texture-minus:fill"
theater_comedy = "material/theater-comedy"
theater_comedy_fill = "material/theater-comedy:fill"
theaters = "material/theaters"
theaters_fill = "material/theaters:fill"
thermometer = "material/thermometer"
thermometer_fill = "material/thermometer:fill"
thermometer_add = "material/thermometer-add"
thermometer_add_fill = "material/thermometer-add:fill"
thermometer_gain = "material/thermometer-gain"
thermometer_gain_fill = "material/thermometer-gain:fill"
thermometer_loss = "material/thermometer-loss"
thermometer_loss_fill = "material/thermometer-loss:fill"
thermometer_minus = "material/thermometer-minus"
thermometer_minus_fill = "material/thermometer-minus:fill"
thermostat = "material/thermostat"
thermostat_fill = "material/thermostat:fill"
thermostat_auto = "material/thermostat-auto"
thermostat_auto_fill = "material/thermostat-auto:fill"
thermostat_carbon = "material/thermostat-carbon"
thermostat_carbon_fill = "material/thermostat-carbon:fill"
thumb_down = "material/thumb-down"
thumb_down_fill = "material/thumb-down:fill"
thumb_up = "material/thumb-up"
thumb_up_fill = "material/thumb-up:fill"
thumbnail_bar = "material/thumbnail-bar"
thumbnail_bar_fill = "material/thumbnail-bar:fill"
thumbs_up_down = "material/thumbs-up-down"
thumbs_up_down_fill = "material/thumbs-up-down:fill"
thunderstorm = "material/thunderstorm"
thunderstorm_fill = "material/thunderstorm:fill"
tibia = "material/tibia"
tibia_fill = "material/tibia:fill"
tibia_alt = "material/tibia-alt"
tibia_alt_fill = "material/tibia-alt:fill"
time_auto = "material/time-auto"
time_auto_fill = "material/time-auto:fill"
timelapse = "material/timelapse"
timelapse_fill = "material/timelapse:fill"
timeline = "material/timeline"
timeline_fill = "material/timeline:fill"
timer = "material/timer"
timer_fill = "material/timer:fill"
timer_10 = "material/timer-10"
timer_10_fill = "material/timer-10:fill"
timer_10_alt_1 = "material/timer-10-alt-1"
timer_10_alt_1_fill = "material/timer-10-alt-1:fill"
timer_10_select = "material/timer-10-select"
timer_10_select_fill = "material/timer-10-select:fill"
timer_3 = "material/timer-3"
timer_3_fill = "material/timer-3:fill"
timer_3_alt_1 = "material/timer-3-alt-1"
timer_3_alt_1_fill = "material/timer-3-alt-1:fill"
timer_3_select = "material/timer-3-select"
timer_3_select_fill = "material/timer-3-select:fill"
timer_off = "material/timer-off"
timer_off_fill = "material/timer-off:fill"
tire_repair = "material/tire-repair"
tire_repair_fill = "material/tire-repair:fill"
title = "material/title"
title_fill = "material/title:fill"
toast = "material/toast"
toast_fill = "material/toast:fill"
toc = "material/toc"
toc_fill = "material/toc:fill"
today = "material/today"
today_fill = "material/today:fill"
toggle_off = "material/toggle-off"
toggle_off_fill = "material/toggle-off:fill"
toggle_on = "material/toggle-on"
toggle_on_fill = "material/toggle-on:fill"
token = "material/token"
token_fill = "material/token:fill"
toll = "material/toll"
toll_fill = "material/toll:fill"
tonality = "material/tonality"
tonality_fill = "material/tonality:fill"
toolbar = "material/toolbar"
toolbar_fill = "material/toolbar:fill"
tools_flat_head = "material/tools-flat-head"
tools_flat_head_fill = "material/tools-flat-head:fill"
tools_installation_kit = "material/tools-installation-kit"
tools_installation_kit_fill = "material/tools-installation-kit:fill"
tools_ladder = "material/tools-ladder"
tools_ladder_fill = "material/tools-ladder:fill"
tools_level = "material/tools-level"
tools_level_fill = "material/tools-level:fill"
tools_phillips = "material/tools-phillips"
tools_phillips_fill = "material/tools-phillips:fill"
tools_pliers_wire_stripper = "material/tools-pliers-wire-stripper"
tools_pliers_wire_stripper_fill = "material/tools-pliers-wire-stripper:fill"
tools_power_drill = "material/tools-power-drill"
tools_power_drill_fill = "material/tools-power-drill:fill"
tooltip = "material/tooltip"
tooltip_fill = "material/tooltip:fill"
top_panel_close = "material/top-panel-close"
top_panel_close_fill = "material/top-panel-close:fill"
top_panel_open = "material/top-panel-open"
top_panel_open_fill = "material/top-panel-open:fill"
topic = "material/topic"
topic_fill = "material/topic:fill"
tornado = "material/tornado"
tornado_fill = "material/tornado:fill"
total_dissolved_solids = "material/total-dissolved-solids"
total_dissolved_solids_fill = "material/total-dissolved-solids:fill"
touch_app = "material/touch-app"
touch_app_fill = "material/touch-app:fill"
touchpad_mouse = "material/touchpad-mouse"
touchpad_mouse_fill = "material/touchpad-mouse:fill"
tour = "material/tour"
tour_fill = "material/tour:fill"
toys = "material/toys"
toys_fill = "material/toys:fill"
toys_fan = "material/toys-fan"
toys_fan_fill = "material/toys-fan:fill"
track_changes = "material/track-changes"
track_changes_fill = "material/track-changes:fill"
traffic = "material/traffic"
traffic_fill = "material/traffic:fill"
trail_length = "material/trail-length"
trail_length_fill = "material/trail-length:fill"
trail_length_medium = "material/trail-length-medium"
trail_length_medium_fill = "material/trail-length-medium:fill"
trail_length_short = "material/trail-length-short"
trail_length_short_fill = "material/trail-length-short:fill"
train = "material/train"
train_fill = "material/train:fill"
tram = "material/tram"
tram_fill = "material/tram:fill"
transcribe = "material/transcribe"
transcribe_fill = "material/transcribe:fill"
transfer_within_a_station = "material/transfer-within-a-station"
transfer_within_a_station_fill = "material/transfer-within-a-station:fill"
transform = "material/transform"
transform_fill = "material/transform:fill"
transgender = "material/transgender"
transgender_fill = "material/transgender:fill"
transit_enterexit = "material/transit-enterexit"
transit_enterexit_fill = "material/transit-enterexit:fill"
translate = "material/translate"
translate_fill = "material/translate:fill"
transportation = "material/transportation"
transportation_fill = "material/transportation:fill"
travel = "material/travel"
travel_fill = "material/travel:fill"
travel_explore = "material/travel-explore"
travel_explore_fill = "material/travel-explore:fill"
trending_down = "material/trending-down"
trending_down_fill = "material/trending-down:fill"
trending_flat = "material/trending-flat"
trending_flat_fill = "material/trending-flat:fill"
trending_up = "material/trending-up"
trending_up_fill = "material/trending-up:fill"
trip_origin = "material/trip-origin"
trip_origin_fill = "material/trip-origin:fill"
trolley = "material/trolley"
trolley_fill = "material/trolley:fill"
trophy = "material/trophy"
trophy_fill = "material/trophy:fill"
troubleshoot = "material/troubleshoot"
troubleshoot_fill = "material/troubleshoot:fill"
tsunami = "material/tsunami"
tsunami_fill = "material/tsunami:fill"
tsv = "material/tsv"
tsv_fill = "material/tsv:fill"
tty = "material/tty"
tty_fill = "material/tty:fill"
tune = "material/tune"
tune_fill = "material/tune:fill"
turn_left = "material/turn-left"
turn_left_fill = "material/turn-left:fill"
turn_right = "material/turn-right"
turn_right_fill = "material/turn-right:fill"
turn_sharp_left = "material/turn-sharp-left"
turn_sharp_left_fill = "material/turn-sharp-left:fill"
turn_sharp_right = "material/turn-sharp-right"
turn_sharp_right_fill = "material/turn-sharp-right:fill"
turn_slight_left = "material/turn-slight-left"
turn_slight_left_fill = "material/turn-slight-left:fill"
turn_slight_right = "material/turn-slight-right"
turn_slight_right_fill = "material/turn-slight-right:fill"
tv = "material/tv"
tv_fill = "material/tv:fill"
tv_gen = "material/tv-gen"
tv_gen_fill = "material/tv-gen:fill"
tv_guide = "material/tv-guide"
tv_guide_fill = "material/tv-guide:fill"
tv_off = "material/tv-off"
tv_off_fill = "material/tv-off:fill"
tv_options_edit_channels = "material/tv-options-edit-channels"
tv_options_edit_channels_fill = "material/tv-options-edit-channels:fill"
tv_remote = "material/tv-remote"
tv_remote_fill = "material/tv-remote:fill"
tv_signin = "material/tv-signin"
tv_signin_fill = "material/tv-signin:fill"
tv_with_assistant = "material/tv-with-assistant"
tv_with_assistant_fill = "material/tv-with-assistant:fill"
twinkle = "material/twinkle"
twinkle_fill = "material/twinkle:fill"
two_wheeler = "material/two-wheeler"
two_wheeler_fill = "material/two-wheeler:fill"
type_specimen = "material/type-specimen"
type_specimen_fill = "material/type-specimen:fill"
u_turn_left = "material/u-turn-left"
u_turn_left_fill = "material/u-turn-left:fill"
u_turn_right = "material/u-turn-right"
u_turn_right_fill = "material/u-turn-right:fill"
ulna_radius = "material/ulna-radius"
ulna_radius_fill = "material/ulna-radius:fill"
ulna_radius_alt = "material/ulna-radius-alt"
ulna_radius_alt_fill = "material/ulna-radius-alt:fill"
umbrella = "material/umbrella"
umbrella_fill = "material/umbrella:fill"
unarchive = "material/unarchive"
unarchive_fill = "material/unarchive:fill"
undo = "material/undo"
undo_fill = "material/undo:fill"
unfold_less = "material/unfold-less"
unfold_less_fill = "material/unfold-less:fill"
unfold_less_double = "material/unfold-less-double"
unfold_less_double_fill = "material/unfold-less-double:fill"
unfold_more = "material/unfold-more"
unfold_more_fill = "material/unfold-more:fill"
unfold_more_double = "material/unfold-more-double"
unfold_more_double_fill = "material/unfold-more-double:fill"
ungroup = "material/ungroup"
ungroup_fill = "material/ungroup:fill"
universal_currency_alt = "material/universal-currency-alt"
universal_currency_alt_fill = "material/universal-currency-alt:fill"
unknown_2 = "material/unknown-2"
unknown_2_fill = "material/unknown-2:fill"
unknown_5 = "material/unknown-5"
unknown_5_fill = "material/unknown-5:fill"
unknown_document = "material/unknown-document"
unknown_document_fill = "material/unknown-document:fill"
unknown_med = "material/unknown-med"
unknown_med_fill = "material/unknown-med:fill"
unpublished = "material/unpublished"
unpublished_fill = "material/unpublished:fill"
unsubscribe = "material/unsubscribe"
unsubscribe_fill = "material/unsubscribe:fill"
upcoming = "material/upcoming"
upcoming_fill = "material/upcoming:fill"
update = "material/update"
update_fill = "material/update:fill"
update_disabled = "material/update-disabled"
update_disabled_fill = "material/update-disabled:fill"
upgrade = "material/upgrade"
upgrade_fill = "material/upgrade:fill"
upload = "material/upload"
upload_fill = "material/upload:fill"
upload_file = "material/upload-file"
upload_file_fill = "material/upload-file:fill"
urology = "material/urology"
urology_fill = "material/urology:fill"
usb = "material/usb"
usb_fill = "material/usb:fill"
usb_off = "material/usb-off"
usb_off_fill = "material/usb-off:fill"
vaccines = "material/vaccines"
vaccines_fill = "material/vaccines:fill"
valve = "material/valve"
valve_fill = "material/valve:fill"
vape_free = "material/vape-free"
vape_free_fill = "material/vape-free:fill"
vaping_rooms = "material/vaping-rooms"
vaping_rooms_fill = "material/vaping-rooms:fill"
variables = "material/variables"
variables_fill = "material/variables:fill"
ventilator = "material/ventilator"
ventilator_fill = "material/ventilator:fill"
verified = "material/verified"
verified_fill = "material/verified:fill"
verified_user = "material/verified-user"
verified_user_fill = "material/verified-user:fill"
vertical_align_bottom = "material/vertical-align-bottom"
vertical_align_bottom_fill = "material/vertical-align-bottom:fill"
vertical_align_center = "material/vertical-align-center"
vertical_align_center_fill = "material/vertical-align-center:fill"
vertical_align_top = "material/vertical-align-top"
vertical_align_top_fill = "material/vertical-align-top:fill"
vertical_distribute = "material/vertical-distribute"
vertical_distribute_fill = "material/vertical-distribute:fill"
vertical_shades = "material/vertical-shades"
vertical_shades_fill = "material/vertical-shades:fill"
vertical_shades_closed = "material/vertical-shades-closed"
vertical_shades_closed_fill = "material/vertical-shades-closed:fill"
vertical_split = "material/vertical-split"
vertical_split_fill = "material/vertical-split:fill"
vibration = "material/vibration"
vibration_fill = "material/vibration:fill"
video_call = "material/video-call"
video_call_fill = "material/video-call:fill"
video_camera_back = "material/video-camera-back"
video_camera_back_fill = "material/video-camera-back:fill"
video_camera_front = "material/video-camera-front"
video_camera_front_fill = "material/video-camera-front:fill"
video_camera_front_off = "material/video-camera-front-off"
video_camera_front_off_fill = "material/video-camera-front-off:fill"
video_chat = "material/video-chat"
video_chat_fill = "material/video-chat:fill"
video_file = "material/video-file"
video_file_fill = "material/video-file:fill"
video_label = "material/video-label"
video_label_fill = "material/video-label:fill"
video_library = "material/video-library"
video_library_fill = "material/video-library:fill"
video_search = "material/video-search"
video_search_fill = "material/video-search:fill"
video_settings = "material/video-settings"
video_settings_fill = "material/video-settings:fill"
video_stable = "material/video-stable"
video_stable_fill = "material/video-stable:fill"
videocam = "material/videocam"
videocam_fill = "material/videocam:fill"
videocam_off = "material/videocam-off"
videocam_off_fill = "material/videocam-off:fill"
videogame_asset = "material/videogame-asset"
videogame_asset_fill = "material/videogame-asset:fill"
videogame_asset_off = "material/videogame-asset-off"
videogame_asset_off_fill = "material/videogame-asset-off:fill"
view_agenda = "material/view-agenda"
view_agenda_fill = "material/view-agenda:fill"
view_array = "material/view-array"
view_array_fill = "material/view-array:fill"
view_carousel = "material/view-carousel"
view_carousel_fill = "material/view-carousel:fill"
view_column = "material/view-column"
view_column_fill = "material/view-column:fill"
view_column_2 = "material/view-column-2"
view_column_2_fill = "material/view-column-2:fill"
view_comfy = "material/view-comfy"
view_comfy_fill = "material/view-comfy:fill"
view_comfy_alt = "material/view-comfy-alt"
view_comfy_alt_fill = "material/view-comfy-alt:fill"
view_compact = "material/view-compact"
view_compact_fill = "material/view-compact:fill"
view_compact_alt = "material/view-compact-alt"
view_compact_alt_fill = "material/view-compact-alt:fill"
view_cozy = "material/view-cozy"
view_cozy_fill = "material/view-cozy:fill"
view_day = "material/view-day"
view_day_fill = "material/view-day:fill"
view_headline = "material/view-headline"
view_headline_fill = "material/view-headline:fill"
view_in_ar = "material/view-in-ar"
view_in_ar_fill = "material/view-in-ar:fill"
view_in_ar_off = "material/view-in-ar-off"
view_in_ar_off_fill = "material/view-in-ar-off:fill"
view_kanban = "material/view-kanban"
view_kanban_fill = "material/view-kanban:fill"
view_list = "material/view-list"
view_list_fill = "material/view-list:fill"
view_module = "material/view-module"
view_module_fill = "material/view-module:fill"
view_quilt = "material/view-quilt"
view_quilt_fill = "material/view-quilt:fill"
view_sidebar = "material/view-sidebar"
view_sidebar_fill = "material/view-sidebar:fill"
view_stream = "material/view-stream"
view_stream_fill = "material/view-stream:fill"
view_timeline = "material/view-timeline"
view_timeline_fill = "material/view-timeline:fill"
view_week = "material/view-week"
view_week_fill = "material/view-week:fill"
vignette = "material/vignette"
vignette_fill = "material/vignette:fill"
villa = "material/villa"
villa_fill = "material/villa:fill"
visibility = "material/visibility"
visibility_fill = "material/visibility:fill"
visibility_lock = "material/visibility-lock"
visibility_lock_fill = "material/visibility-lock:fill"
visibility_off = "material/visibility-off"
visibility_off_fill = "material/visibility-off:fill"
vital_signs = "material/vital-signs"
vital_signs_fill = "material/vital-signs:fill"
voice_chat = "material/voice-chat"
voice_chat_fill = "material/voice-chat:fill"
voice_over_off = "material/voice-over-off"
voice_over_off_fill = "material/voice-over-off:fill"
voice_selection = "material/voice-selection"
voice_selection_fill = "material/voice-selection:fill"
voicemail = "material/voicemail"
voicemail_fill = "material/voicemail:fill"
volcano = "material/volcano"
volcano_fill = "material/volcano:fill"
volume_down = "material/volume-down"
volume_down_fill = "material/volume-down:fill"
volume_down_alt = "material/volume-down-alt"
volume_down_alt_fill = "material/volume-down-alt:fill"
volume_mute = "material/volume-mute"
volume_mute_fill = "material/volume-mute:fill"
volume_off = "material/volume-off"
volume_off_fill = "material/volume-off:fill"
volume_up = "material/volume-up"
volume_up_fill = "material/volume-up:fill"
volunteer_activism = "material/volunteer-activism"
volunteer_activism_fill = "material/volunteer-activism:fill"
voting_chip = "material/voting-chip"
voting_chip_fill = "material/voting-chip:fill"
vpn_key = "material/vpn-key"
vpn_key_fill = "material/vpn-key:fill"
vpn_key_alert = "material/vpn-key-alert"
vpn_key_alert_fill = "material/vpn-key-alert:fill"
vpn_key_off = "material/vpn-key-off"
vpn_key_off_fill = "material/vpn-key-off:fill"
vpn_lock = "material/vpn-lock"
vpn_lock_fill = "material/vpn-lock:fill"
vr180_create2d = "material/vr180-create2d"
vr180_create2d_fill = "material/vr180-create2d:fill"
vr180_create2d_off = "material/vr180-create2d-off"
vr180_create2d_off_fill = "material/vr180-create2d-off:fill"
vrpano = "material/vrpano"
vrpano_fill = "material/vrpano:fill"
wall_art = "material/wall-art"
wall_art_fill = "material/wall-art:fill"
wall_lamp = "material/wall-lamp"
wall_lamp_fill = "material/wall-lamp:fill"
wallet = "material/wallet"
wallet_fill = "material/wallet:fill"
wallpaper = "material/wallpaper"
wallpaper_fill = "material/wallpaper:fill"
wallpaper_slideshow = "material/wallpaper-slideshow"
wallpaper_slideshow_fill = "material/wallpaper-slideshow:fill"
ward = "material/ward"
ward_fill = "material/ward:fill"
warehouse = "material/warehouse"
warehouse_fill = "material/warehouse:fill"
warning = "material/warning"
warning_fill = "material/warning:fill"
warning_off = "material/warning-off"
warning_off_fill = "material/warning-off:fill"
wash = "material/wash"
wash_fill = "material/wash:fill"
watch = "material/watch"
watch_fill = "material/watch:fill"
watch_button_press = "material/watch-button-press"
watch_button_press_fill = "material/watch-button-press:fill"
watch_off = "material/watch-off"
watch_off_fill = "material/watch-off:fill"
watch_screentime = "material/watch-screentime"
watch_screentime_fill = "material/watch-screentime:fill"
watch_wake = "material/watch-wake"
watch_wake_fill = "material/watch-wake:fill"
water = "material/water"
water_fill = "material/water:fill"
water_bottle = "material/water-bottle"
water_bottle_fill = "material/water-bottle:fill"
water_bottle_large = "material/water-bottle-large"
water_bottle_large_fill = "material/water-bottle-large:fill"
water_damage = "material/water-damage"
water_damage_fill = "material/water-damage:fill"
water_do = "material/water-do"
water_do_fill = "material/water-do:fill"
water_drop = "material/water-drop"
water_drop_fill = "material/water-drop:fill"
water_ec = "material/water-ec"
water_ec_fill = "material/water-ec:fill"
water_full = "material/water-full"
water_full_fill = "material/water-full:fill"
water_heater = "material/water-heater"
water_heater_fill = "material/water-heater:fill"
water_lock = "material/water-lock"
water_lock_fill = "material/water-lock:fill"
water_loss = "material/water-loss"
water_loss_fill = "material/water-loss:fill"
water_lux = "material/water-lux"
water_lux_fill = "material/water-lux:fill"
water_medium = "material/water-medium"
water_medium_fill = "material/water-medium:fill"
water_orp = "material/water-orp"
water_orp_fill = "material/water-orp:fill"
water_ph = "material/water-ph"
water_ph_fill = "material/water-ph:fill"
water_pump = "material/water-pump"
water_pump_fill = "material/water-pump:fill"
water_voc = "material/water-voc"
water_voc_fill = "material/water-voc:fill"
waterfall_chart = "material/waterfall-chart"
waterfall_chart_fill = "material/waterfall-chart:fill"
waves = "material/waves"
waves_fill = "material/waves:fill"
waving_hand = "material/waving-hand"
waving_hand_fill = "material/waving-hand:fill"
wb_auto = "material/wb-auto"
wb_auto_fill = "material/wb-auto:fill"
wb_incandescent = "material/wb-incandescent"
wb_incandescent_fill = "material/wb-incandescent:fill"
wb_iridescent = "material/wb-iridescent"
wb_iridescent_fill = "material/wb-iridescent:fill"
wb_shade = "material/wb-shade"
wb_shade_fill = "material/wb-shade:fill"
wb_sunny = "material/wb-sunny"
wb_sunny_fill = "material/wb-sunny:fill"
wb_twilight = "material/wb-twilight"
wb_twilight_fill = "material/wb-twilight:fill"
wc = "material/wc"
wc_fill = "material/wc:fill"
weather_hail = "material/weather-hail"
weather_hail_fill = "material/weather-hail:fill"
weather_mix = "material/weather-mix"
weather_mix_fill = "material/weather-mix:fill"
weather_snowy = "material/weather-snowy"
weather_snowy_fill = "material/weather-snowy:fill"
web = "material/web"
web_fill = "material/web:fill"
web_asset = "material/web-asset"
web_asset_fill = "material/web-asset:fill"
web_asset_off = "material/web-asset-off"
web_asset_off_fill = "material/web-asset-off:fill"
web_stories = "material/web-stories"
web_stories_fill = "material/web-stories:fill"
webhook = "material/webhook"
webhook_fill = "material/webhook:fill"
weekend = "material/weekend"
weekend_fill = "material/weekend:fill"
weight = "material/weight"
weight_fill = "material/weight:fill"
west = "material/west"
west_fill = "material/west:fill"
whatshot = "material/whatshot"
whatshot_fill = "material/whatshot:fill"
wheelchair_pickup = "material/wheelchair-pickup"
wheelchair_pickup_fill = "material/wheelchair-pickup:fill"
where_to_vote = "material/where-to-vote"
where_to_vote_fill = "material/where-to-vote:fill"
widgets = "material/widgets"
widgets_fill = "material/widgets:fill"
width = "material/width"
width_fill = "material/width:fill"
width_full = "material/width-full"
width_full_fill = "material/width-full:fill"
width_normal = "material/width-normal"
width_normal_fill = "material/width-normal:fill"
width_wide = "material/width-wide"
width_wide_fill = "material/width-wide:fill"
wifi = "material/wifi"
wifi_fill = "material/wifi:fill"
wifi_1_bar = "material/wifi-1-bar"
wifi_1_bar_fill = "material/wifi-1-bar:fill"
wifi_2_bar = "material/wifi-2-bar"
wifi_2_bar_fill = "material/wifi-2-bar:fill"
wifi_add = "material/wifi-add"
wifi_add_fill = "material/wifi-add:fill"
wifi_calling = "material/wifi-calling"
wifi_calling_fill = "material/wifi-calling:fill"
wifi_calling_1 = "material/wifi-calling-1"
wifi_calling_1_fill = "material/wifi-calling-1:fill"
wifi_calling_2 = "material/wifi-calling-2"
wifi_calling_2_fill = "material/wifi-calling-2:fill"
wifi_calling_3 = "material/wifi-calling-3"
wifi_calling_3_fill = "material/wifi-calling-3:fill"
wifi_channel = "material/wifi-channel"
wifi_channel_fill = "material/wifi-channel:fill"
wifi_find = "material/wifi-find"
wifi_find_fill = "material/wifi-find:fill"
wifi_home = "material/wifi-home"
wifi_home_fill = "material/wifi-home:fill"
wifi_lock = "material/wifi-lock"
wifi_lock_fill = "material/wifi-lock:fill"
wifi_notification = "material/wifi-notification"
wifi_notification_fill = "material/wifi-notification:fill"
wifi_off = "material/wifi-off"
wifi_off_fill = "material/wifi-off:fill"
wifi_password = "material/wifi-password"
wifi_password_fill = "material/wifi-password:fill"
wifi_protected_setup = "material/wifi-protected-setup"
wifi_protected_setup_fill = "material/wifi-protected-setup:fill"
wifi_proxy = "material/wifi-proxy"
wifi_proxy_fill = "material/wifi-proxy:fill"
wifi_tethering = "material/wifi-tethering"
wifi_tethering_fill = "material/wifi-tethering:fill"
wifi_tethering_error = "material/wifi-tethering-error"
wifi_tethering_error_fill = "material/wifi-tethering-error:fill"
wifi_tethering_off = "material/wifi-tethering-off"
wifi_tethering_off_fill = "material/wifi-tethering-off:fill"
wind_power = "material/wind-power"
wind_power_fill = "material/wind-power:fill"
window = "material/window"
window_fill = "material/window:fill"
window_closed = "material/window-closed"
window_closed_fill = "material/window-closed:fill"
window_open = "material/window-open"
window_open_fill = "material/window-open:fill"
window_sensor = "material/window-sensor"
window_sensor_fill = "material/window-sensor:fill"
wine_bar = "material/wine-bar"
wine_bar_fill = "material/wine-bar:fill"
woman = "material/woman"
woman_fill = "material/woman:fill"
woman_2 = "material/woman-2"
woman_2_fill = "material/woman-2:fill"
work = "material/work"
work_fill = "material/work:fill"
work_alert = "material/work-alert"
work_alert_fill = "material/work-alert:fill"
work_history = "material/work-history"
work_history_fill = "material/work-history:fill"
work_update = "material/work-update"
work_update_fill = "material/work-update:fill"
workspace_premium = "material/workspace-premium"
workspace_premium_fill = "material/workspace-premium:fill"
workspaces = "material/workspaces"
workspaces_fill = "material/workspaces:fill"
wounds_injuries = "material/wounds-injuries"
wounds_injuries_fill = "material/wounds-injuries:fill"
wrap_text = "material/wrap-text"
wrap_text_fill = "material/wrap-text:fill"
wrist = "material/wrist"
wrist_fill = "material/wrist:fill"
wrong_location = "material/wrong-location"
wrong_location_fill = "material/wrong-location:fill"
wysiwyg = "material/wysiwyg"
wysiwyg_fill = "material/wysiwyg:fill"
yard = "material/yard"
yard_fill = "material/yard:fill"
your_trips = "material/your-trips"
your_trips_fill = "material/your-trips:fill"
youtube_activity = "material/youtube-activity"
youtube_activity_fill = "material/youtube-activity:fill"
youtube_searched_for = "material/youtube-searched-for"
youtube_searched_for_fill = "material/youtube-searched-for:fill"
zone_person_alert = "material/zone-person-alert"
zone_person_alert_fill = "material/zone-person-alert:fill"
zone_person_idle = "material/zone-person-idle"
zone_person_idle_fill = "material/zone-person-idle:fill"
zone_person_urgent = "material/zone-person-urgent"
zone_person_urgent_fill = "material/zone-person-urgent:fill"
zoom_in = "material/zoom-in"
zoom_in_fill = "material/zoom-in:fill"
zoom_in_map = "material/zoom-in-map"
zoom_in_map_fill = "material/zoom-in-map:fill"
zoom_out = "material/zoom-out"
zoom_out_fill = "material/zoom-out:fill"
zoom_out_map = "material/zoom-out-map"
zoom_out_map_fill = "material/zoom-out-map:fill"
